
/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */

/*
 * callbacks.h
 * Copyright (C) Niklas Knutsson 2007 <nq@altern.org>
 * 
 * callbacks.h is free software.
 * 
 * You may redistribute it and/or modify it under the terms of the
 * GNU General Public License, as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option)
 * any later version.
 * 
 * callbacks.h is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with callbacks.h.  If not, write to:
 * 	The Free Software Foundation, Inc.,
 * 	51 Franklin Street, Fifth Floor
 * 	Boston, MA  02110-1301, USA.
 */

#ifndef CALLBACKS_H
#define CALLBACKS_H

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gtk/gtk.h>
#include <gconf/gconf.h>
#include <gconf/gconf-client.h>
#include <libnotify/notify.h>
#include <libgnomecanvas/libgnomecanvas.h>

#include "gtvg_channel.h"
#include "gtvg_program.h"
#include "gtvg_favourite.h"
#include "gtvg_category.h"

/*
 * Standard gettext macros.
 */
#ifdef ENABLE_NLS
#  include <libintl.h>
#  undef _
#  define _(String) dgettext (PACKAGE, String)
#  ifdef gettext_noop
#    define N_(String) gettext_noop (String)
#  else
#    define N_(String) (String)
#  endif
#else
#  define textdomain(String) (String)
#  define gettext(String) (String)
#  define dgettext(Domain,Message) (Message)
#  define dcgettext(Domain,Message,Type) (Message)
#  define bindtextdomain(Domain,Directory) (Domain)
#  define _(String) (String)
#  define N_(String) (String)
#endif

#define FAVOURITES_DISPLAY_COLUMN		0
#define FAVOURITES_TITLE_COLUMN			1
#define FAVOURITES_OBJECT_COLUMN		2

#define CHANNELS_NAME_COLUMN			0
#define CHANNELS_ICON_COLUMN				1
#define CHANNELS_OBJECT_COLUMN		2
#define CHANNELS_ID_COLUMN					3

#define PROGRESS_COLUMN						0
#define PROGRESS_TEXT_COLUMN				1
#define TITLE_COLUMN									2
#define TIME_COLUMN									3
#define CHANNEL_COLUMN							4
#define BACKGROUND_COLUMN					5
#define FOREGROUND_COLUMN					6
#define OBJECT_COLUMN								7

static const char *grabbers[] = {
	"tv_grab_ar",
	"tv_grab_au",
	"tv_grab_be",
	"tv_grab_br",
	"tv_grab_br_net",
	"tv_grab_ch",
	"tv_grab_ch_bluewin",
	"tv_grab_ch_search",
	"tv_grab_cz",
	"tv_grab_de_tvtoday",
	"tv_grab_dk",
	"tv_grab_dtv_la",
	"tv_grab_ee",
	"tv_grab_es",
	"tv_grab_es_laguiatv",
	"tv_grab_fi",
	"tv_grab_fr",
	"tv_grab_hr",
	"tv_grab_huro",
	"tv_grab_il",
	"tv_grab_is",
	"tv_grab_it",
	"tv_grab_jp",
	"tv_grab_na_dd",
	"tv_grab_nc",
	"tv_grab_nl",
	"tv_grab_nl_wolf",
	"tv_grab_no",
	"tv_grab_no_gfeed",
	"tv_grab_pt",
	"tv_grab_re",
	"tv_grab_se_swedb",
	"tv_grab_uk_rt",
	"tv_grab_uk_bleb",
	"tv_grab_za",
	NULL
};

static gboolean grabber_supports_slow[] = {
	FALSE,
	FALSE,
	TRUE,
	FALSE,
	FALSE,
	FALSE,
	FALSE,
	FALSE,
	FALSE,
	FALSE,
	FALSE,
	FALSE,
	FALSE,
	FALSE,
	FALSE,
	FALSE,
	TRUE,
	FALSE,
	TRUE,
	FALSE,
	FALSE,
	TRUE,
	FALSE,
	FALSE,
	TRUE,
	TRUE,
	FALSE,
	FALSE,
	FALSE,
	FALSE,
	TRUE,
	FALSE,
	FALSE,
	FALSE,
	FALSE
};

static const char *record_presets[] = {
	"XdTV",
	NULL
};

static const char *record_preset_start[] = {
	"xdtv -rec_filename \"$HOME/Documents/%p-%d.avi\" -e \"setchannel %c; record\"",
	NULL
};

static const char *record_preset_stop[] = {
	"xdtv_cmd \"record; quit\"",
	NULL
};

enum favouriteType {
	FAVOURITE_ALL,
	FAVOURITE_CHANNEL,
	FAVOURITE_TIME,
	FAVOURITE_DAYANDTIME,
	FAVOURITE_ONCE
};

enum mainwindowState {
	MAINWINDOW_SHOWN,
	MAINWINDOW_MAXIMIZED,
	MAINWINDOW_ICONIFIED,
	MAINWINDOW_HIDDEN
};

struct favourite_schedule {
	struct GtvgFavourite *fav;
	struct GtvgProgram *prog;
	NotifyNotification *notification;
};

struct record_schedule {
	struct GtvgProgram *prog;
	time_t start_time, stop_time;
	gint priority;
	gint disabled;
};

void on_recordScheduleList_selection_changed(GtkTreeSelection * treeselection, gpointer user_data);
void addFavouriteType(int favtype);
void addFavourite(struct GtvgFavourite *fav);
int configure(gboolean init_run);
void updateXMLTVFile(gboolean reload);
void updateRecSchedule(void);
void updateFavourites(void);
void updateBlacklist(void);
void enableReminders(gboolean enable);
void on_quit(void);
void findNextProgram(const gchar * gstr, gboolean search_future);
void findProgram(const gchar * gstr, gboolean search_future, time_t firsttime);
void searchFavouriteTitle(void);
void searchProgram(void);
void findNextFavourite(GSList * favs, gboolean search_future);
void findFavourite(GSList * favs, gboolean search_future, time_t firsttime);
void searchFavourite(void);
void free_favsched(struct favourite_schedule *favsched);
void free_recsched(struct record_schedule *recsched);
void updateChannelIcons(void);
void clearFilters(void);
void updateTooltip(void);
struct GtvgProgram *selectedProgram(void);
void programSelected(struct GtvgProgram *prog);
void on_viewListMenuItem_toggled(GtkCheckMenuItem * w, gpointer user_data);
void on_viewListToolbutton_toggled(GtkToggleToolButton * w, gpointer user_data);
void on_viewPages_switch_page(GtkNotebook * notebook, GtkNotebookPage * page, guint page_num, gpointer user_data);
void updateWakeupTime(void);
void setWakeupTime(time_t wakeup_time);
void stopRecording(void);

gint gchar_compare_func(gconstpointer a, gconstpointer b);
gint favsched_compare_func(gconstpointer a, gconstpointer b);
gint recsched_compare_func(gconstpointer a, gconstpointer b);
gboolean favouriteIncludes(struct GtvgFavourite *favlist, struct GtvgFavourite *favuser);
gboolean favouriteIncludesProgram(struct GtvgFavourite *fav, struct GtvgProgram *prog, gchar * lower, gchar * upper);
gint favourite_compare_func(gconstpointer a, gconstpointer b);
gint favourite_strict_compare_func(gconstpointer a, gconstpointer b);
gint favourite_sort_compare_func(gconstpointer a, gconstpointer b);

void on_programCanvas_hadj_changed(GtkAdjustment * adj, gpointer user_data);
void on_programCanvas_vadj_changed(GtkAdjustment * adj, gpointer user_data);
gboolean on_gridItem_event(GnomeCanvasItem * item, GdkEvent * event, gpointer user_data);
void on_programList_selection_changed(GtkTreeSelection * treeselection, gpointer user_data);
gboolean on_programList_view_button_press_event(GtkWidget * w, GdkEventButton * event, gpointer user_data);
gboolean on_programList_view_popup_menu(GtkWidget * w, gpointer user_data);
gboolean popup_programList_menu(GdkEventButton * event);
void on_descriptionExpander_expanded(GObject * object, GParamSpec * param_spec, gpointer user_data);
void on_channelsList_selection_changed(GtkTreeSelection * treeselection, gpointer user_data);
void on_categoriesList_selection_changed(GtkTreeSelection * treeselection, gpointer user_data);
void on_channelsList_row_deleted(GtkTreeModel * model, GtkTreePath * path, gpointer user_data);
void on_channelsList_row_inserted(GtkTreeModel * model, GtkTreePath * path, GtkTreeIter * iter, gpointer user_data);
void on_channelsList_drag_end(GtkWidget * w, GdkDragContext * context, gpointer user_data);
gboolean on_channelsList_view_button_press_event(GtkWidget * w, GdkEventButton * event, gpointer user_data);
gboolean on_channelsList_view_popup_menu(GtkWidget * w, gpointer user_data);
gboolean popup_channelsList_menu(GdkEventButton * event);
void on_allChannelsMenuItem_activate(GtkMenuItem * w, gpointer user_data);
void on_updateIconsChannelsMenuItem_activate(GtkMenuItem * w, gpointer user_data);
gboolean on_categoriesList_view_button_press_event(GtkWidget * w, GdkEventButton * event, gpointer user_data);
gboolean on_categoriesList_view_popup_menu(GtkWidget * w, gpointer user_data);
gboolean popup_categoriesList_menu(GdkEventButton * event);
void on_allCategoriesMenuItem_activate(GtkMenuItem * w, gpointer user_data);
void on_favouritesList_selection_changed(GtkTreeSelection * treeselection, gpointer user_data);
gboolean on_favouritesList_view_button_press_event(GtkWidget * w, GdkEventButton * event, gpointer user_data);
gboolean on_favouritesList_view_popup_menu(GtkWidget * w, gpointer user_data);
gboolean popup_favouritesList_menu(GdkEventButton * event);
void on_addFavouriteButton_clicked(GtkButton * w, gpointer user_data);
void removeFavourite(struct GtvgFavourite *fav);
void editFavourite(struct GtvgFavourite *fav);
void newFavourite(void);
void removeTitleFavourites(gchar * title);
void removeProgramFavourites(struct GtvgProgram *prog);
void on_removeFavouriteButton_clicked(GtkButton * w, gpointer user_data);
void on_editFavouriteButton_clicked(GtkButton * w, gpointer user_data);
void on_removeFavouriteMenuItem_activate(GtkMenuItem * w, gpointer user_data);
void on_removeFavouritesMenuItem_activate(GtkMenuItem * w, gpointer user_data);
void on_findFavouritesMenuItem_activate(GtkMenuItem * w, gpointer user_data);
void on_addFavouriteMenuItem_activate(GtkMenuItem * w, gpointer user_data);
void on_blacklist_selection_changed(GtkTreeSelection * treeselection, gpointer user_data);
void on_addToBlacklistMenuItem_activate(GtkMenuItem * w, gpointer user_data);
gboolean on_blacklist_view_button_press_event(GtkWidget * w, GdkEventButton * event, gpointer user_data);
gboolean on_blacklist_view_popup_menu(GtkWidget * w, gpointer user_data);
gboolean popup_blacklist_menu(GdkEventButton * event);
void on_addToBlacklistButton_clicked(GtkButton * w, gpointer user_data);
void removeFromBlacklist(gchar * str);
void on_removeFromBlacklistButton_clicked(GtkButton * w, gpointer user_data);
void on_removeBlacklistMenuItem_activate(GtkMenuItem * w, gpointer user_data);
void on_searchButton_clicked(GtkButton * w, gpointer user_data);
void on_clearSearchButton_clicked(GtkButton * w, gpointer user_data);
void on_searchEntry_activate(GtkEntry * entry, gpointer user_data);
void on_searchEntry_changed(GtkEditable * entry, gpointer user_data);
gboolean on_searchEntry_focus_out(GtkWidget * w, GdkEventFocus * event, gpointer user_data);
void on_updateButton_clicked(GtkButton * w, gpointer user_data);
void on_configureButton_clicked(GtkButton * w, gpointer user_data);
void on_showFavouritesButton_toggled(GtkToggleButton * w, gboolean b, gpointer user_data);
void on_hidePastButton_toggled(GtkToggleButton * w, gboolean b, gpointer user_data);
void on_dayCombo_changed(GtkComboBox * w, gpointer user_data);
void on_aboutMenuItem_activate(GtkMenuItem * w, gpointer user_data);
gboolean checkProgramTimes(gpointer user_data);
gboolean checkFavourites(gpointer user_data);
gboolean on_startRecording_timeout(gpointer user_data);
void on_fileButton_clicked(GtkButton * w, gpointer user_data);
void on_grabCommandCombo_changed(GtkComboBox * w, gpointer user_data);
void on_status_icon_activated(GtkStatusIcon * w, gpointer user_data);
void on_status_icon_popup_menu(GtkStatusIcon * w, guint button, guint activate_time, gpointer user_data);
void on_disableStatusMenuItem_activate(GtkMenuItem * w, gpointer user_data);
void closeWindow();
void on_window_shown(GtkWidget * w, gpointer user_data);
void on_toolbarMenuItem_toggled(GtkCheckMenuItem * w, gpointer user_data);
void on_menubarMenuItem_toggled(GtkCheckMenuItem * w, gpointer user_data);
void on_menubarToolbutton_toggled(GtkToggleToolButton * w, gpointer user_data);
void on_gconf_notify(GConfClient * c, guint cnxn_id, GConfEntry * entry, gpointer user_data);
gboolean on_window_state_event(GtkWidget * widget, GdkEvent * event, gpointer user_data);
void save_position(void);
void restore_position(void);
void set_toolbar_style(const gchar * toolbar_style);

#endif
