
/*
 * gtvg_favourite.h
 * Copyright (C) Niklas Knutsson 2007 <nq@altern.org>
 * 
 * gtvg_favourite.h is free software.
 * 
 * You may redistribute it and/or modify it under the terms of the
 * GNU General Public License, as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option)
 * any later version.
 * 
 * callbacks.h is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with gtvg_favourite.h.  If not, write to:
 * 	The Free Software Foundation, Inc.,
 * 	51 Franklin Street, Fifth Floor
 * 	Boston, MA  02110-1301, USA.
 */

#ifndef GTVG_FAVOURITE_H
#define GTVG_FAVOURITE_H

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gtk/gtk.h>

struct recording_occasion {
	gchar *channel;
	time_t time;
};

gint recocc_compare_func(gconstpointer a, gconstpointer b);

struct GtvgFavourite {
	gchar *title;
	gboolean partial_title;
	gchar *channel;
	gint timeofday;
	gint dayofweek;
	time_t time;
	gint reminder;
	gint reminder_time;
	gint reminder_duration;
	gint record;
	gint record_start_margin;
	gint record_stop_margin;
	gboolean prioritise;
	GSList *disabled_recordings;
	GSList *prioritised_recordings;
};

struct GtvgFavourite *gtvg_favourite_new(void);
void gtvg_favourite_free(struct GtvgFavourite *fav);
void gtvg_favourite_init(struct GtvgFavourite *fav);
void gtvg_favourite_clear(struct GtvgFavourite *fav);
void gtvg_favourite_prioritise_recording(struct GtvgFavourite *fav, gchar * channel, time_t time);
gboolean gtvg_favourite_recording_prioritised(struct GtvgFavourite *fav, gchar * channel, time_t time);
gboolean gtvg_favourite_recording_priority(struct GtvgFavourite *fav, gchar * channel, time_t time);
void gtvg_favourite_unprioritise_recording(struct GtvgFavourite *fav, gchar * channel, time_t time);
void gtvg_favourite_disable_recording(struct GtvgFavourite *fav, gchar * channel, time_t time);
gboolean gtvg_favourite_recording_disabled(struct GtvgFavourite *fav, gchar * channel, time_t time);
void gtvg_favourite_enable_recording(struct GtvgFavourite *fav, gchar * channel, time_t time);

#endif
