
/*
 * gtvg_program.c
 * Copyright (C) Niklas Knutsson 2007 <nq@altern.org>
 * 
 * gtvg_program.c is free software.
 * 
 * You may redistribute it and/or modify it under the terms of the
 * GNU General Public License, as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option)
 * any later version.
 * 
 * callbacks.h is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with gtvg_program.c.  If not, write to:
 * 	The Free Software Foundation, Inc.,
 * 	51 Franklin Street, Fifth Floor
 * 	Boston, MA  02110-1301, USA.
 */

#include "gtvg_program.h"
#include "gtvg_category.h"

extern void free_list_gchar(gpointer data, gpointer user_data);

extern void free_list_category(gpointer data, gpointer user_data);

struct GtvgProgram *gtvg_program_new(void)
{
	struct GtvgProgram *prog = g_slice_new(struct GtvgProgram);

	gtvg_program_init(prog);
	return prog;
}
void gtvg_program_free(struct GtvgProgram *prog)
{
	gtvg_program_clear(prog);
	g_slice_free(struct GtvgProgram, prog);
}
void gtvg_program_init(struct GtvgProgram *prog)
{
	prog->start = 0;
	prog->stop = 0;
	prog->channel = NULL;
	prog->chid = NULL;
	prog->showview = NULL;
	prog->videoplus = NULL;
	prog->title = NULL;
	prog->subtitle = NULL;
	prog->description = NULL;
	prog->short_description = NULL;
	prog->categories = NULL;
	prog->original_categories = NULL;
	prog->episode = NULL;
	prog->date = NULL;
	prog->directors = NULL;
	prog->actors = NULL;
	prog->writers = NULL;
	prog->adapters = NULL;
	prog->producers = NULL;
	prog->presenters = NULL;
	prog->commentators = NULL;
	prog->guests = NULL;
	prog->language = NULL;
	prog->original_language = NULL;
	prog->length = NULL;
	prog->length_units = NULL;
	prog->country = NULL;
	prog->star_rating = NULL;
	prog->rating = NULL;
	prog->aspect = NULL;
	prog->quality = NULL;
	prog->color = NULL;
	prog->audio_present = NULL;
	prog->audio_stereo = NULL;
	prog->previously_shown = FALSE;
	prog->previous_start = NULL;
	prog->previous_chid = NULL;
	prog->previous_channel = NULL;
	prog->new_program = FALSE;
	prog->favourites = NULL;
	prog->canvas_rect = NULL;
	prog->canvas_text = NULL;
	prog->canvas_favourite = FALSE;
}
void gtvg_program_clear(struct GtvgProgram *prog)
{
	if(prog->chid != NULL)
		g_free(prog->chid);
	if(prog->showview != NULL)
		g_free(prog->showview);
	if(prog->videoplus != NULL)
		g_free(prog->videoplus);
	if(prog->title != NULL)
		g_free(prog->title);
	if(prog->subtitle != NULL)
		g_free(prog->subtitle);
	if(prog->description != NULL)
		g_free(prog->description);
	if(prog->short_description != NULL)
		g_free(prog->short_description);
	if(prog->episode != NULL)
		g_free(prog->episode);
	if(prog->date != NULL)
		g_free(prog->date);
	if(prog->language != NULL)
		g_free(prog->language);
	if(prog->original_language != NULL)
		g_free(prog->original_language);
	if(prog->length != NULL)
		g_free(prog->length);
	if(prog->length_units != NULL)
		g_free(prog->length_units);
	if(prog->country != NULL)
		g_free(prog->country);
	if(prog->star_rating != NULL)
		g_free(prog->star_rating);
	if(prog->rating != NULL)
		g_free(prog->rating);
	if(prog->aspect != NULL)
		g_free(prog->aspect);
	if(prog->quality != NULL)
		g_free(prog->quality);
	if(prog->color != NULL)
		g_free(prog->color);
	if(prog->audio_present != NULL)
		g_free(prog->audio_present);
	if(prog->audio_stereo != NULL)
		g_free(prog->audio_stereo);
	if(prog->previous_start != NULL)
		g_free(prog->previous_start);
	if(prog->previous_chid != NULL)
		g_free(prog->previous_chid);
	if(prog->categories != NULL) {
		g_slist_free(prog->categories);
	}
	if(prog->original_categories != NULL) {
		g_slist_foreach(prog->original_categories, free_list_gchar, NULL);
		g_slist_free(prog->original_categories);
	}
	if(prog->directors != NULL) {
		g_slist_foreach(prog->directors, free_list_gchar, NULL);
		g_slist_free(prog->directors);
	}
	if(prog->actors != NULL) {
		g_slist_foreach(prog->actors, free_list_gchar, NULL);
		g_slist_free(prog->actors);
	}
	if(prog->writers != NULL) {
		g_slist_foreach(prog->writers, free_list_gchar, NULL);
		g_slist_free(prog->writers);
	}
	if(prog->adapters != NULL) {
		g_slist_foreach(prog->adapters, free_list_gchar, NULL);
		g_slist_free(prog->adapters);
	}
	if(prog->producers != NULL) {
		g_slist_foreach(prog->producers, free_list_gchar, NULL);
		g_slist_free(prog->producers);
	}
	if(prog->presenters != NULL) {
		g_slist_foreach(prog->presenters, free_list_gchar, NULL);
		g_slist_free(prog->presenters);
	}
	if(prog->commentators != NULL) {
		g_slist_foreach(prog->commentators, free_list_gchar, NULL);
		g_slist_free(prog->commentators);
	}
	if(prog->guests != NULL) {
		g_slist_foreach(prog->guests, free_list_gchar, NULL);
		g_slist_free(prog->guests);
	}
	if(prog->favourites != NULL)
		g_slist_free(prog->favourites);
	gtvg_program_init(prog);
}
