
/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */

/*
 * callbacks.c
 * Copyright (C) Niklas Knutsson 2007 <nq@altern.org>
 * 
 * callbacks.c is free software.
 * 
 * You may redistribute it and/or modify it under the terms of the
 * GNU General Public License, as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option)
 * any later version.
 * 
 * callbacks.c is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with callbacks.c.  If not, write to:
 * 	The Free Software Foundation, Inc.,
 * 	51 Franklin Street, Fifth Floor
 * 	Boston, MA  02110-1301, USA.
 */

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <sys/stat.h>
#include <string.h>
#include <stdio.h>
#include <unistd.h>
#ifndef __USE_XOPEN
#define __USE_XOPEN
#include <time.h>
#undef __USE_XOPEN
#else
#include <time.h>
#endif
#include <sys/wait.h>

#include <glib/gstdio.h>
#include <gtk/gtk.h>
#include <glade/glade.h>
#include <libnotify/notify.h>
#ifdef HAVE_LIBGNOME
#include <libgnome/libgnome.h>
#endif
#include <dbus/dbus-glib.h>

#include <libxml/parser.h>

#include "callbacks.h"
#include "session.h"

extern GladeXML *gxml;
extern GConfClient *client;

extern GtkListStore *programList_store;
extern GtkListStore *channelsList_store;
extern GtkListStore *favouritesList_store;
extern GtkListStore *categoriesList_store;
extern GtkListStore *blacklist_store;
extern GtkListStore *dayCombo_store;
extern GtkListStore *favouriteDayCombo_store;
extern GtkListStore *favouriteChannelCombo_store;
extern GtkWidget *getCategoryDialog(void);
extern GtkWidget *getConfigurationDialog(void);
extern GtkWidget *getRecordScheduleDialog(void);
extern GtkWidget *getFavouriteDialog(void);
extern GtkStatusIcon *status_icon;
extern GSList *favourites;
extern GSList *blacklist;
extern GSList *favourite_schedules;
extern GSList *record_schedules;
extern GSList *disabled_record_schedules;
extern GSList *notifying_favscheds;
extern GSList *gridprog_items;
extern GtkWidget *window;
extern gboolean reminders_enabled;
extern gboolean reminder_details;
extern gint reminder_time;
extern gint reminder_duration;
extern GtkTreeIter *first_nonpast_iter;
extern time_t xml_load_time;
extern time_t current_day;
extern time_t first_day;
extern time_t last_day;
extern gboolean all_days;
extern time_t tomorrow_time;
extern void updateDays(void);
extern xmlDocPtr doc;
gboolean update_in_progress = FALSE;
extern gboolean loading_xmltv;
gboolean xmtlv_new_configuration;
extern void updateProgramList(void);
extern void updateProgramList_sub(void);
extern void updateProgramGrid(gboolean update_channels);
extern void updateProgramGrid_sub(gboolean update_channels);
extern void updateCategoryList(struct GtvgCategory *selcat);
extern void loadXMLTV(gboolean init_run);
extern gchar *createDescription(struct GtvgProgram *prog, gboolean for_reminder, GtkTextBuffer * tb);
extern void removeReminders(struct GtvgFavourite *fav);
extern void markFavourites(void);
extern GHashTable *channel_hash;
extern GSList *programs;
extern GSList *channels;
extern GSList *categories;
extern GSList *original_categories;
extern gint channels_compare_func(gconstpointer a, gconstpointer b);
extern gboolean programInFilter(struct GtvgProgram *prog);
extern gboolean programInChannels(struct GtvgProgram *prog);
extern gboolean programInCategories(struct GtvgProgram *prog);
extern void updateReminders(struct GtvgFavourite *onlyfav, struct GtvgProgram *onlyprog);
extern void updateChannelList(void);
extern gboolean channels_moved;
extern GtkWidget *searchEntry;
extern GtkWidget *searchButton;
extern GtkWidget *clearSearchButton;
extern GSList *status_list;
gsize tooltip_length = 1000;
gboolean on_notification_timeout(gpointer user_data);
extern struct GtvgProgram *selected_gridprog;
extern gboolean pending_grid_updates;
extern gboolean pending_grid_update_channels;
extern gboolean pending_gridtime_updates;
extern gboolean pending_list_updates;
extern void checkEnableClearFilters(void);
extern void updateGridTime(gboolean force, gboolean move_to_current);
extern gboolean searchNoCase(gchar * str, gchar * lower, gchar * upper);
extern time_t prevtime;
struct tm selected_favourite_date;
extern gboolean notify_sound;
extern gboolean notify_sound_regardless;
extern gchar *notify_sound_file;
extern struct record_schedule *wakeup_recsched;
extern gboolean wakeup_enabled;
extern gboolean recordings_enabled;
extern gboolean ask_record;
extern gchar *start_recording_command;
extern gchar *stop_recording_command;
extern gint start_margin;
extern gint stop_margin;
extern guint gconf_notify_id;
extern time_t current_record_stop_time;
extern gchar *current_record_stop_command;
extern gchar *current_record_title;
extern gchar *current_record_channel;
extern struct GtvgProgram *current_record_prog;
extern time_t current_record_program_stop;
extern gboolean grid_at_current;
extern gdouble text_margin;
extern gdouble scroll_x;
extern GSList *current_gridprogs;
gchar *current_reccom_file;
extern gboolean rec_timeout_running;
extern guint rec_timeout_id;
extern void updateRecordScheduleList(void);
extern GdkColor future_bg_color;
extern GdkColor past_bg_color;
extern GdkColor default_bg_color;
extern GdkColor selected_bg_color;
extern GdkColor favourite_bg_color;
extern GdkColor current_bg_color;
extern GdkColor default_border_color;
extern GdkColor selected_border_color;
extern GdkColor favourite_border_color;
extern GdkColor current_border_color;
extern GdkColor default_text_color;
extern GdkColor selected_text_color;
extern GdkColor favourite_text_color;
extern GdkColor current_text_color;
extern gint categories_compare_func(gconstpointer a, gconstpointer b);
extern GdkColor *favBgColor(struct GtvgProgram *prog);
extern GdkColor *defBgColor(struct GtvgProgram *prog);
extern GdkColor *favTextColor(struct GtvgProgram *prog);
extern GdkColor *defTextColor(struct GtvgProgram *prog);
extern gint day_starts_at;
gint selected_day_starts_at;
extern gint future_tooltip_items;
extern gint current_tooltip_items;
extern DBusGConnection *connection;
extern DBusGProxy *proxy;
extern gboolean in_sleep_mode;
extern gboolean can_suspend;

void free_list_gchar(gpointer data, gpointer user_data)
{
	g_free((gchar *) data);
}

void suspendComputer(void)
{
	GError *error = NULL;

	if(proxy != NULL && !dbus_g_proxy_call(proxy, "Suspend", &error, G_TYPE_INVALID, G_TYPE_INVALID)) {
		GtkWidget *dialog = gtk_message_dialog_new(GTK_WINDOW(window), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, _("Failed to suspend the computer: %s"), error->message);

		gtk_dialog_run(GTK_DIALOG(dialog));
		gtk_widget_destroy(dialog);
		g_error_free(error);
	}
}

void enterSleepMode(void)
{
	in_sleep_mode = TRUE;
	if(current_record_program_stop <= 0 && (record_schedules == NULL || ((struct record_schedule *) record_schedules->data)->start_time > time(NULL) + 600)) {
		suspendComputer();
	}
}

void on_sleepModeMenuItem_toggled(GtkCheckMenuItem * w, gpointer user_data)
{
	if(gtk_check_menu_item_get_active(w)) {
		if(!wakeup_enabled) {
			GtkWidget *dialog = gtk_message_dialog_new(GTK_WINDOW(window), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, _("Wakeup is not enabled. The option to wakeup the computer before start of recording must be enabled in order to let you enter sleep mode. (This require that nvram-wakeup is installed and functioning properly.)\n\nDo you want to enable wakeup and enter sleep mode now?"));

			if(gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_YES) {
				wakeup_enabled = TRUE;
				updateWakeupTime();
				gconf_client_set_bool(client, "/apps/gtvg/wakeup_enabled", wakeup_enabled, NULL);
				gtk_widget_destroy(dialog);
				enterSleepMode();
			} else {
				gtk_widget_destroy(dialog);
			}
		} else {
			enterSleepMode();
		}
	} else {
		in_sleep_mode = FALSE;
	}
	g_signal_handlers_block_matched((gpointer) glade_xml_get_widget(gxml, "sleepModeMenuItem"), G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_sleepModeMenuItem_toggled, NULL);
	g_signal_handlers_block_matched((gpointer) glade_xml_get_widget(gxml, "sleepModeStatusMenuItem"), G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_sleepModeMenuItem_toggled, NULL);
	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(glade_xml_get_widget(gxml, "sleepModeMenuItem")), in_sleep_mode);
	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(glade_xml_get_widget(gxml, "sleepModeStatusMenuItem")), in_sleep_mode);
	g_signal_handlers_unblock_matched((gpointer) glade_xml_get_widget(gxml, "sleepModeMenuItem"), G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_sleepModeMenuItem_toggled, NULL);
	g_signal_handlers_unblock_matched((gpointer) glade_xml_get_widget(gxml, "sleepModeStatusMenuItem"), G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_sleepModeMenuItem_toggled, NULL);
}

struct GtvgProgram *selectedProgram_in_nb(gint index)
{
	if(index == 1) {
		return selected_gridprog;
	} else {
		GtkTreeSelection *selection;
		GtkTreeIter iter;
		GtkTreeModel *model;
		struct GtvgProgram *prog;

		selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "programList_view")));
		if(gtk_tree_selection_get_selected(selection, &model, &iter)) {
			gtk_tree_model_get(model, &iter, OBJECT_COLUMN, &prog, -1);
			return prog;
		}
	}
	return NULL;
}

struct GtvgProgram *selectedProgram(void)
{
	return selectedProgram_in_nb(gtk_notebook_get_current_page(GTK_NOTEBOOK(glade_xml_get_widget(gxml, "viewPages"))));
}

void programSelected(struct GtvgProgram *prog)
{
	if(prog != NULL) {
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "addToBlacklistToolbutton"), TRUE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "addToBlacklistMenuItem"), TRUE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "findProgramProgramsMenuItem"), TRUE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "findProgramToolbutton"), TRUE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "findProgramMenuItem"), TRUE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "addFavouriteMenuItem"), TRUE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "addFavouriteChannelMenuItem"), TRUE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "addFavouriteTimeMenuItem"), TRUE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "addFavouriteDayAndTimeMenuItem"), TRUE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "addFavouriteOnlyMenuItem"), TRUE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "addFavouriteProgramsMenuItem"), TRUE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "addFavouriteChannelProgramsMenuItem"), TRUE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "addFavouriteTimeProgramsMenuItem"), TRUE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "addFavouriteDayAndTimeProgramsMenuItem"), TRUE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "addFavouriteOnlyProgramsMenuItem"), TRUE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "addFavouriteToolMenuItem"), TRUE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "addFavouriteChannelToolMenuItem"), TRUE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "addFavouriteTimeToolMenuItem"), TRUE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "addFavouriteDayAndTimeToolMenuItem"), TRUE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "addFavouriteOnlyToolMenuItem"), TRUE);
	} else {
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "addToBlacklistToolbutton"), FALSE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "addToBlacklistMenuItem"), FALSE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "findProgramProgramsMenuItem"), FALSE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "findProgramToolbutton"), FALSE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "findProgramMenuItem"), FALSE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "addFavouriteMenuItem"), FALSE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "addFavouriteChannelMenuItem"), FALSE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "addFavouriteTimeMenuItem"), FALSE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "addFavouriteDayAndTimeMenuItem"), FALSE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "addFavouriteOnlyMenuItem"), FALSE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "addFavouriteProgramsMenuItem"), FALSE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "addFavouriteChannelProgramsMenuItem"), FALSE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "addFavouriteTimeProgramsMenuItem"), FALSE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "addFavouriteDayAndTimeProgramsMenuItem"), FALSE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "addFavouriteOnlyProgramsMenuItem"), FALSE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "addFavouriteToolMenuItem"), FALSE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "addFavouriteChannelToolMenuItem"), FALSE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "addFavouriteTimeToolMenuItem"), FALSE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "addFavouriteDayAndTimeToolMenuItem"), FALSE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "addFavouriteOnlyToolMenuItem"), FALSE);
	}
	if(prog != NULL && prog->favourites != NULL) {
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "removeFavouriteMenuItem"), TRUE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "removeFavouriteProgramsMenuItem"), TRUE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "removeFavouriteToolbutton"), TRUE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "findFavouriteProgramsMenuItem"), TRUE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "findFavouriteMenuItem"), TRUE);
	} else {
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "removeFavouriteMenuItem"), FALSE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "removeFavouriteProgramsMenuItem"), FALSE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "removeFavouriteToolbutton"), FALSE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "findFavouriteProgramsMenuItem"), FALSE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "findFavouriteMenuItem"), FALSE);
	}
}

void on_programCanvas_hadj_changed(GtkAdjustment * adj, gpointer user_data)
{
	gtk_adjustment_set_value(gtk_scrolled_window_get_hadjustment(GTK_SCROLLED_WINDOW(glade_xml_get_widget(gxml, "timeCanvas_scrolled"))), gtk_adjustment_get_value(adj));
	if(grid_at_current && gtk_adjustment_get_value(adj) < scroll_x) {
		GSList *list, *list2;
		struct GtvgProgram *prog;
		gdouble x1, x2;

		list = current_gridprogs;
		while(list != NULL) {
			list2 = (GSList *) list->data;
			if(list2 != NULL) {
				prog = (struct GtvgProgram *) list2->data;
				if(prog->canvas_text != NULL) {
					g_object_get(G_OBJECT(prog->canvas_rect), "x1", &x1, "x2", &x2, NULL);
					g_object_set(G_OBJECT(prog->canvas_text), "x", x1 + text_margin, "clip-width", x2 - x1 - (text_margin * 2), NULL);
				}
			}
			list = g_slist_next(list);
		}
		grid_at_current = FALSE;
	}
}
void on_programCanvas_vadj_changed(GtkAdjustment * adj, gpointer user_data)
{
	gtk_adjustment_set_value(gtk_scrolled_window_get_vadjustment(GTK_SCROLLED_WINDOW(glade_xml_get_widget(gxml, "channelsCanvas_scrolled"))), gtk_adjustment_get_value(adj));
}

void on_programCanvas_style_set(GtkWidget * w, GtkStyle * previous_style, gpointer user_data)
{
	updateProgramGrid(TRUE);
}

gboolean on_gridItem_event(GnomeCanvasItem * item, GdkEvent * event, gpointer user_data)
{
	struct GtvgProgram *prog = (struct GtvgProgram *) user_data;
	GtkTextBuffer *tb;
	time_t curtime;

	if(event->type == GDK_BUTTON_PRESS && event->button.type == GDK_BUTTON_PRESS && prog->canvas_text != NULL) {
		tb = gtk_text_view_get_buffer(GTK_TEXT_VIEW(glade_xml_get_widget(gxml, "gridDescriptionView")));
		curtime = time(NULL);
		if(selected_gridprog != NULL) {
			g_object_set(G_OBJECT(selected_gridprog->canvas_rect), "fill-color-gdk", selected_gridprog->canvas_text == NULL ? NULL : (selected_gridprog->start <= curtime && selected_gridprog->stop > curtime ? &current_bg_color : (selected_gridprog->favourites != NULL ? favBgColor(selected_gridprog) : defBgColor(selected_gridprog))), "outline-color-gdk", selected_gridprog->start <= curtime && selected_gridprog->stop > curtime ? &current_border_color : (selected_gridprog->favourites != NULL ? &favourite_border_color : &default_border_color), NULL);
			if(selected_gridprog->canvas_text != NULL) {
				g_object_set(G_OBJECT(selected_gridprog->canvas_text), "fill-color-gdk", selected_gridprog->start <= curtime && selected_gridprog->stop > curtime ? &current_text_color : (selected_gridprog->favourites != NULL ? favTextColor(selected_gridprog) : defTextColor(selected_gridprog)), NULL);
			}
		}
		selected_gridprog = prog;
		g_object_set(G_OBJECT(prog->canvas_rect), "fill-color-gdk", &selected_bg_color, "outline-color-gdk", &selected_border_color, NULL);
		g_object_set(G_OBJECT(prog->canvas_text), "fill-color-gdk", &selected_text_color, NULL);
		createDescription(prog, FALSE, tb);
		programSelected(prog);
		if(event->button.button == 3) {
			gtk_menu_popup(GTK_MENU(glade_xml_get_widget(gxml, "programList_menu")), NULL, NULL, NULL, NULL, event->button.button, gdk_event_get_time(event));
		}
		return TRUE;
	}
	return FALSE;
}

void currentDayChanged(void)
{
	gchar *gstr, *time_str;
	struct tm curday_tm;

	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "gridForwardButton"), first_day != 0 && last_day > current_day);
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "gridBackButton"), first_day != 0 && first_day < current_day);
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "gridHomeButton"), current_day != tomorrow_time - 86400);
	time_str = g_strnfill(80, '\0');
	localtime_r(&current_day, &curday_tm);
	if(current_day == tomorrow_time - 172800) {
		//Yesterday [date]
		strftime(time_str, 80, _("Yesterday\n%F"), &curday_tm);
	} else if(current_day == tomorrow_time - 86400) {
		//Today [date]
		strftime(time_str, 80, _("Today\n%F"), &curday_tm);
	} else if(current_day == tomorrow_time) {
		//Tomorrow [date]
		strftime(time_str, 80, _("Tomorrow\n%F"), &curday_tm);
	} else {
		//Day of week [date]
		strftime(time_str, 80, _("%A\n%F"), &curday_tm);
	}
	gstr = g_strdup_printf("<big>%s</big>", time_str);
	gtk_label_set_markup(GTK_LABEL(glade_xml_get_widget(gxml, "gridDateLabel")), gstr);
	g_free(gstr);
	g_free(time_str);
	updateProgramGrid(FALSE);
	if(!all_days) {
		GtkTreeIter iter;
		long daytime;
		gboolean b = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(dayCombo_store), &iter);

		while(b) {
			gtk_tree_model_get(GTK_TREE_MODEL(dayCombo_store), &iter, 1, &daytime, -1);
			if(daytime == current_day) {
				g_signal_handlers_block_matched((gpointer) glade_xml_get_widget(gxml, "dayCombo"), G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_dayCombo_changed, NULL);
				gtk_combo_box_set_active_iter(GTK_COMBO_BOX(glade_xml_get_widget(gxml, "dayCombo")), &iter);
				g_signal_handlers_unblock_matched((gpointer) glade_xml_get_widget(gxml, "dayCombo"), G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_dayCombo_changed, NULL);
				break;
			}
			b = gtk_tree_model_iter_next(GTK_TREE_MODEL(dayCombo_store), &iter);
		}
		updateProgramList();
	}
}

void on_gridForwardButton_clicked(GtkButton * w, gpointer user_data)
{
	current_day += 86400;
	currentDayChanged();
}

void on_gridBackButton_clicked(GtkButton * w, gpointer user_data)
{
	current_day -= 86400;
	currentDayChanged();
}

void on_gridHomeButton_clicked(GtkButton * w, gpointer user_data)
{
	current_day = tomorrow_time - 86400;
	currentDayChanged();
}

void on_viewListMenuItem_toggled(GtkCheckMenuItem * w, gpointer user_data)
{
	if(gtk_check_menu_item_get_active(w)) {
		gtk_notebook_set_current_page(GTK_NOTEBOOK(glade_xml_get_widget(gxml, "viewPages")), 0);
	} else {
		gtk_notebook_set_current_page(GTK_NOTEBOOK(glade_xml_get_widget(gxml, "viewPages")), 1);
	}
}

void on_viewListToolbutton_toggled(GtkToggleToolButton * w, gpointer user_data)
{
	if(gtk_toggle_tool_button_get_active(w)) {
		gtk_notebook_set_current_page(GTK_NOTEBOOK(glade_xml_get_widget(gxml, "viewPages")), 0);
	} else {
		gtk_notebook_set_current_page(GTK_NOTEBOOK(glade_xml_get_widget(gxml, "viewPages")), 1);
	}
}

void on_viewPages_switch_page(GtkNotebook * notebook, GtkNotebookPage * page, guint page_num, gpointer user_data)
{
	g_signal_handlers_block_matched((gpointer) glade_xml_get_widget(gxml, "viewListToolbutton"), G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_viewListToolbutton_toggled, NULL);
	g_signal_handlers_block_matched((gpointer) glade_xml_get_widget(gxml, "viewListMenuItem"), G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_viewListMenuItem_toggled, NULL);
	if(page_num == 1) {
		gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(glade_xml_get_widget(gxml, "viewListMenuItem")), FALSE);
		gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(glade_xml_get_widget(gxml, "viewGridMenuItem")), TRUE);
		gtk_toggle_tool_button_set_active(GTK_TOGGLE_TOOL_BUTTON(glade_xml_get_widget(gxml, "viewListToolbutton")), FALSE);
		gtk_toggle_tool_button_set_active(GTK_TOGGLE_TOOL_BUTTON(glade_xml_get_widget(gxml, "viewGridToolbutton")), TRUE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "clearFiltersToolbutton"), FALSE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "clearFiltersMenuItem"), FALSE);
		if(pending_grid_updates)
			updateProgramGrid_sub(pending_grid_update_channels);
		else if(pending_gridtime_updates)
			updateGridTime(TRUE, TRUE);
	} else {
		gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(glade_xml_get_widget(gxml, "viewListMenuItem")), TRUE);
		gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(glade_xml_get_widget(gxml, "viewGridMenuItem")), FALSE);
		gtk_toggle_tool_button_set_active(GTK_TOGGLE_TOOL_BUTTON(glade_xml_get_widget(gxml, "viewListToolbutton")), TRUE);
		gtk_toggle_tool_button_set_active(GTK_TOGGLE_TOOL_BUTTON(glade_xml_get_widget(gxml, "viewGridToolbutton")), FALSE);
		checkEnableClearFilters();
		if(pending_list_updates)
			updateProgramList_sub();
	}
	programSelected(selectedProgram_in_nb(page_num));
	g_signal_handlers_unblock_matched((gpointer) glade_xml_get_widget(gxml, "viewListMenuItem"), G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_viewListMenuItem_toggled, NULL);
	g_signal_handlers_unblock_matched((gpointer) glade_xml_get_widget(gxml, "viewListToolbutton"), G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_viewListToolbutton_toggled, NULL);
	gconf_client_set_bool(client, "/apps/gtvg/show_grid", page_num == 1, NULL);
}

gint gchar_compare_func(gconstpointer a, gconstpointer b)
{
	return strcmp((gchar *) a, (gchar *) b);
}

gint favsched_compare_func(gconstpointer a, gconstpointer b)
{
	struct favourite_schedule *favsched1 = (struct favourite_schedule *) a;
	struct favourite_schedule *favsched2 = (struct favourite_schedule *) b;
	gint start1 = favsched1->prog->start - (favsched1->fav->reminder > 0 ? favsched1->fav->reminder_time : reminder_time) * 60;
	gint start2 = favsched2->prog->start - (favsched2->fav->reminder > 0 ? favsched2->fav->reminder_time : reminder_time) * 60;

	if(start1 > start2)
		return 1;
	if(start1 < start2)
		return -1;
	return 0;
}

gint recsched_compare_func(gconstpointer a, gconstpointer b)
{
	struct record_schedule *recsched1 = (struct record_schedule *) a;
	struct record_schedule *recsched2 = (struct record_schedule *) b;

	if(recsched1->start_time > recsched2->start_time)
		return 1;
	if(recsched1->start_time < recsched2->start_time)
		return -1;
	return 0;
}

gboolean favouriteIncludesProgram(struct GtvgFavourite * fav, struct GtvgProgram * prog, gchar * lower, gchar * upper)
{
	if(fav->time > 0) {
		if(prog->start != fav->time)
			return FALSE;
	}
	if(fav->dayofweek >= 0) {
		if(prog->start_tm.tm_wday != fav->dayofweek)
			return FALSE;
	}
	if(fav->timeofday >= 0) {
		if((prog->start_tm.tm_hour * 3600 + prog->start_tm.tm_min * 60 + prog->start_tm.tm_sec) != fav->timeofday)
			return FALSE;
	}
	if(fav->channel != NULL) {
		if(strcmp(prog->chid, fav->channel) != 0)
			return FALSE;
	}
	if(fav->partial_title && lower != NULL)
		return searchNoCase(prog->title, lower, upper);
	if(strcmp(prog->title, fav->title) == 0)
		return TRUE;
	return FALSE;
}

gint favourite_strict_compare_func(gconstpointer a, gconstpointer b)
{
	struct GtvgFavourite *favlist, *favuser;
	int cmp;

	favlist = (struct GtvgFavourite *) a;
	favuser = (struct GtvgFavourite *) b;
	cmp = strcmp(favlist->title, favuser->title);
	if(cmp == 0 && (favlist->partial_title == favuser->partial_title) && (favlist->reminder == favuser->reminder) && (favlist->reminder_time == favuser->reminder_time) && (favlist->reminder_duration == favuser->reminder_duration) && (favlist->time == favuser->time) && (favlist->dayofweek == favuser->dayofweek) && (favlist->timeofday == favuser->timeofday) && (favlist->channel == favuser->channel || (favlist->channel != NULL && favuser->channel != NULL && strcmp(favlist->channel, favuser->channel) == 0))) {
		return 0;
	}
	if(cmp == 0)
		return 1;
	return cmp;
}

gint favourite_sort_compare_func(gconstpointer a, gconstpointer b)
{
	struct GtvgFavourite *favlist, *favuser;
	int cmp;

	favlist = (struct GtvgFavourite *) a;
	favuser = (struct GtvgFavourite *) b;
	cmp = strcmp(favlist->title, favuser->title);
	return cmp;
}

void free_favsched(struct favourite_schedule *favsched)
{
	if(favsched->notification != NULL) {
		g_source_remove_by_user_data(favsched);
		notify_notification_close(favsched->notification, NULL);
		g_object_unref(favsched->notification);
	}
	g_slice_free(struct favourite_schedule, favsched);
}

void free_recsched(struct record_schedule *recsched)
{
	g_slice_free(struct record_schedule, recsched);
}

void free_list_treepath(gpointer data, gpointer user_data)
{
	gtk_tree_path_free((GtkTreePath *) data);
}

void updateFavourites(void)
{
	GtkTreeIter iter;
	struct GtvgFavourite *fav;
	gchar *gstr, *time_str, *ch_name = NULL, *title_str;
	struct GtvgChannel *ch;
	GSList *list = favourites;
	struct tm timetp;

	time_str = g_strnfill(80, '\0');
	gtk_list_store_clear(favouritesList_store);
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "removeFavouriteButton"), FALSE);
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "editFavouriteButton"), FALSE);
	while(list) {
		gtk_list_store_append(favouritesList_store, &iter);
		fav = (struct GtvgFavourite *) list->data;
		if(fav->channel != NULL) {
			ch = g_hash_table_lookup(channel_hash, fav->channel);
			if(ch == NULL)
				ch_name = fav->channel;
			else
				ch_name = ch->name;
		}
		if(fav->partial_title) {
			title_str = g_strdup_printf("*%s*", fav->title);
		} else {
			title_str = fav->title;
		}
		if(fav->time > 0) {
			localtime_r(&fav->time, &timetp);
			//time and date (ex. "7 May 20:00")
			strftime(time_str, 80, _("%e %b %R"), &timetp);
			if(fav->channel != NULL) {
				//[title] (on [channel], [time and date])                       
				gstr = g_strdup_printf(_("%s (on %s, %s)"), title_str, ch_name, time_str);
			} else {
				//[title] ([time and date])                     
				gstr = g_strdup_printf(_("%s (%s)"), title_str, time_str);
			}
		} else if(fav->dayofweek >= 0) {
			if(fav->timeofday >= 0) {
				timetp.tm_hour = fav->timeofday / 3600;
				timetp.tm_min = (fav->timeofday % 3600) / 60;
				timetp.tm_wday = fav->dayofweek;
				//day of week and time (ex. "Mon 20:00")
				strftime(time_str, 80, _("%a %R"), &timetp);
			} else {
				timetp.tm_wday = fav->dayofweek;
				//day of week
				strftime(time_str, 80, _("%A"), &timetp);
			}
			if(fav->channel != NULL) {
				//[title] (on [channel], [day of week and time])
				gstr = g_strdup_printf(_("%s (on %s, %s)"), title_str, ch_name, time_str);
			} else {
				//[title] ([day of week and time])
				gstr = g_strdup_printf(_("%s (%s)"), title_str, time_str);
			}
		} else if(fav->timeofday >= 0) {
			timetp.tm_hour = fav->timeofday / 3600;
			timetp.tm_min = (fav->timeofday % 3600) / 60;
			//time of day (ex. "20:00")
			strftime(time_str, 80, _("%R"), &timetp);
			if(fav->channel != NULL) {
				//[title] (on [channel], [time of day])
				gstr = g_strdup_printf(_("%s (on %s, %s)"), title_str, ch_name, time_str);
			} else {
				//[title] ([time of day])
				gstr = g_strdup_printf(_("%s (%s)"), title_str, time_str);
			}
		} else if(fav->channel != NULL) {
			//[title] (on [channel])
			gstr = g_strdup_printf(_("%s (on %s)"), title_str, ch_name);
		} else {
			gstr = title_str;
		}
		gtk_list_store_set(favouritesList_store, &iter, FAVOURITES_DISPLAY_COLUMN, gstr, FAVOURITES_TITLE_COLUMN, fav->title, FAVOURITES_OBJECT_COLUMN, fav, -1);
		if(gstr != title_str)
			g_free(gstr);
		if(title_str != fav->title)
			g_free(title_str);
		list = g_slist_next(list);
	}
	g_free(time_str);
}

void updateBlacklist(void)
{
	GtkTreeIter iter;
	GSList *list = blacklist;

	gtk_list_store_clear(blacklist_store);
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "removeFromBlacklistButton"), FALSE);
	while(list) {
		gtk_list_store_append(blacklist_store, &iter);
		gtk_list_store_set(blacklist_store, &iter, 0, list->data, -1);
		list = g_slist_next(list);
	}
}

static const char *terminals[] = {
	"gnome-terminal",
	"xterm",
	"rxvt",
	"xfce4-terminal",
	"eterm",
	"aterm",
	"multi-gnome-terminal",
	"Terminal",
	"konsole",
	"greent",
	"tilda",
	"roxterm",
	"wterm",
	"mrxvt",
	"materm",
	"urxvt",
	"kuake",
	"dzt",
	"sakura",
	"hanterm",
	"multixterm",
	"3dterm",
	"mpterm",
	"yakuake",
	"gemvt",
	"fxvt",
	NULL
};

gchar *terminalCommand(void)
{
	gchar *terminal_str;
	gchar *gstr;
	size_t i = 0;

	terminal_str = gconf_client_get_string(client, "/desktop/gnome/applications/terminal/exec", NULL);
	if(terminal_str != NULL) {
		gstr = g_find_program_in_path(terminal_str);
		if(gstr == NULL) {
			g_free(terminal_str);
			terminal_str = NULL;
		} else {
			g_free(gstr);
		}
	}
	while(terminal_str == NULL && terminals[i] != NULL) {
		gstr = g_find_program_in_path(terminals[i]);
		if(gstr == NULL) {
			terminal_str = NULL;
		} else {
			g_free(gstr);
			terminal_str = g_strdup(terminals[i]);
		}
		i++;
	}
	return terminal_str;
}

gboolean configureXMLTV(const gchar * grabber_str)
{
	gchar *terminal_str, *command_str;
	GtkWidget *dialog;
	GError *error = NULL;

	terminal_str = terminalCommand();
	if(terminal_str == NULL) {
		dialog = gtk_message_dialog_new(GTK_WINDOW(window), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, _("No terminal application found. Please run %s --configure manually."), grabber_str);
		gtk_dialog_run(GTK_DIALOG(dialog));
		gtk_widget_destroy(dialog);
		return FALSE;
	}
	command_str = g_strconcat(terminal_str, " -e \"", grabber_str, " --configure\"", NULL);
	g_free(terminal_str);
	if(!g_spawn_command_line_sync(command_str, NULL, NULL, NULL, &error)) {
		dialog = gtk_message_dialog_new(GTK_WINDOW(window), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, _("Error configuring XMLTV (using %s): %s"), command_str, error->message);
		gtk_dialog_run(GTK_DIALOG(dialog));
		gtk_widget_destroy(dialog);
	}
	g_free(command_str);
	return TRUE;
}

void on_configureXMLTVButton_clicked(GtkButton * w, gpointer user_data)
{
	gchar *gstr;
	GtkTreeIter iter;

	if(gtk_combo_box_get_active_iter(GTK_COMBO_BOX(glade_xml_get_widget(gxml, "grabCommandCombo")), &iter)) {
		gtk_tree_model_get(gtk_combo_box_get_model(GTK_COMBO_BOX(glade_xml_get_widget(gxml, "grabCommandCombo"))), &iter, 1, &gstr, -1);
		if(gstr) {
			if(configureXMLTV(gstr)) {
				xmtlv_new_configuration = TRUE;
			}
			g_free(gstr);
		}
	}
}

void updateXMLTVFile(gboolean reload)
{
	GConfValue *gvalue_command, *gvalue_file;
	int days;
	gchar *grab_command;
	const gchar *str_command;
	gboolean show_progress;
	GtkWidget *progressDialog = NULL;
	GtkWidget *dialog;
	GError *error = NULL;
	size_t i = 0;
	gboolean b, b_custom;
	GPid child_pid;
	gchar **argv;
	int status, waitret;
	gint tmpfd = 0;
	gchar *tmpfile = NULL;
	gchar *contents;
	xmlDocPtr doc;
	xmlNodePtr cur;
	gboolean use_slow = FALSE;

	update_in_progress = TRUE;
	show_progress = GTK_WIDGET_VISIBLE(window);
	if(show_progress) {
		progressDialog = glade_xml_get_widget(gxml, "progressDialog");
		gtk_label_set_text(GTK_LABEL(glade_xml_get_widget(gxml, "progressLabel")), _("Downloading TV listings..."));
		//gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(glade_xml_get_widget(gxml, "loadingProgressBar")), 0.0);
		gtk_widget_show(progressDialog);
		while(gtk_events_pending())
			gtk_main_iteration();
	}
	use_slow = gconf_client_get_bool(client, "/apps/gtvg/grab_with_slow", NULL);
	gvalue_file = gconf_client_get(client, "/apps/gtvg/xmltv_file", NULL);
	gvalue_command = gconf_client_get(client, "/apps/gtvg/grabber_command", NULL);
	days = gconf_client_get_int(client, "/apps/gtvg/days_to_grab", NULL);
	if(days <= 0)
		days = 5;
	if(gvalue_file == NULL || gvalue_command == NULL) {
		if(gvalue_command == NULL) {
			dialog = gtk_message_dialog_new(GTK_WINDOW(window), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, _("No grab command set."));
		} else {
			dialog = gtk_message_dialog_new(GTK_WINDOW(window), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, _("No XMLTV file specified."));
		}
		gtk_widget_hide(progressDialog);
		gtk_dialog_run(GTK_DIALOG(dialog));
		gtk_widget_destroy(dialog);
		update_in_progress = FALSE;
		return;
	}
	b_custom = TRUE;
	str_command = gconf_value_get_string(gvalue_command);
	while(grabbers[i] != NULL) {
		if(strcmp(grabbers[i], str_command) == 0) {
			if(use_slow)
				use_slow = grabber_supports_slow[i];
			b_custom = FALSE;
			break;
		}
		i++;
	}
	if(!b_custom) {
		tmpfd = g_file_open_tmp("gtvg-xmltv-XXXXXX", &tmpfile, NULL);
		if(tmpfd >= 0) {
			close(tmpfd);
			if(use_slow)
				grab_command = g_strdup_printf("%s --slow --days %i --offset %i --output \"%s\"", str_command, days, gconf_client_get_int(client, "/apps/gtvg/grab_offset", NULL), tmpfile);
			else
				grab_command = g_strdup_printf("%s --days %i --offset %i --output \"%s\"", str_command, days, gconf_client_get_int(client, "/apps/gtvg/grab_offset", NULL), tmpfile);
		} else {
			if(tmpfile != NULL) {
				g_unlink(tmpfile);
				g_free(tmpfile);
				tmpfile = NULL;
			}
			if(use_slow)
				grab_command = g_strdup_printf("%s --slow --days %i --offset %i --output \"%s\"", str_command, days, gconf_client_get_int(client, "/apps/gtvg/grab_offset", NULL), gconf_value_get_string(gvalue_file));
			else
				grab_command = g_strdup_printf("%s --days %i --offset %i --output \"%s\"", str_command, days, gconf_client_get_int(client, "/apps/gtvg/grab_offset", NULL), gconf_value_get_string(gvalue_file));
		}
	} else {
		grab_command = g_strdup(str_command);
	}
	b = TRUE;
	g_shell_parse_argv(grab_command, NULL, &argv, NULL);
	if(!g_spawn_async(NULL, argv, NULL, (GSpawnFlags) G_SPAWN_DO_NOT_REAP_CHILD | G_SPAWN_SEARCH_PATH, NULL, NULL, &child_pid, &error)) {
		dialog = gtk_message_dialog_new(GTK_WINDOW(window), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, _("Error updating XMLTV file (using %s): %s"), grab_command, error->message);
		if(show_progress)
			gtk_widget_hide(progressDialog);
		gtk_dialog_run(GTK_DIALOG(dialog));
		gtk_widget_destroy(dialog);
		b = FALSE;
	}
	if(b) {
		waitret = waitpid(child_pid, &status, WNOHANG | WUNTRACED);
		while(waitret >= 0) {
			if(waitret != 0 && WIFEXITED(status) != 0) {
				if(WEXITSTATUS(status) != EXIT_SUCCESS) {
					dialog = gtk_message_dialog_new(GTK_WINDOW(window), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, _("Failed to update XMLTV file (using %s)"), grab_command);
					if(show_progress)
						gtk_widget_hide(progressDialog);
					gtk_dialog_run(GTK_DIALOG(dialog));
					gtk_widget_destroy(dialog);
					b = FALSE;
				}
				break;
			}
			if(show_progress) {
				gtk_progress_bar_pulse(GTK_PROGRESS_BAR(glade_xml_get_widget(gxml, "loadingProgressBar")));
				while(gtk_events_pending())
					gtk_main_iteration();
			}
			usleep(100000);
			waitret = waitpid(child_pid, &status, WNOHANG | WUNTRACED);
		}
		if(b && waitret < 0) {
			dialog = gtk_message_dialog_new(GTK_WINDOW(window), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, _("Failed to update XMLTV file (using %s)"), grab_command);
			if(show_progress)
				gtk_widget_hide(progressDialog);
			gtk_dialog_run(GTK_DIALOG(dialog));
			gtk_widget_destroy(dialog);
			b = FALSE;
		}
		g_spawn_close_pid(child_pid);
	}
	if(b) {
		if(tmpfile != NULL) {
			doc = xmlParseFile(tmpfile);
			cur = xmlDocGetRootElement(doc);
			if(cur == NULL) {
				dialog = gtk_message_dialog_new(GTK_WINDOW(window), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, _("Invalid XMLTV file"));
				gtk_dialog_run(GTK_DIALOG(dialog));
				gtk_widget_destroy(dialog);
				b = FALSE;
			}
			xmlFreeDoc(doc);
			if(b) {
				g_file_get_contents(tmpfile, &contents, NULL, NULL);
				if(!g_file_set_contents(gconf_value_get_string(gvalue_file), contents, -1, &error)) {
					dialog = gtk_message_dialog_new(GTK_WINDOW(window), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, _("Error when copying temporary XMLTV file to %s: %s"), gconf_value_get_string(gvalue_file), error->message);
					gtk_dialog_run(GTK_DIALOG(dialog));
					gtk_widget_destroy(dialog);
					b = FALSE;
				}
				if(contents != NULL)
					g_free(contents);
			}
		}
	}
	if(b) {
		if(reload)
			loadXMLTV(FALSE);
		if(show_progress)
			gtk_widget_hide(progressDialog);
	}
	if(tmpfile != NULL) {
		g_unlink(tmpfile);
		g_free(tmpfile);
	}
	gconf_value_free(gvalue_command);
	gconf_value_free(gvalue_file);
	g_free(grab_command);
	g_strfreev(argv);
	update_in_progress = FALSE;
	checkFavourites(NULL);
}

void on_reminderUntilEndButton_toggled(GtkToggleButton * w, gpointer user_data)
{
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "reminderDurationSpin"), !gtk_toggle_button_get_active(w));
}

void on_reminderSoundButton_toggled(GtkToggleButton * w, gpointer user_data)
{
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "reminderSoundBox"), gtk_toggle_button_get_active(w));
#ifndef HAVE_LIBGNOME
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "reminderSoundFileButton"), FALSE);
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "reminderSoundFileChooserButton"), FALSE);
#endif
}

void on_showRemindersButton_toggled(GtkToggleButton * w, gpointer user_data)
{
	//gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "remindersBox"), gtk_toggle_button_get_active(w));
}

void on_recordPresetsCombo_changed(GtkComboBox * w, gpointer user_data)
{
	gint i = gtk_combo_box_get_active(w);

	if(i != 0) {
		gtk_entry_set_text(GTK_ENTRY(glade_xml_get_widget(gxml, "startRecordCommandEntry")), record_preset_start[i - 1]);
		gtk_entry_set_text(GTK_ENTRY(glade_xml_get_widget(gxml, "stopRecordCommandEntry")), record_preset_stop[i - 1]);
		gtk_combo_box_set_active(w, 0);
	}
}

void on_recordingsPrioritiseButton_toggled(GtkToggleButton * w, gpointer user_data)
{
	GtkTreeIter iter;
	GtkTreeModel *model;
	GSList *list;
	struct GtvgFavourite *fav;
	struct record_schedule *recsched = NULL;
	GtkTreeSelection *treeselection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "recordScheduleList_view")));

	if(gtk_tree_selection_get_selected(treeselection, &model, &iter)) {
		gtk_tree_model_get(model, &iter, 4, &recsched, -1);
		if(recsched == NULL)
			return;
		if(gtk_toggle_button_get_active(w)) {
			list = recsched->prog->favourites;
			while(list != NULL) {
				fav = (struct GtvgFavourite *) list->data;
				if(fav->record > 0 || (fav->record < 0 && recordings_enabled)) {
					gtvg_favourite_prioritise_recording(fav, recsched->prog->channel->id, recsched->prog->start);
				}
				list = g_slist_next(list);
			}
		} else {
			list = recsched->prog->favourites;
			while(list != NULL) {
				fav = (struct GtvgFavourite *) list->data;
				if(fav->record > 0 || (fav->record < 0 && recordings_enabled)) {
					gtvg_favourite_unprioritise_recording(fav, recsched->prog->channel->id, recsched->prog->start);
				}
				list = g_slist_next(list);
			}
		}
	}
	updateRecSchedule();
	markFavourites();
}

void on_recordingsDisableButton_toggled(GtkToggleButton * w, gpointer user_data)
{
	GtkTreeIter iter;
	GtkTreeModel *model;
	GSList *list;
	struct GtvgFavourite *fav;
	struct record_schedule *recsched = NULL;
	GtkTreeSelection *treeselection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "recordScheduleList_view")));

	if(gtk_tree_selection_get_selected(treeselection, &model, &iter)) {
		gtk_tree_model_get(model, &iter, 4, &recsched, -1);
		if(gtk_toggle_button_get_active(w)) {
			if(recsched == NULL) {
				GtkWidget *dialog = gtk_message_dialog_new(GTK_WINDOW(glade_xml_get_widget(gxml, "recordScheduleDialog")), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, _("This will stop the current ongoing recording. Are you sure that is what you want to do?"));

				if(gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_YES) {
					if(current_record_prog != NULL) {
						list = current_record_prog->favourites;
						while(list != NULL) {
							fav = (struct GtvgFavourite *) list->data;
							if(fav->record > 0 || (fav->record < 0 && recordings_enabled)) {
								gtvg_favourite_disable_recording(fav, current_record_prog->channel->id, current_record_prog->start);
							}
							list = g_slist_next(list);
						}
					}
					gtk_widget_destroy(dialog);
					stopRecording();
				} else {
					gtk_widget_destroy(dialog);
					return;
				}
			} else {
				list = recsched->prog->favourites;
				while(list != NULL) {
					fav = (struct GtvgFavourite *) list->data;
					if(fav->record > 0 || (fav->record < 0 && recordings_enabled)) {
						gtvg_favourite_disable_recording(fav, recsched->prog->channel->id, recsched->prog->start);
					}
					list = g_slist_next(list);
				}
			}
		} else {
			if(recsched == NULL) {
				return;
			}
			list = recsched->prog->favourites;
			while(list != NULL) {
				fav = (struct GtvgFavourite *) list->data;
				if(fav->record > 0 || (fav->record < 0 && recordings_enabled)) {
					gtvg_favourite_enable_recording(fav, recsched->prog->channel->id, recsched->prog->start);
				}
				list = g_slist_next(list);
			}
		}
	}
	updateRecSchedule();
	markFavourites();
}

void on_recordScheduleList_selection_changed(GtkTreeSelection * treeselection, gpointer user_data)
{
	GtkTreeIter iter;
	GtkTreeModel *model;
	struct record_schedule *recsched = NULL;

	g_signal_handlers_block_matched((gpointer) glade_xml_get_widget(gxml, "recordingsDisableButton"), G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_recordingsDisableButton_toggled, NULL);
	g_signal_handlers_block_matched((gpointer) glade_xml_get_widget(gxml, "recordingsPrioritiseButton"), G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_recordingsPrioritiseButton_toggled, NULL);

	if(gtk_tree_selection_get_selected(treeselection, &model, &iter)) {
		gtk_tree_model_get(model, &iter, 4, &recsched, -1);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "recordingsDisableButton"), recsched == NULL || recsched->disabled != 1);
		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "recordingsDisableButton")), recsched != NULL && recsched->disabled > 1);
		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "recordingsPrioritiseButton")), recsched != NULL && recsched->priority > 1);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "recordingsPrioritiseButton"), recsched != NULL && recsched->disabled < 2);
	} else {
		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "recordingsPrioritiseButton")), FALSE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "recordingsPrioritiseButton"), FALSE);
		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "recordingsDisableButton")), FALSE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "recordingsDisableButton"), FALSE);
	}
	g_signal_handlers_unblock_matched((gpointer) glade_xml_get_widget(gxml, "recordingsDisableButton"), G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_recordingsDisableButton_toggled, NULL);
	g_signal_handlers_unblock_matched((gpointer) glade_xml_get_widget(gxml, "recordingsPrioritiseButton"), G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_recordingsPrioritiseButton_toggled, NULL);

}

void on_recordingsCloseButton_clicked(GtkButton * w, gpointer user_data)
{
	gtk_widget_hide(glade_xml_get_widget(gxml, "recordScheduleDialog"));
}

void on_recordScheduleMenuItem_activate(GtkMenuItem * w, gpointer user_data)
{
	GtkWidget *dialog = getRecordScheduleDialog();

	if(!GTK_WIDGET_VISIBLE(dialog)) {
		gtk_window_present(GTK_WINDOW(dialog));
		updateRecordScheduleList();
	} else {
		gtk_window_present(GTK_WINDOW(dialog));
	}
}

int configure(gboolean init_run)
{
	GtkTreeIter iter;
	GtkWidget *configurationDialog, *dialog;
	gchar *gstr = NULL, *gstr2 = NULL, *gstr3 = NULL, *gstr4 = NULL;
	int days;
	gboolean new_xml_file, b, b2 = FALSE, update_recscheds = FALSE, day_updated = FALSE, update_tooltip = FALSE;
	gint ret, index, i;

	xmtlv_new_configuration = FALSE;
	configurationDialog = getConfigurationDialog();

	gtk_notebook_set_current_page(GTK_NOTEBOOK(glade_xml_get_widget(gxml, "configurationTabs")), gtk_notebook_page_num(GTK_NOTEBOOK(glade_xml_get_widget(gxml, "configurationTabs")), glade_xml_get_widget(gxml, "xmltvConfigurationTab")));

	if(init_run) {
		gtk_widget_show(glade_xml_get_widget(gxml, "instructionsLabel"));
		gtk_notebook_set_show_border(GTK_NOTEBOOK(glade_xml_get_widget(gxml, "configurationTabs")), FALSE);
		gtk_notebook_set_show_tabs(GTK_NOTEBOOK(glade_xml_get_widget(gxml, "configurationTabs")), FALSE);
	} else {
		gtk_widget_hide(glade_xml_get_widget(gxml, "instructionsLabel"));
		gtk_notebook_set_show_border(GTK_NOTEBOOK(glade_xml_get_widget(gxml, "configurationTabs")), TRUE);
		gtk_notebook_set_show_tabs(GTK_NOTEBOOK(glade_xml_get_widget(gxml, "configurationTabs")), TRUE);
		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "statusIconButton")), gtk_status_icon_get_visible(status_icon));
		gtk_spin_button_set_value(GTK_SPIN_BUTTON(glade_xml_get_widget(gxml, "reminderTimeSpin")), (double) reminder_time);
		gtk_spin_button_set_value(GTK_SPIN_BUTTON(glade_xml_get_widget(gxml, "reminderDurationSpin")), reminder_duration > 0 ? (double) reminder_duration : reminder_time + 1.0);
		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "reminderUntilEndButton")), reminder_duration <= 0);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "reminderDurationSpin"), reminder_duration > 0);
		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "showRemindersButton")), reminders_enabled);
		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "reminderDetailsButton")), reminder_details);
		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "reminderSoundButton")), notify_sound);
		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "reminderSoundRegardlessButton")), notify_sound_regardless);
#ifdef HAVE_LIBGNOME
		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "reminderSoundFileButton")), notify_sound_file != NULL);
		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "reminderBeepButton")), notify_sound_file == NULL);
#else
		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "reminderBeepButton")), TRUE);
#endif
		if(notify_sound_file != NULL)
			gtk_file_chooser_set_filename(GTK_FILE_CHOOSER(glade_xml_get_widget(gxml, "reminderSoundFileChooserButton")), notify_sound_file);
		gtk_spin_button_set_value(GTK_SPIN_BUTTON(glade_xml_get_widget(gxml, "currentTooltipItemsSpin")), (double) current_tooltip_items);
		gtk_spin_button_set_value(GTK_SPIN_BUTTON(glade_xml_get_widget(gxml, "futureTooltipItemsSpin")), (double) future_tooltip_items);
		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "wakeupButton")), wakeup_enabled);
		if(recordings_enabled) {
			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "recordAllButton")), TRUE);
		} else if(ask_record) {
			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "recordAskButton")), TRUE);
		} else {
			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "recordNoneButton")), TRUE);
		}
		gtk_entry_set_text(GTK_ENTRY(glade_xml_get_widget(gxml, "startRecordCommandEntry")), start_recording_command);
		gtk_entry_set_text(GTK_ENTRY(glade_xml_get_widget(gxml, "stopRecordCommandEntry")), stop_recording_command);
		gtk_spin_button_set_value(GTK_SPIN_BUTTON(glade_xml_get_widget(gxml, "startMarginSpin")), (gdouble) start_margin);
		gtk_spin_button_set_value(GTK_SPIN_BUTTON(glade_xml_get_widget(gxml, "stopMarginSpin")), (gdouble) stop_margin);
	}
	selected_day_starts_at = day_starts_at;
	gstr = g_strdup_printf("%02i:%02i", day_starts_at / 60, day_starts_at % 60);
	gtk_entry_set_text(GTK_ENTRY(glade_xml_get_widget(gxml, "dayStartsAtEntry")), gstr);
	g_free(gstr);
	gstr = NULL;
	days = gconf_client_get_int(client, "/apps/gtvg/days_to_grab", NULL);
	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "slowButton")), gconf_client_get_bool(client, "/apps/gtvg/grab_with_slow", NULL));
	if(days <= 0)
		days = 5;
	gtk_spin_button_set_value(GTK_SPIN_BUTTON(glade_xml_get_widget(gxml, "daysSpin")), (double) days);
	gtk_spin_button_set_value(GTK_SPIN_BUTTON(glade_xml_get_widget(gxml, "offsetSpin")), (double) gconf_client_get_int(client, "/apps/gtvg/grab_offset", NULL));
	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "updateOnStartupButton")), gconf_client_get_bool(client, "/apps/gtvg/update_on_startup", NULL));
	ret = gtk_dialog_run(GTK_DIALOG(configurationDialog));
	while(TRUE) {
		if(ret != 1) {
			gtk_widget_hide(configurationDialog);
			return 0;
		}
		b = TRUE;
		index = gtk_combo_box_get_active(GTK_COMBO_BOX(glade_xml_get_widget(gxml, "grabCommandCombo")));
		gstr = g_strstrip(g_strdup(gtk_entry_get_text(GTK_ENTRY(glade_xml_get_widget(gxml, "fileEntry")))));
		if(strlen(gstr) == 0) {
			b = FALSE;
			dialog = gtk_message_dialog_new(GTK_WINDOW(window), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, _("Empty output filename"));
			gtk_dialog_run(GTK_DIALOG(dialog));
			gtk_widget_destroy(dialog);
			gtk_widget_grab_focus(glade_xml_get_widget(gxml, "fileEntry"));
			g_free(gstr);
		}
		if(b) {
			if(index == 1) {
				gstr2 = g_strstrip(g_strdup(gtk_entry_get_text(GTK_ENTRY(glade_xml_get_widget(gxml, "commandEntry")))));
				if(strlen(gstr2) == 0) {
					b = FALSE;
					dialog = gtk_message_dialog_new(GTK_WINDOW(window), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, _("Empty command"));
					gtk_dialog_run(GTK_DIALOG(dialog));
					gtk_widget_destroy(dialog);
					gtk_widget_grab_focus(glade_xml_get_widget(gxml, "commandEntry"));
					g_free(gstr2);
				}
			}
		}
		if(b && !init_run) {
			if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "reminderSoundButton"))) && gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "reminderSoundFileButton")))) {
				gstr4 = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(glade_xml_get_widget(gxml, "reminderSoundFileChooserButton")));
				if(gstr4 == NULL) {
					b = FALSE;
					dialog = gtk_message_dialog_new(GTK_WINDOW(window), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, _("No sound file selected"));
					gtk_dialog_run(GTK_DIALOG(dialog));
					gtk_widget_destroy(dialog);
					gtk_widget_grab_focus(glade_xml_get_widget(gxml, "reminderSoundFileChooserButton"));
				}
			}
		}
		if(b) {
			break;
		}
		ret = gtk_dialog_run(GTK_DIALOG(configurationDialog));
	}
	day_updated = (day_starts_at != selected_day_starts_at);
	day_starts_at = selected_day_starts_at;
	gstr3 = g_strdup_printf("%02i:%02i", day_starts_at / 60, day_starts_at % 60);
	gconf_client_set_string(client, "/apps/gtvg/day_starts_at", gstr3, NULL);
	g_free(gstr3);
	gstr3 = gconf_client_get_string(client, "/apps/gtvg/xmltv_file", NULL);
	new_xml_file = ((gstr3 == NULL) || (strcmp(gstr, gstr3) != 0));
	if(gstr3 != NULL) g_free(gstr3);
	gconf_client_set_string(client, "/apps/gtvg/xmltv_file", gstr, NULL);
	g_free(gstr);
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "updateMenuItem"), index != 0);
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "updateToolbutton"), index != 0);
	if(index == 0) {
		gconf_client_set_string(client, "/apps/gtvg/grabber_command", "", NULL);
	} else if(index == 1) {
		gconf_client_set_string(client, "/apps/gtvg/grabber_command", gstr2, NULL);
		g_free(gstr2);
	} else if(gtk_combo_box_get_active_iter(GTK_COMBO_BOX(glade_xml_get_widget(gxml, "grabCommandCombo")), &iter)) {
		gtk_tree_model_get(gtk_combo_box_get_model(GTK_COMBO_BOX(glade_xml_get_widget(gxml, "grabCommandCombo"))), &iter, 1, &gstr, -1);
		gconf_client_set_string(client, "/apps/gtvg/grabber_command", gstr, NULL);
		g_free(gstr);
	}
	gtk_widget_hide(configurationDialog);
	if(!init_run) {
		gconf_client_set_bool(client, "/apps/gtvg/show_in_notification_area", gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "statusIconButton"))), NULL);
		gconf_client_notify_remove(client, gconf_notify_id);
		i = reminder_time;
		reminder_time = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(glade_xml_get_widget(gxml, "reminderTimeSpin")));
		if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "reminderUntilEndButton")))) {
			reminder_duration = -1;
		} else {
			reminder_duration = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(glade_xml_get_widget(gxml, "reminderDurationSpin")));
		}
		if(reminder_time != i) {
			favourite_schedules = g_slist_sort(favourite_schedules, favsched_compare_func);
		}
		reminders_enabled = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "showRemindersButton")));
		reminder_details = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "reminderDetailsButton")));
		notify_sound = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "reminderSoundButton")));
		notify_sound_regardless = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "reminderSoundRegardlessButton")));
		if(notify_sound_file != NULL) {
			g_free(notify_sound_file);
			notify_sound_file = NULL;
		}
		if(notify_sound && gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "reminderSoundFileButton")))) {
			notify_sound_file = gstr4;
		}
		i = current_tooltip_items;
		current_tooltip_items = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(glade_xml_get_widget(gxml, "currentTooltipItemsSpin")));
		if(i != current_tooltip_items)
			update_tooltip = TRUE;
		i = future_tooltip_items;
		future_tooltip_items = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(glade_xml_get_widget(gxml, "futureTooltipItemsSpin")));
		if(i != future_tooltip_items)
			update_tooltip = TRUE;
		gtk_spin_button_set_value(GTK_SPIN_BUTTON(glade_xml_get_widget(gxml, "futureTooltipItemsSpin")), (double) future_tooltip_items);
		gconf_client_set_bool(client, "/apps/gtvg/reminders_enabled", reminders_enabled, NULL);
		gconf_client_set_int(client, "/apps/gtvg/reminder_time", reminder_time, NULL);
		gconf_client_set_int(client, "/apps/gtvg/reminder_duration", reminder_duration, NULL);
		gconf_client_set_bool(client, "/apps/gtvg/show_reminder_details", reminder_details, NULL);
		gconf_client_set_bool(client, "/apps/gtvg/play_reminder_sound", notify_sound, NULL);
		gconf_client_set_bool(client, "/apps/gtvg/always_play_reminder_sound", notify_sound_regardless, NULL);
		if(notify_sound_file == NULL)
			gconf_client_set_string(client, "/apps/gtvg/reminder_sound_file", "", NULL);
		else
			gconf_client_set_string(client, "/apps/gtvg/reminder_sound_file", notify_sound_file, NULL);
		gconf_client_set_int(client, "/apps/gtvg/current_programs_in_tooltip", current_tooltip_items, NULL);
		gconf_client_set_int(client, "/apps/gtvg/upcoming_programs_in_tooltip", future_tooltip_items, NULL);
		b = wakeup_enabled;
		wakeup_enabled = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "wakeupButton")));
		gconf_client_set_bool(client, "/apps/gtvg/wakeup_enabled", wakeup_enabled, NULL);
		b2 = recordings_enabled;
		recordings_enabled = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "recordAllButton")));
		ask_record = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "recordAskButton")));
		if(b != wakeup_enabled || b2 != recordings_enabled) {
			update_recscheds = TRUE;
		}
		gconf_client_set_bool(client, "/apps/gtvg/recordings_enabled", recordings_enabled, NULL);
		gconf_client_set_bool(client, "/apps/gtvg/ask_if_record", ask_record, NULL);
		if(start_recording_command != NULL) {
			g_free(start_recording_command);
			start_recording_command = NULL;
		}
		start_recording_command = g_strdup(gtk_entry_get_text(GTK_ENTRY(glade_xml_get_widget(gxml, "startRecordCommandEntry"))));
		gconf_client_set_string(client, "/apps/gtvg/start_recording_command", start_recording_command, NULL);
		if(stop_recording_command != NULL) {
			g_free(stop_recording_command);
			stop_recording_command = NULL;
		}
		stop_recording_command = g_strdup(gtk_entry_get_text(GTK_ENTRY(glade_xml_get_widget(gxml, "stopRecordCommandEntry"))));
		gconf_client_set_string(client, "/apps/gtvg/stop_recording_command", stop_recording_command, NULL);
		i = start_margin;
		start_margin = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(glade_xml_get_widget(gxml, "startMarginSpin")));
		if(start_margin != i)
			update_recscheds = TRUE;
		gconf_client_set_int(client, "/apps/gtvg/start_recording_margin", start_margin, NULL);
		i = stop_margin;
		stop_margin = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(glade_xml_get_widget(gxml, "stopMarginSpin")));
		if(stop_margin != i)
			update_recscheds = TRUE;
		gconf_client_set_int(client, "/apps/gtvg/stop_recording_margin", stop_margin, NULL);
		gconf_notify_id = gconf_client_notify_add(client, "/apps/gtvg", on_gconf_notify, NULL, NULL, NULL);
	}
	gconf_client_set_bool(client, "/apps/gtvg/grab_with_slow", gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "slowButton"))), NULL);
	gconf_client_set_int(client, "/apps/gtvg/days_to_grab", gtk_spin_button_get_value(GTK_SPIN_BUTTON(glade_xml_get_widget(gxml, "daysSpin"))), NULL);
	gconf_client_set_int(client, "/apps/gtvg/grab_offset", gtk_spin_button_get_value(GTK_SPIN_BUTTON(glade_xml_get_widget(gxml, "offsetSpin"))), NULL);
	gconf_client_set_bool(client, "/apps/gtvg/update_on_startup", gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "updateOnStartupButton"))), NULL);
	if(index > 0 && (xmtlv_new_configuration || (new_xml_file && !g_file_test(gtk_entry_get_text(GTK_ENTRY(glade_xml_get_widget(gxml, "fileEntry"))), G_FILE_TEST_EXISTS)))) {
		updateXMLTVFile(!init_run);
		return 2;
	}
	if(!new_xml_file && !day_updated) {
		if(update_recscheds) {
			updateRecSchedule();
			markFavourites();
		}
		if(update_tooltip)
			updateTooltip();
		return 0;
	}
	if(!init_run)
		loadXMLTV(FALSE);
	checkFavourites(NULL);
	return 1;
}

void clearFilters(void)
{
	GtkTreeSelection *selection;
	glong daytime;
	gboolean b, b2 = FALSE;
	GtkTreeIter iter;

	g_signal_handlers_block_matched((gpointer) searchEntry, G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_searchEntry_changed, NULL);
	gtk_entry_set_text(GTK_ENTRY(searchEntry), "");
	gtk_widget_set_sensitive(searchButton, FALSE);
	gtk_widget_set_sensitive(clearSearchButton, FALSE);
	g_signal_handlers_unblock_matched((gpointer) searchEntry, G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_searchEntry_changed, NULL);
	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "channelsList_view")));
	g_signal_handlers_block_matched((gpointer) selection, G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_channelsList_selection_changed, NULL);
	gtk_tree_selection_unselect_all(selection);
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "allChannelsButton"), FALSE);
	g_signal_handlers_unblock_matched((gpointer) selection, G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_channelsList_selection_changed, NULL);
	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "categoriesList_view")));
	g_signal_handlers_block_matched((gpointer) selection, G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_categoriesList_selection_changed, NULL);
	gtk_tree_selection_unselect_all(selection);
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "allCategoriesButton"), FALSE);
	g_signal_handlers_unblock_matched((gpointer) selection, G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_categoriesList_selection_changed, NULL);
	g_signal_handlers_block_matched((gpointer) glade_xml_get_widget(gxml, "showFavouritesButton"), G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_showFavouritesButton_toggled, NULL);
	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "showFavouritesButton")), FALSE);
	g_signal_handlers_unblock_matched((gpointer) glade_xml_get_widget(gxml, "showFavouritesButton"), G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_showFavouritesButton_toggled, NULL);
	if(all_days || tomorrow_time - 86400 != current_day) {
		b = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(dayCombo_store), &iter);
		while(b) {
			gtk_tree_model_get(GTK_TREE_MODEL(dayCombo_store), &iter, 1, &daytime, -1);
			if(daytime == (glong) tomorrow_time - 86400) {
				b2 = tomorrow_time - 86400 != current_day;
				g_signal_handlers_block_matched((gpointer) glade_xml_get_widget(gxml, "dayCombo"), G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_dayCombo_changed, NULL);
				gtk_combo_box_set_active_iter(GTK_COMBO_BOX(glade_xml_get_widget(gxml, "dayCombo")), &iter);
				g_signal_handlers_unblock_matched((gpointer) glade_xml_get_widget(gxml, "dayCombo"), G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_dayCombo_changed, NULL);
				current_day = (time_t) daytime;
				all_days = FALSE;
				break;
			}
			b = gtk_tree_model_iter_next(GTK_TREE_MODEL(dayCombo_store), &iter);
		}
	}
	g_signal_handlers_block_matched((gpointer) glade_xml_get_widget(gxml, "hidePastButton"), G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_hidePastButton_toggled, NULL);
	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "hidePastButton")), TRUE);
	g_signal_handlers_unblock_matched((gpointer) glade_xml_get_widget(gxml, "hidePastButton"), G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_hidePastButton_toggled, NULL);
	updateProgramList();
	if(b2)
		updateProgramGrid(FALSE);
}

void on_clearFiltersToolbutton_clicked(GtkToolButton * w, gpointer user_data)
{
	clearFilters();
}

void on_clearFiltersMenuItem_activate(GtkMenuItem * w, gpointer user_data)
{
	clearFilters();
}

void on_copyDescriptionMenuItem_activate(GtkMenuItem * w, gpointer user_data)
{
	GtkTextBuffer *tb = gtk_text_view_get_buffer(GTK_TEXT_VIEW(glade_xml_get_widget(gxml, "programInfoView")));
	GtkClipboard *clip = gtk_clipboard_get(GDK_SELECTION_CLIPBOARD);

	gtk_text_buffer_copy_clipboard(tb, clip);
}

void on_selectAllDescriptionMenuItem_activate(GtkMenuItem * w, gpointer user_data)
{
	GtkTextIter iter1, iter2;
	GtkTextBuffer *tb = gtk_text_view_get_buffer(GTK_TEXT_VIEW(glade_xml_get_widget(gxml, "programInfoView")));

	gtk_text_buffer_get_start_iter(tb, &iter1);
	gtk_text_buffer_get_end_iter(tb, &iter2);
	gtk_text_buffer_select_range(tb, &iter1, &iter2);
}

gboolean popup_programInfoView_menu(GdkEventButton * event)
{
	GtkTextBuffer *tb = gtk_text_view_get_buffer(GTK_TEXT_VIEW(glade_xml_get_widget(gxml, "programInfoView")));

	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "copyDescriptionMenuItem"), gtk_text_buffer_get_has_selection(tb));
	gtk_menu_popup(GTK_MENU(glade_xml_get_widget(gxml, "programInfoView_menu")), NULL, NULL, NULL, NULL, (event != NULL) ? event->button : 0, (event != NULL) ? gdk_event_get_time((GdkEvent *) event) : gtk_get_current_event_time());
	return TRUE;
}

gboolean on_programInfoView_popup_menu(GtkWidget * w, gpointer user_data)
{
	return popup_programInfoView_menu(NULL);
}

gboolean on_programInfoView_button_press_event(GtkWidget * w, GdkEventButton * event, gpointer user_data)
{
	if(event->type == GDK_BUTTON_PRESS && event->button == 3) {
		return popup_programInfoView_menu(event);
	}
	return FALSE;
}

void on_programList_selection_changed(GtkTreeSelection * treeselection, gpointer user_data)
{
	GtkTreeIter iter;
	GtkTreeModel *model;
	GtkTextBuffer *tb;
	struct GtvgProgram *prog = NULL;

	tb = gtk_text_view_get_buffer(GTK_TEXT_VIEW(glade_xml_get_widget(gxml, "programInfoView")));
	if(gtk_tree_selection_get_selected(treeselection, &model, &iter)) {
		gtk_tree_model_get(model, &iter, OBJECT_COLUMN, &prog, -1);
		createDescription(prog, FALSE, tb);
	} else {
		gtk_text_buffer_set_text(tb, "", -1);
	}
	programSelected(prog);
}

gboolean on_programList_view_button_press_event(GtkWidget * w, GdkEventButton * event, gpointer user_data)
{
	GtkTreePath *path;
	GtkTreeSelection *selection;
	GtkTreeIter iter;
	GtkTreeModel *model;

	if(event->type == GDK_2BUTTON_PRESS && event->button == 1) {
		selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "programList_view")));
		if(gtk_tree_selection_get_selected(selection, &model, &iter)) {
			gtk_expander_set_expanded(GTK_EXPANDER(glade_xml_get_widget(gxml, "descriptionExpander")), !gtk_expander_get_expanded(GTK_EXPANDER(glade_xml_get_widget(gxml, "descriptionExpander"))));
			return TRUE;
		}
	} else if(event->type == GDK_BUTTON_PRESS && event->button == 3) {
		if(gtk_tree_view_get_path_at_pos(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "programList_view")), (gint) event->x, (gint) event->y, &path, NULL, NULL, NULL)) {
			selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "programList_view")));
			gtk_tree_selection_select_path(selection, path);
			gtk_tree_path_free(path);
		}
		return popup_programList_menu(event);
	}
	return FALSE;
}

gboolean on_programList_view_popup_menu(GtkWidget * w, gpointer user_data)
{
	return popup_programList_menu(NULL);
}

gboolean popup_programList_menu(GdkEventButton * event)
{
	GtkTreeSelection *selection;
	GtkTreeIter iter;
	GtkTreeModel *model;

	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "programList_view")));
	if(gtk_tree_selection_get_selected(selection, &model, &iter)) {
		gtk_menu_popup(GTK_MENU(glade_xml_get_widget(gxml, "programList_menu")), NULL, NULL, NULL, NULL, (event != NULL) ? event->button : 0, (event != NULL) ? gdk_event_get_time((GdkEvent *) event) : gtk_get_current_event_time());
		return TRUE;
	}
	return FALSE;
}

gboolean ensureSelectedProgramVisible(gpointer user_data)
{
	GtkTreePath *path, *p_a, *p_b;
	GtkTreeSelection *selection;
	GtkTreeIter iter;
	GtkTreeModel *model;

	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "programList_view")));
	if(gtk_tree_selection_get_selected(selection, &model, &iter)) {
		if(gtk_tree_view_get_visible_range(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "programList_view")), &p_a, &p_b)) {
			path = gtk_tree_model_get_path(model, &iter);
			if(gtk_tree_path_compare(path, p_a) < 0) {
				gtk_tree_view_scroll_to_cell(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "programList_view")), path, NULL, FALSE, 0.0, 0.0);
			} else if(gtk_tree_path_compare(path, p_b) > 0) {
				gtk_tree_view_scroll_to_cell(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "programList_view")), path, NULL, FALSE, 0.0, 0.0);
			}
			gtk_tree_path_free(path);
			gtk_tree_path_free(p_a);
			gtk_tree_path_free(p_b);
		}
	}
	return FALSE;
}

void on_descriptionExpander_expanded(GObject * object, GParamSpec * param_spec, gpointer user_data)
{
	gconf_client_set_bool(client, "/apps/gtvg/show_description", gtk_expander_get_expanded(GTK_EXPANDER(object)), NULL);
	if(gtk_expander_get_expanded(GTK_EXPANDER(object))) {
		if(gconf_client_get_int(client, "/apps/gtvg/last_hpane_pos", NULL) > 0) {
			gtk_paned_set_position(GTK_PANED(glade_xml_get_widget(gxml, "programListPanels")), gconf_client_get_int(client, "/apps/gtvg/last_hpane_pos", NULL));
		}
		//the expander is not visually expanded yet
		g_timeout_add(200, ensureSelectedProgramVisible, NULL);
	} else {
		gconf_client_set_int(client, "/apps/gtvg/last_hpane_pos", gtk_paned_get_position(GTK_PANED(glade_xml_get_widget(gxml, "programListPanels"))), NULL);
		gtk_paned_set_position(GTK_PANED(glade_xml_get_widget(gxml, "programListPanels")), -1);
	}
}

void on_removeFavouritesMenuItem_activate(GtkMenuItem * w, gpointer user_data)
{
	on_removeFavouriteButton_clicked(NULL, NULL);
}

void on_editFavouritesMenuItem_activate(GtkMenuItem * w, gpointer user_data)
{
	on_editFavouriteButton_clicked(NULL, NULL);
}

void removeSelectedFavourite(void)
{
	struct GtvgProgram *prog = selectedProgram();

	if(prog != NULL)
		removeProgramFavourites(prog);
}

void on_removeFavouriteToolbutton_clicked(GtkToolButton * w, gpointer user_data)
{
	removeSelectedFavourite();
}

void on_removeFavouriteMenuItem_activate(GtkMenuItem * w, gpointer user_data)
{
	removeSelectedFavourite();
}

void on_addToBlacklistMenuItem_activate(GtkMenuItem * w, gpointer user_data)
{
	on_addToBlacklistButton_clicked(NULL, NULL);
}

void on_addToBlacklistToolbutton_clicked(GtkToolButton * w, gpointer user_data)
{
	on_addToBlacklistButton_clicked(NULL, NULL);
}

void on_favouritesList_selection_changed(GtkTreeSelection * treeselection, gpointer user_data)
{
	GtkTreeIter iter;

	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "removeFavouriteButton"), gtk_tree_selection_get_selected(treeselection, NULL, &iter));
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "editFavouriteButton"), gtk_tree_selection_get_selected(treeselection, NULL, &iter));
}

void findNextProgram(const gchar * title, gboolean search_future)
{
	struct GtvgProgram *prog = selectedProgram();

	if(prog != NULL && prog->title != NULL) {
		if(strcmp(title, prog->title) == 0) {
			findProgram(title, search_future, prog->stop + 1);
			return;
		}
	}
	findProgram(title, search_future, time(NULL));
}

void findProgram(const gchar * title, gboolean search_future, time_t firsttime)
{
	GtkTreeIter iter;
	GtkTreeModel *model;
	GtkTreeSelection *selection, *selection2;
	gboolean b;
	gboolean valid;
	GSList *list;
	GtkTreePath *path;
	struct GtvgProgram *prog;
	struct tm tmptp;
	GtkTextBuffer *tb;
	time_t curtime;
	gdouble x1, x2, y1, y2;

	if(gtk_notebook_get_current_page(GTK_NOTEBOOK(glade_xml_get_widget(gxml, "viewPages"))) == 1) {
		list = programs;
		while(list != NULL) {
			prog = (struct GtvgProgram *) list->data;
			if(prog->stop >= firsttime) {
				if((prog->canvas_text != NULL || prog->canvas_rect == NULL) && strcmp(title, prog->title) == 0) {
					if(search_future && prog->canvas_rect == NULL && (prog->start >= current_day + 86400 || prog->stop <= current_day)) {
						tmptp = prog->start_tm;
						tmptp.tm_sec = 0;
						b = (tmptp.tm_hour * 60 + tmptp.tm_min < day_starts_at);
						tmptp.tm_hour = day_starts_at / 60;
						tmptp.tm_min = day_starts_at % 60;
						current_day = mktime(&tmptp);
						if(b)
							current_day -= 86400;
						currentDayChanged();
						while(gtk_events_pending())
							gtk_main_iteration();
						findProgram(title, FALSE, prog->stop - 1);
						break;
					}
					if(prog->canvas_rect == NULL)
						break;
					g_object_get(prog->canvas_rect, "x1", &x1, "x2", &x2, "y1", &y1, "y2", &y2, NULL);
					gtk_adjustment_set_value(gtk_scrolled_window_get_hadjustment(GTK_SCROLLED_WINDOW(glade_xml_get_widget(gxml, "programCanvas_scrolled"))), x1 - 60);
					gtk_adjustment_clamp_page(gtk_scrolled_window_get_vadjustment(GTK_SCROLLED_WINDOW(glade_xml_get_widget(gxml, "programCanvas_scrolled"))), y1, y2);
					tb = gtk_text_view_get_buffer(GTK_TEXT_VIEW(glade_xml_get_widget(gxml, "gridDescriptionView")));
					curtime = time(NULL);
					if(selected_gridprog != NULL) {
						g_object_set(G_OBJECT(selected_gridprog->canvas_rect), "fill-color-gdk", selected_gridprog->canvas_text == NULL ? NULL : (selected_gridprog->start <= curtime && selected_gridprog->stop > curtime ? &current_bg_color : (selected_gridprog->favourites != NULL ? favBgColor(selected_gridprog) : defBgColor(selected_gridprog))), "outline-color-gdk", selected_gridprog->start <= curtime && selected_gridprog->stop > curtime ? &current_border_color : (selected_gridprog->favourites != NULL ? &favourite_border_color : &default_border_color), NULL);
						if(selected_gridprog->canvas_text != NULL) {
							g_object_set(G_OBJECT(selected_gridprog->canvas_text), "fill-color-gdk", selected_gridprog->start <= curtime && selected_gridprog->stop > curtime ? &current_text_color : (selected_gridprog->favourites != NULL ? favTextColor(selected_gridprog) : defTextColor(selected_gridprog)), NULL);
						}
					}
					selected_gridprog = prog;
					g_object_set(G_OBJECT(prog->canvas_rect), "fill-color-gdk", &selected_bg_color, "outline-color-gdk", &selected_border_color, NULL);
					if(prog->canvas_text != NULL)
						g_object_set(G_OBJECT(prog->canvas_text), "fill-color-gdk", &selected_text_color, NULL);
					createDescription(prog, FALSE, tb);
					programSelected(prog);
					break;
				}
			}
			list = g_slist_next(list);
		}
	} else {
		model = GTK_TREE_MODEL(programList_store);
		valid = gtk_tree_model_get_iter_first(model, &iter);
		while(valid) {
			gtk_tree_model_get(model, &iter, OBJECT_COLUMN, &prog, -1);
			if(prog->stop >= firsttime) {
				if(prog->title) {
					if(strcmp(title, prog->title) == 0) {
						selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "programList_view")));
						gtk_tree_selection_select_iter(selection, &iter);
						path = gtk_tree_model_get_path(model, &iter);
						while(gtk_events_pending())
							gtk_main_iteration();
						gtk_tree_view_scroll_to_cell(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "programList_view")), path, NULL, TRUE, 0.5, 0.0);
						gtk_tree_path_free(path);
						return;
					}
				}
			}
			valid = gtk_tree_model_iter_next(model, &iter);
		}
		selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "channelsList_view")));
		selection2 = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "categoriesList_view")));
		b = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "showFavouritesButton")));
		if(search_future && (b || !all_days || gtk_tree_selection_count_selected_rows(selection) > 0 || gtk_tree_selection_count_selected_rows(selection2) > 0 || strlen(gtk_entry_get_text(GTK_ENTRY(searchEntry))) > 0)) {
			list = programs;
			while(list != NULL) {
				prog = (struct GtvgProgram *) list->data;
				if(prog->stop >= firsttime) {
					if(strcmp(title, prog->title) == 0) {
						if(!programInChannels(prog)) {
							g_signal_handlers_block_matched((gpointer) selection, G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_channelsList_selection_changed, NULL);
							gtk_tree_selection_unselect_all(selection);
							gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "allChannelsButton"), FALSE);
							g_signal_handlers_unblock_matched((gpointer) selection, G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_channelsList_selection_changed, NULL);
						}
						if(!programInCategories(prog)) {
							g_signal_handlers_block_matched((gpointer) selection2, G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_categoriesList_selection_changed, NULL);
							gtk_tree_selection_unselect_all(selection2);
							gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "allCategoriesButton"), FALSE);
							g_signal_handlers_unblock_matched((gpointer) selection2, G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_categoriesList_selection_changed, NULL);
						}
						if(b && prog->favourites == NULL) {
							g_signal_handlers_block_matched((gpointer) glade_xml_get_widget(gxml, "showFavouritesButton"), G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_showFavouritesButton_toggled, NULL);
							gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "showFavouritesButton")), FALSE);
							g_signal_handlers_unblock_matched((gpointer) glade_xml_get_widget(gxml, "showFavouritesButton"), G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_showFavouritesButton_toggled, NULL);
						}
						if(prog->start >= current_day + 86400 || prog->start < current_day) {
							gtk_tree_model_get_iter_first(GTK_TREE_MODEL(dayCombo_store), &iter);
							gtk_combo_box_set_active_iter(GTK_COMBO_BOX(glade_xml_get_widget(gxml, "dayCombo")), &iter);
						} else {
							updateProgramList();
						}
						findProgram(title, FALSE, firsttime);
						return;
					}
				}
				list = g_slist_next(list);
			}
		}
	}
}

void searchFavouriteTitle(void)
{
	GtkTreeSelection *selection;
	GtkTreeIter iter;
	GtkTreeModel *model;
	gchar *gstr;

	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "favouritesList_view")));
	if(gtk_tree_selection_get_selected(selection, &model, &iter)) {
		gtk_tree_model_get(model, &iter, FAVOURITES_TITLE_COLUMN, &gstr, -1);
		if(gstr) {
			findNextProgram(gstr, TRUE);
			g_free(gstr);
		}
	}
}

gboolean favsInFavs(GSList * favs1, GSList * favs2)
{
	GSList *list = favs1;

	while(list != NULL) {
		if(g_slist_find(favs2, list->data))
			return TRUE;
		list = g_slist_next(list);
	}
	return FALSE;
}

void findNextFavourite(GSList * favs, gboolean search_future)
{
	struct GtvgProgram *prog = selectedProgram();

	if(prog != NULL && favsInFavs(prog->favourites, favs)) {
		findFavourite(favs, search_future, prog->stop + 1);
		return;
	}
	findFavourite(favs, search_future, time(NULL));
}

void findFavourite(GSList * favs, gboolean search_future, time_t firsttime)
{
	GtkTreeIter iter;
	GtkTreeModel *model;
	GtkTreeSelection *selection, *selection2;
	gboolean valid;
	GSList *list;
	GtkTreePath *path;
	struct GtvgProgram *prog;
	struct tm tmptp;
	GtkTextBuffer *tb;
	time_t curtime;
	gdouble x1, x2, y1, y2;
	gboolean b;

	if(gtk_notebook_get_current_page(GTK_NOTEBOOK(glade_xml_get_widget(gxml, "viewPages"))) == 1) {
		list = programs;
		while(list != NULL) {
			prog = (struct GtvgProgram *) list->data;
			if(prog->stop >= firsttime) {
				if((prog->canvas_text != NULL || prog->canvas_rect == NULL) && favsInFavs(prog->favourites, favs)) {
					if(search_future && prog->canvas_rect == NULL && (prog->start >= current_day + 86400 || prog->stop <= current_day)) {
						tmptp = prog->start_tm;
						tmptp.tm_sec = 0;
						b = (tmptp.tm_hour * 60 + tmptp.tm_min < day_starts_at);
						tmptp.tm_hour = day_starts_at / 60;
						tmptp.tm_min = day_starts_at % 60;
						current_day = mktime(&tmptp);
						if(b)
							current_day -= 86400;
						currentDayChanged();
						while(gtk_events_pending())
							gtk_main_iteration();
						findFavourite(favs, FALSE, prog->stop - 1);
						break;
					}
					if(prog->canvas_rect == NULL)
						break;
					g_object_get(prog->canvas_rect, "x1", &x1, "x2", &x2, "y1", &y1, "y2", &y2, NULL);
					gtk_adjustment_set_value(gtk_scrolled_window_get_hadjustment(GTK_SCROLLED_WINDOW(glade_xml_get_widget(gxml, "programCanvas_scrolled"))), x1 - 60);
					gtk_adjustment_clamp_page(gtk_scrolled_window_get_vadjustment(GTK_SCROLLED_WINDOW(glade_xml_get_widget(gxml, "programCanvas_scrolled"))), y1, y2);
					tb = gtk_text_view_get_buffer(GTK_TEXT_VIEW(glade_xml_get_widget(gxml, "gridDescriptionView")));
					curtime = time(NULL);
					if(selected_gridprog != NULL) {
						g_object_set(G_OBJECT(selected_gridprog->canvas_rect), "fill-color-gdk", selected_gridprog->canvas_text == NULL ? NULL : (selected_gridprog->start <= curtime && selected_gridprog->stop > curtime ? &current_bg_color : (selected_gridprog->favourites != NULL ? favBgColor(selected_gridprog) : defBgColor(selected_gridprog))), "outline-color-gdk", selected_gridprog->start <= curtime && selected_gridprog->stop > curtime ? &current_border_color : (selected_gridprog->favourites != NULL ? &favourite_border_color : &default_border_color), NULL);
						if(selected_gridprog->canvas_text != NULL) {
							g_object_set(G_OBJECT(selected_gridprog->canvas_text), "fill-color-gdk", selected_gridprog->start <= curtime && selected_gridprog->stop > curtime ? &current_text_color : (selected_gridprog->favourites != NULL ? favTextColor(selected_gridprog) : defTextColor(selected_gridprog)), NULL);
						}
					}
					selected_gridprog = prog;
					g_object_set(G_OBJECT(prog->canvas_rect), "fill-color-gdk", &selected_bg_color, "outline-color-gdk", &selected_border_color, NULL);
					if(prog->canvas_text != NULL)
						g_object_set(G_OBJECT(prog->canvas_text), "fill-color-gdk", &selected_text_color, NULL);
					createDescription(prog, FALSE, tb);
					programSelected(prog);
					break;
				}
			}
			list = g_slist_next(list);
		}
	} else {
		model = GTK_TREE_MODEL(programList_store);
		valid = gtk_tree_model_get_iter_first(model, &iter);
		while(valid) {
			gtk_tree_model_get(model, &iter, OBJECT_COLUMN, &prog, -1);
			if(prog->stop >= firsttime && favsInFavs(prog->favourites, favs)) {
				selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "programList_view")));
				gtk_tree_selection_select_iter(selection, &iter);
				path = gtk_tree_model_get_path(model, &iter);
				while(gtk_events_pending())
					gtk_main_iteration();
				gtk_tree_view_scroll_to_cell(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "programList_view")), path, NULL, TRUE, 0.5, 0.0);
				gtk_tree_path_free(path);
				return;
			}
			valid = gtk_tree_model_iter_next(model, &iter);
		}
		selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "channelsList_view")));
		selection2 = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "categoriesList_view")));
		if(search_future && (!all_days || gtk_tree_selection_count_selected_rows(selection) > 0 || gtk_tree_selection_count_selected_rows(selection2) > 0 || strlen(gtk_entry_get_text(GTK_ENTRY(searchEntry))) > 0)) {
			list = programs;
			while(list != NULL) {
				prog = (struct GtvgProgram *) list->data;
				if(prog->stop >= firsttime && favsInFavs(prog->favourites, favs)) {
					if(!programInFilter(prog)) {
						g_signal_handlers_block_matched((gpointer) searchEntry, G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_searchEntry_changed, NULL);
						gtk_entry_set_text(GTK_ENTRY(searchEntry), "");
						gtk_widget_set_sensitive(searchButton, FALSE);
						gtk_widget_set_sensitive(clearSearchButton, FALSE);
						g_signal_handlers_unblock_matched((gpointer) searchEntry, G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_searchEntry_changed, NULL);
					}
					if(!programInChannels(prog)) {
						g_signal_handlers_block_matched((gpointer) selection, G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_channelsList_selection_changed, NULL);
						gtk_tree_selection_unselect_all(selection);
						gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "allChannelsButton"), FALSE);
						g_signal_handlers_unblock_matched((gpointer) selection, G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_channelsList_selection_changed, NULL);
					}
					if(!programInCategories(prog)) {
						g_signal_handlers_block_matched((gpointer) selection2, G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_categoriesList_selection_changed, NULL);
						gtk_tree_selection_unselect_all(selection2);
						gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "allCategoriesButton"), FALSE);
						g_signal_handlers_unblock_matched((gpointer) selection2, G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_categoriesList_selection_changed, NULL);
					}
					if(prog->start >= current_day + 86400 || prog->start < current_day) {
						gtk_tree_model_get_iter_first(GTK_TREE_MODEL(dayCombo_store), &iter);
						gtk_combo_box_set_active_iter(GTK_COMBO_BOX(glade_xml_get_widget(gxml, "dayCombo")), &iter);
					} else {
						updateProgramList();
					}
					findFavourite(favs, FALSE, firsttime);
					return;
				}
				list = g_slist_next(list);
			}
		}
	}
}

void searchFavourite(void)
{
	GtkTreeSelection *selection;
	GtkTreeIter iter;
	GtkTreeModel *model;
	struct GtvgFavourite *fav;
	GSList *favs = NULL;

	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "favouritesList_view")));
	if(gtk_tree_selection_get_selected(selection, &model, &iter)) {
		gtk_tree_model_get(model, &iter, FAVOURITES_OBJECT_COLUMN, &fav, -1);
		if(fav != NULL) {
			favs = g_slist_prepend(favs, fav);
			findNextFavourite(favs, TRUE);
			g_slist_free(favs);
		}
	}
}

gboolean on_favouritesList_view_button_press_event(GtkWidget * w, GdkEventButton * event, gpointer user_data)
{
	GtkTreePath *path;
	GtkTreeSelection *selection;

	if(event->type == GDK_2BUTTON_PRESS && event->button == 1) {
		searchFavourite();
		return TRUE;
	} else if(event->type == GDK_BUTTON_PRESS && event->button == 3) {
		if(gtk_tree_view_get_path_at_pos(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "favouritesList_view")), (gint) event->x, (gint) event->y, &path, NULL, NULL, NULL)) {
			selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "favouritesList_view")));
			gtk_tree_selection_select_path(selection, path);
			gtk_tree_path_free(path);
		}
		return popup_favouritesList_menu(event);
	}
	return FALSE;
}

void on_findFavouritesMenuItem_activate(GtkMenuItem * w, gpointer user_data)
{
	searchFavourite();
}

void on_findTitleFavouritesMenuItem_activate(GtkMenuItem * w, gpointer user_data)
{
	searchFavouriteTitle();
}

void on_findFavouriteMenuItem_activate(GtkMenuItem * w, gpointer user_data)
{
	struct GtvgProgram *prog = selectedProgram();

	if(prog != NULL && prog->favourites != NULL) {
		findNextFavourite(prog->favourites, TRUE);
	}
}

void on_findProgramMenuItem_activate(GtkMenuItem * w, gpointer user_data)
{

	struct GtvgProgram *prog = selectedProgram();

	if(prog != NULL) {
		findNextProgram(prog->title, TRUE);
	}
}

void on_findProgramToolbutton_clicked(GtkToolButton * w, gpointer user_data)
{
	struct GtvgProgram *prog = selectedProgram();

	if(prog != NULL) {
		findNextProgram(prog->title, TRUE);
	}
}

gboolean on_favouritesList_view_popup_menu(GtkWidget * w, gpointer user_data)
{
	return popup_favouritesList_menu(NULL);
}

gboolean popup_favouritesList_menu(GdkEventButton * event)
{
	GtkTreeSelection *selection;
	GtkTreeIter iter;
	GtkTreeModel *model;

	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "favouritesList_view")));
	if(gtk_tree_selection_get_selected(selection, &model, &iter)) {
		gtk_menu_popup(GTK_MENU(glade_xml_get_widget(gxml, "favouritesList_menu")), NULL, NULL, NULL, NULL, (event != NULL) ? event->button : 0, (event != NULL) ? gdk_event_get_time((GdkEvent *) event) : gtk_get_current_event_time());
		return TRUE;
	}
	return FALSE;
}

void on_addFavouriteToolbutton_clicked(GtkToolButton * w, gpointer user_data)
{
	if(selectedProgram() != NULL)
		addFavouriteType(FAVOURITE_ALL);
	else
		newFavourite();
}

void addFavouriteType(int favtype)
{
	struct GtvgFavourite *fav;
	struct GtvgProgram *prog = selectedProgram();

	if(prog == NULL)
		return;

	fav = gtvg_favourite_new();
	fav->title = g_strdup(prog->title);
	fav->time = 0;
	fav->dayofweek = -1;
	fav->timeofday = -1;
	fav->channel = NULL;
	if(ask_record) {
		GtkWidget *dialog = gtk_message_dialog_new(GTK_WINDOW(window), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, _("Shall this favourite be recorded?"));

		if(gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_YES) {
			fav->record = 1;
			fav->record_start_margin = start_margin;
			fav->record_stop_margin = stop_margin;
		}
		gtk_widget_destroy(dialog);
	}
	switch (favtype) {
		case FAVOURITE_ONCE:{
				fav->time = prog->start;
				fav->channel = g_strdup(prog->chid);
				break;
			}
		case FAVOURITE_DAYANDTIME:{
				fav->timeofday = prog->start_tm.tm_hour * 3600 + prog->start_tm.tm_min * 60 + prog->start_tm.tm_sec;
				fav->dayofweek = prog->start_tm.tm_wday;
				fav->channel = g_strdup(prog->chid);
				break;
			}
		case FAVOURITE_TIME:{
				fav->timeofday = prog->start_tm.tm_hour * 3600 + prog->start_tm.tm_min * 60 + prog->start_tm.tm_sec;
				fav->channel = g_strdup(prog->chid);
				break;
			}
		case FAVOURITE_CHANNEL:{
				fav->channel = g_strdup(prog->chid);
				break;
			}
		default:{
			}
	}

	addFavourite(fav);

}

void addFavourite(struct GtvgFavourite *fav)
{
	GSList *list;
	gchar *upper, *lower;
	gboolean b;

	if(fav->partial_title) {
		upper = g_utf8_strup(fav->title, -1);
		lower = g_utf8_strdown(fav->title, -1);
		g_strstrip(upper);
		g_strstrip(lower);
		list = blacklist;
		b = FALSE;
		while(list != NULL) {
			if(searchNoCase((gchar *) list->data, lower, upper)) {
				blacklist = g_slist_delete_link(blacklist, list);
				list = blacklist;
				b = TRUE;
			} else {
				list = g_slist_next(list);
			}
		}
		g_free(upper);
		g_free(lower);
		if(b) {
			gconf_client_set_list(client, "/apps/gtvg/blacklist", GCONF_VALUE_STRING, blacklist, NULL);
			updateProgramList();
			updateProgramGrid(FALSE);
			updateBlacklist();
		}
	} else {
		removeFromBlacklist(fav->title);
	}
	if(g_slist_find_custom(favourites, fav, favourite_strict_compare_func) != NULL) {
		gtvg_favourite_free(fav);
		return;
	}
	favourites = g_slist_insert_sorted(favourites, fav, favourite_sort_compare_func);
	updateReminders(fav, NULL);
	if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "showFavouritesButton")))) {
		updateProgramList();
	}
	markFavourites();
	programSelected(selectedProgram());
	updateFavourites();
}

void on_addFavouriteMenuItem_activate(GtkMenuItem * w, gpointer user_data)
{
	addFavouriteType(FAVOURITE_ALL);
}

void on_addFavouriteChannelMenuItem_activate(GtkMenuItem * w, gpointer user_data)
{
	addFavouriteType(FAVOURITE_CHANNEL);
}

void on_addFavouriteTimeMenuItem_activate(GtkMenuItem * w, gpointer user_data)
{
	addFavouriteType(FAVOURITE_TIME);
}

void on_addFavouriteDayAndTimeMenuItem_activate(GtkMenuItem * w, gpointer user_data)
{
	addFavouriteType(FAVOURITE_DAYANDTIME);
}

void on_addFavouriteOnlyMenuItem_activate(GtkMenuItem * w, gpointer user_data)
{
	addFavouriteType(FAVOURITE_ONCE);
}

void on_addCustomFavouriteMenuItem_activate(GtkMenuItem * w, gpointer user_data)
{
	newFavourite();
}

gboolean iters_equal(GtkTreeModel * model, GtkTreeIter * iter1, GtkTreeIter * iter2)
{
	gboolean iter_equal;
	GtkTreePath *path1, *path2;

	if(iter1 == NULL || iter2 == NULL)
		return FALSE;
	path1 = gtk_tree_model_get_path(model, iter1);
	path2 = gtk_tree_model_get_path(model, iter2);
	iter_equal = (gtk_tree_path_compare(path1, path2) == 0);
	gtk_tree_path_free(path1);
	gtk_tree_path_free(path2);
	return iter_equal;
}

void removeFavourite(struct GtvgFavourite *fav)
{
	GSList *list;

	list = g_slist_find(favourites, fav);
	if(list != NULL)
		favourites = g_slist_delete_link(favourites, list);
	removeReminders(fav);
	gtvg_favourite_free(fav);
	if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "showFavouritesButton")))) {
		updateProgramList();
	}
	markFavourites();
	programSelected(selectedProgram());
	updateFavourites();
}

gboolean on_dayStartsAtEntry_focus_out_event(GtkWidget * w, GdkEventFocus * event, gpointer user_data)
{
	struct tm time_tm;
	gchar *time_str;

	if(strptime(gtk_entry_get_text(GTK_ENTRY(w)), "%H:%M", &time_tm) == NULL) {
		if(strptime(gtk_entry_get_text(GTK_ENTRY(w)), "%H%M", &time_tm) == NULL) {
			if(strptime(gtk_entry_get_text(GTK_ENTRY(w)), "%H.%M", &time_tm) == NULL) {
				GtkWidget *dialog = gtk_message_dialog_new(GTK_WINDOW(glade_xml_get_widget(gxml, "configurationDialog")), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, _("Invalid time value"));

				gtk_dialog_run(GTK_DIALOG(dialog));
				gtk_widget_destroy(dialog);
				gtk_widget_grab_focus(w);
				time_str = g_strdup_printf("%02i:%02i", selected_day_starts_at / 60, selected_day_starts_at % 60);
				gtk_entry_set_text(GTK_ENTRY(w), time_str);
				gtk_editable_select_region(GTK_EDITABLE(w), 0, -1);
				g_free(time_str);
				return FALSE;
			}
		}
	}
	selected_day_starts_at = time_tm.tm_min + time_tm.tm_hour * 60;
	return FALSE;
}

gboolean on_favouriteTimeEntry_focus_out_event(GtkWidget * w, GdkEventFocus * event, gpointer user_data)
{
	struct tm time_tm;
	gchar *time_str;

	if(strptime(gtk_entry_get_text(GTK_ENTRY(w)), "%H:%M", &time_tm) == NULL) {
		if(strptime(gtk_entry_get_text(GTK_ENTRY(w)), "%H%M", &time_tm) == NULL) {
			if(strptime(gtk_entry_get_text(GTK_ENTRY(w)), "%H.%M", &time_tm) == NULL) {
				GtkWidget *dialog = gtk_message_dialog_new(GTK_WINDOW(window), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, _("Invalid time value"));

				gtk_dialog_run(GTK_DIALOG(dialog));
				gtk_widget_destroy(dialog);
				gtk_widget_grab_focus(w);
				time_str = g_strnfill(20, '\0');
				strftime(time_str, 20, "%H:%M", &selected_favourite_date);
				gtk_entry_set_text(GTK_ENTRY(w), time_str);
				gtk_editable_select_region(GTK_EDITABLE(w), 0, -1);
				g_free(time_str);
				return FALSE;
			}
		}
	}
	selected_favourite_date.tm_min = time_tm.tm_min;
	selected_favourite_date.tm_hour = time_tm.tm_hour;
	return FALSE;
}

void editFavourite(struct GtvgFavourite *fav)
{
	GtkTreeIter iter;
	struct GtvgChannel *ch;
	GtkWidget *favouriteDialog;
	gchar *gstr, *time_str;
	time_t timetmp;
	struct GtvgProgram *prog = selectedProgram();

	favouriteDialog = getFavouriteDialog();
	gtk_window_set_title(GTK_WINDOW(favouriteDialog), fav != NULL ? _("Edit Favourite") : _("New Favourite"));
	if(fav == NULL && prog != NULL) {
		timetmp = prog->start;
	} else if(fav != NULL && fav->time > 0) {
		timetmp = fav->time;
	} else {
		timetmp = time(NULL);
	}
	time_str = g_strnfill(80, '\0');
	localtime_r(&timetmp, &selected_favourite_date);
	if(fav != NULL && fav->time <= 0 && fav->timeofday >= 0) {
		selected_favourite_date.tm_hour = fav->timeofday / 3600;
		selected_favourite_date.tm_min = (fav->timeofday % 3600) / 60;
	}
	gtk_combo_box_set_active(GTK_COMBO_BOX(glade_xml_get_widget(gxml, "favouriteDayCombo")), (fav != NULL && fav->dayofweek >= 0) ? fav->dayofweek : selected_favourite_date.tm_wday);
	gtk_combo_box_set_active(GTK_COMBO_BOX(glade_xml_get_widget(gxml, "favouriteChannelCombo")), 0);
	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "favouritePartialTitleButton")), fav != NULL ? fav->partial_title : FALSE);
	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "favouriteChannelButton")), fav != NULL && fav->channel != NULL);
	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "favouriteDayButton")), fav != NULL && fav->dayofweek >= 0);
	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "favouriteTimeButton")), fav != NULL && (fav->timeofday >= 0 || fav->time > 0));
	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "favouriteDateButton")), fav != NULL && fav->time > 0);
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "favouriteChannelCombo"), fav != NULL && fav->channel != NULL);
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "favouriteDayCombo"), fav != NULL && fav->dayofweek >= 0);
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "favouriteTimeCombo"), fav != NULL && (fav->timeofday >= 0 || fav->time > 0));
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "favouriteDateEditButton"), fav != NULL && fav->time > 0);
	strftime(time_str, 80, "%H:%M", &selected_favourite_date);
	gtk_entry_set_text(GTK_ENTRY(glade_xml_get_widget(gxml, "favouriteTimeEntry")), time_str);
	gtk_entry_set_text(GTK_ENTRY(glade_xml_get_widget(gxml, "favouriteTitleEntry")), fav != NULL ? fav->title : (prog != NULL ? prog->title : ""));
	if(fav == NULL || fav->reminder < 0) {
		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "favouriteDefaultReminderButton")), TRUE);
	} else if(fav->reminder == 0) {
		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "favouriteNoReminderButton")), TRUE);
	} else if(fav->reminder > 0) {
		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "favouriteCustomReminderButton")), TRUE);
	}
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "favouriteCustomReminderBox"), fav != NULL && fav->reminder > 0);
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "favouriteReminderDurationSpin"), (fav != NULL && fav->reminder > 0) ? (fav->reminder_duration > 0) : (reminder_duration > 0));
	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "favouriteReminderUntilEndButton")), (fav != NULL && fav->reminder > 0) ? (fav->reminder_duration < 0) : (reminder_duration < 0));
	gtk_spin_button_set_value(GTK_SPIN_BUTTON(glade_xml_get_widget(gxml, "favouriteReminderTimeSpin")), (fav != NULL && fav->reminder > 0) ? (double) fav->reminder_time : (double) reminder_time);
	gtk_spin_button_set_value(GTK_SPIN_BUTTON(glade_xml_get_widget(gxml, "favouriteReminderDurationSpin")), (fav != NULL && fav->reminder > 0) ? (fav->reminder_duration > 0 ? (double) fav->reminder_duration : fav->reminder_time + 1.0) : (reminder_duration > 0 ? (double) reminder_duration : reminder_time + 1.0));
	//Time and date
	strftime(time_str, 80, _("%F"), &selected_favourite_date);
	gtk_button_set_label(GTK_BUTTON(glade_xml_get_widget(gxml, "favouriteDateEditButton")), time_str);
	if(fav != NULL && fav->channel != NULL) {
		gint i = 0;
		gboolean b = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(favouriteChannelCombo_store), &iter);

		while(b) {
			gtk_tree_model_get(GTK_TREE_MODEL(favouriteChannelCombo_store), &iter, 1, &ch, -1);
			if(strcmp(ch->id, fav->channel) == 0) {
				gtk_combo_box_set_active(GTK_COMBO_BOX(glade_xml_get_widget(gxml, "favouriteChannelCombo")), i);
				break;
			}
			i++;
			b = gtk_tree_model_iter_next(GTK_TREE_MODEL(favouriteChannelCombo_store), &iter);
		}
	}
	if(fav == NULL || fav->record < 0) {
		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "favouriteDefaultRecordButton")), TRUE);
	} else if(fav->record == 0) {
		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "favouriteNoRecordButton")), TRUE);
	} else if(fav->record > 0) {
		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "favouriteCustomRecordButton")), TRUE);
	}
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "favouriteCustomRecordBox"), fav != NULL && fav->record > 0);
	gtk_spin_button_set_value(GTK_SPIN_BUTTON(glade_xml_get_widget(gxml, "favouriteStartMarginSpin")), (fav != NULL && fav->record > 0) ? (double) fav->record_start_margin : (double) start_margin);
	gtk_spin_button_set_value(GTK_SPIN_BUTTON(glade_xml_get_widget(gxml, "favouriteStopMarginSpin")), (fav != NULL && fav->record > 0) ? (double) fav->record_stop_margin : (double) stop_margin);
	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "favouritePrioritiseButton")), fav != NULL && fav->prioritise);
	while(gtk_dialog_run(GTK_DIALOG(favouriteDialog)) == 1) {
		gstr = g_strstrip(g_strdup(gtk_entry_get_text(GTK_ENTRY(glade_xml_get_widget(gxml, "favouriteTitleEntry")))));
		if(strlen(gstr) > 0) {
			if(fav != NULL)
				removeFavourite(fav);
			fav = gtvg_favourite_new();
			fav->title = gstr;
			fav->partial_title = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "favouritePartialTitleButton")));
			if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "favouriteChannelButton")))) {
				gtk_combo_box_get_active_iter(GTK_COMBO_BOX(glade_xml_get_widget(gxml, "favouriteChannelCombo")), &iter);
				gtk_tree_model_get(GTK_TREE_MODEL(favouriteChannelCombo_store), &iter, 1, &ch, -1);
				fav->channel = g_strdup(ch->id);
			}
			if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "favouriteDayButton")))) {
				fav->dayofweek = gtk_combo_box_get_active(GTK_COMBO_BOX(glade_xml_get_widget(gxml, "favouriteDayCombo")));
			}
			if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "favouriteDateButton")))) {
				fav->time = mktime(&selected_favourite_date);
			} else if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "favouriteTimeButton")))) {
				fav->timeofday = selected_favourite_date.tm_min * 60 + selected_favourite_date.tm_hour * 3600;
			}
			if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "favouriteNoReminderButton")))) {
				fav->reminder = 0;
			} else if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "favouriteCustomReminderButton")))) {
				fav->reminder = 1;
				fav->reminder_time = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(glade_xml_get_widget(gxml, "favouriteReminderTimeSpin")));
				if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "favouriteReminderUntilEndButton")))) {
					fav->reminder_duration = -1;
				} else {
					fav->reminder_duration = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(glade_xml_get_widget(gxml, "favouriteReminderDurationSpin")));
				}
			}
			if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "favouriteNoRecordButton")))) {
				fav->record = 0;
			} else if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "favouriteCustomRecordButton")))) {
				fav->record = 1;
				fav->record_start_margin = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(glade_xml_get_widget(gxml, "favouriteStartMarginSpin")));
				fav->record_stop_margin = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(glade_xml_get_widget(gxml, "favouriteStopMarginSpin")));
			}
			fav->prioritise = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "favouritePrioritiseButton")));
			addFavourite(fav);
			break;
		} else {
			GtkWidget *dialog = gtk_message_dialog_new(GTK_WINDOW(favouriteDialog), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, _("Empty program title"));

			gtk_dialog_run(GTK_DIALOG(dialog));
			gtk_widget_destroy(dialog);
			gtk_widget_grab_focus(glade_xml_get_widget(gxml, "favouriteTitleEntry"));
			g_free(gstr);
		}
	}
	gtk_widget_hide(favouriteDialog);
	g_free(time_str);

}

void newFavourite(void)
{
	editFavourite(NULL);
}

void on_removeFavouriteButton_clicked(GtkButton * w, gpointer user_data)
{
	GtkTreeSelection *selection;
	GtkTreeIter iter;
	GtkTreeModel *model;
	struct GtvgFavourite *fav;

	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "favouritesList_view")));
	if(gtk_tree_selection_get_selected(selection, &model, &iter)) {
		gtk_tree_model_get(model, &iter, FAVOURITES_OBJECT_COLUMN, &fav, -1);
		if(fav != NULL) {
			removeFavourite(fav);
		}
	}
}

void on_favouriteChannelButton_toggled(GtkToggleButton * w, gpointer user_data)
{
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "favouriteChannelCombo"), gtk_toggle_button_get_active(w));
}

void on_favouriteDayButton_toggled(GtkToggleButton * w, gpointer user_data)
{
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "favouriteDayCombo"), gtk_toggle_button_get_active(w));
	if(gtk_toggle_button_get_active(w)) {
		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "favouriteDateButton")), FALSE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "favouriteDateEditButton"), FALSE);
	}
}

void on_favouriteDateButton_toggled(GtkToggleButton * w, gpointer user_data)
{
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "favouriteDateEditButton"), gtk_toggle_button_get_active(w));
	if(gtk_toggle_button_get_active(w)) {
		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "favouriteDayButton")), FALSE);
		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "favouriteTimeButton")), TRUE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "favouriteDayCombo"), FALSE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "favouriteTimeCombo"), TRUE);
	}
}

void on_favouriteTimeButton_toggled(GtkToggleButton * w, gpointer user_data)
{
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "favouriteTimeCombo"), gtk_toggle_button_get_active(w));
	if(!gtk_toggle_button_get_active(w)) {
		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "favouriteDateButton")), FALSE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "favouriteDateEditButton"), FALSE);
	}
}

void on_favouriteDateEditButton_clicked(GtkButton * w, gpointer user_data)
{
	GtkWidget *calendar, *dialog, *box;
	guint y, m, d;
	gchar *time_str;

	dialog = gtk_dialog_new_with_buttons(_("Select Date"), GTK_WINDOW(glade_xml_get_widget(gxml, "favouriteDialog")), GTK_DIALOG_NO_SEPARATOR, GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT, NULL);
	calendar = gtk_calendar_new();
	gtk_calendar_select_month(GTK_CALENDAR(calendar), selected_favourite_date.tm_mon, selected_favourite_date.tm_year + 1900);
	gtk_calendar_select_day(GTK_CALENDAR(calendar), selected_favourite_date.tm_mday);
	gtk_container_set_border_width(GTK_CONTAINER(dialog), 6);
	box = gtk_hbox_new(FALSE, 12);
	gtk_container_set_border_width(GTK_CONTAINER(box), 6);
	gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox), box);
	gtk_box_pack_start(GTK_BOX(box), calendar, FALSE, TRUE, 0);
	gtk_widget_show_all(box);
	if(gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_ACCEPT) {
		y = (guint) selected_favourite_date.tm_year;
		m = (guint) selected_favourite_date.tm_mon;
		d = (guint) selected_favourite_date.tm_mday;
		gtk_calendar_get_date(GTK_CALENDAR(calendar), &y, &m, &d);
		selected_favourite_date.tm_year = (int) y;
		selected_favourite_date.tm_mon = (int) m;
		selected_favourite_date.tm_mday = (int) d;
		selected_favourite_date.tm_year -= 1900;
		time_str = g_strnfill(80, '\0');
		strftime(time_str, 80, _("%F"), &selected_favourite_date);
		gtk_button_set_label(GTK_BUTTON(glade_xml_get_widget(gxml, "favouriteDateEditButton")), time_str);
		g_free(time_str);
	}
	gtk_widget_destroy(dialog);
}

void on_favouriteReminderUntilEndButton_toggled(GtkToggleButton * w, gpointer user_data)
{
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "favouriteReminderDurationSpin"), !gtk_toggle_button_get_active(w));
}

void on_favouriteCustomReminderButton_toggled(GtkToggleButton * w, gpointer user_data)
{
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "favouriteCustomReminderBox"), gtk_toggle_button_get_active(w));
}

void on_favouriteCustomRecordButton_toggled(GtkToggleButton * w, gpointer user_data)
{
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "favouriteCustomRecordBox"), gtk_toggle_button_get_active(w));
}

void on_editFavouriteButton_clicked(GtkButton * w, gpointer user_data)
{
	GtkTreeSelection *selection;
	GtkTreeIter iter;
	GtkTreeModel *model;
	struct GtvgFavourite *fav;

	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "favouritesList_view")));
	if(gtk_tree_selection_get_selected(selection, &model, &iter)) {
		gtk_tree_model_get(model, &iter, FAVOURITES_OBJECT_COLUMN, &fav, -1);
		if(fav != NULL) {
			editFavourite(fav);
		}
	}
}

void on_newFavouriteButton_clicked(GtkButton * w, gpointer user_data)
{
	newFavourite();
}

void on_categoryNameEntry_changed(GtkEditable * editable, gpointer user_data)
{
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "categoryOKButton"), strlen(gtk_entry_get_text(GTK_ENTRY(editable))) > 0);
}

void on_categoryBackgroundButton_toggled(GtkToggleButton * w, gboolean b, gpointer user_data)
{
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "categoryBackgroundColorButton"), gtk_toggle_button_get_active(w));
}

void on_categoryTextButton_toggled(GtkToggleButton * w, gboolean b, gpointer user_data)
{
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "categoryTextColorButton"), gtk_toggle_button_get_active(w));
}

void unsetCategory(struct GtvgCategory *leader_cat)
{
	GSList *list, *list2, *list3;
	struct GtvgCategory *cat;

	list = leader_cat->original_names;
	while(list != NULL) {
		if(g_slist_find_custom(original_categories, (gchar *) list->data, gchar_compare_func) != NULL) {
			cat = gtvg_category_new();
			cat->name = g_strdup((gchar *) list->data);
			cat->original_names = g_slist_prepend(cat->original_names, g_strdup((gchar *) list->data));
			categories = g_slist_insert_sorted(categories, cat, categories_compare_func);
			list3 = programs;
			while(list3 != NULL) {
				struct GtvgProgram *prog = (struct GtvgProgram *) list3->data;

				list2 = prog->categories;
				while(list2 != NULL) {
					if(list2->data == leader_cat && g_slist_find_custom(prog->original_categories, list->data, gchar_compare_func) != NULL) {
						prog->categories = g_slist_append(prog->categories, cat);
						break;
					}
					list2 = g_slist_next(list2);
				}
				list3 = g_slist_next(list3);
			}
		}
		list = g_slist_next(list);
	}
	list3 = programs;
	while(list3 != NULL) {
		struct GtvgProgram *prog = (struct GtvgProgram *) list3->data;

		list2 = prog->categories;
		while(list2 != NULL) {
			if(list2->data == leader_cat) {
				prog->categories = g_slist_delete_link(prog->categories, list2);
				break;
			}
			list2 = g_slist_next(list2);
		}
		list3 = g_slist_next(list3);
	}
	categories = g_slist_remove(categories, leader_cat);
	updateCategoryList(NULL);
	updateProgramList();
	updateProgramGrid(FALSE);
}

void editCategory(void)
{
	GtkTreeSelection *selection;
	GtkTreeIter iter;
	GtkTreeModel *model;
	struct GtvgCategory *cat, *leader_cat = NULL;
	GList *selected, *sel_list;
	GSList *list, *edited_cats = NULL, *list2;
	GtkWidget *dialog;
	GString *str;
	gboolean b;
	gint retval;

	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "categoriesList_view")));
	selected = gtk_tree_selection_get_selected_rows(selection, &model);
	if(selected != NULL) {
		sel_list = selected;
		while(sel_list != NULL) {
			gtk_tree_model_get_iter(model, &iter, (GtkTreePath *) sel_list->data);
			gtk_tree_model_get(model, &iter, 1, &cat, -1);
			edited_cats = g_slist_append(edited_cats, cat);
			if(leader_cat == NULL && (cat->bg_color != NULL || cat->text_color != NULL || g_slist_length(cat->original_names) != 1 || strcmp(cat->name, (gchar *) cat->original_names->data) != 0)) {
				leader_cat = cat;
			}
			sel_list = g_list_next(sel_list);
		}
		if(leader_cat == NULL) {
			gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "categoryUnsetButton"), FALSE);
			leader_cat = (struct GtvgCategory *) edited_cats->data;
		} else {
			gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "categoryUnsetButton"), g_slist_length(edited_cats) == 1);
		}
		dialog = getCategoryDialog();
		str = g_string_new("");
		list = edited_cats;
		b = FALSE;
		while(list != NULL) {
			list2 = ((struct GtvgCategory *) list->data)->original_names;
			while(list2 != NULL) {
				if(b)
					g_string_append(str, ", ");
				else
					b = TRUE;
				g_string_append(str, (gchar *) list2->data);
				list2 = g_slist_next(list2);
			}
			list = g_slist_next(list);
		}
		gtk_label_set_text(GTK_LABEL(glade_xml_get_widget(gxml, "categoryOriginalNamesLabel")), str->str);
		gtk_entry_set_text(GTK_ENTRY(glade_xml_get_widget(gxml, "categoryNameEntry")), leader_cat->name);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "categoryOKButton"), strlen(gtk_entry_get_text(GTK_ENTRY(glade_xml_get_widget(gxml, "categoryNameEntry")))) > 0);
		if(leader_cat->bg_color != NULL) {
			gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "categoryBackgroundColorButton"), TRUE);
			gtk_color_button_set_color(GTK_COLOR_BUTTON(glade_xml_get_widget(gxml, "categoryBackgroundColorButton")), leader_cat->bg_color);
			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "categoryBackgroundButton")), TRUE);
		} else {
			GdkColor white;

			white.red = 65535;
			white.green = 65535;
			white.blue = 65535;
			gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "categoryBackgroundColorButton"), FALSE);
			gtk_color_button_set_color(GTK_COLOR_BUTTON(glade_xml_get_widget(gxml, "categoryBackgroundColorButton")), &white);
			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "categoryBackgroundButton")), FALSE);
		}
		if(leader_cat->text_color != NULL) {
			gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "categoryTextColorButton"), TRUE);
			gtk_color_button_set_color(GTK_COLOR_BUTTON(glade_xml_get_widget(gxml, "categoryTextColorButton")), leader_cat->text_color);
			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "categoryTextButton")), TRUE);
		} else {
			GdkColor black;

			black.red = 0;
			black.green = 0;
			black.blue = 0;
			gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "categoryTextColorButton"), FALSE);
			gtk_color_button_set_color(GTK_COLOR_BUTTON(glade_xml_get_widget(gxml, "categoryTextColorButton")), &black);
			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "categoryTextButton")), FALSE);
		}
		g_string_free(str, TRUE);
		retval = gtk_dialog_run(GTK_DIALOG(dialog));
		if(retval == 1) {
			cat = gtvg_category_new();
			cat->name = g_strdup(gtk_entry_get_text(GTK_ENTRY(glade_xml_get_widget(gxml, "categoryNameEntry"))));
			list = edited_cats;
			while(list != NULL) {
				list2 = ((struct GtvgCategory *) list->data)->original_names;
				while(list2 != NULL) {
					cat->original_names = g_slist_prepend(cat->original_names, g_strdup((gchar *) list2->data));
					list2 = g_slist_next(list2);
				}
				list = g_slist_next(list);
			}
			if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "categoryBackgroundButton")))) {
				cat->bg_color = g_slice_new(GdkColor);
				gtk_color_button_get_color(GTK_COLOR_BUTTON(glade_xml_get_widget(gxml, "categoryBackgroundColorButton")), cat->bg_color);
			}
			if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "categoryTextButton")))) {
				cat->text_color = g_slice_new(GdkColor);
				gtk_color_button_get_color(GTK_COLOR_BUTTON(glade_xml_get_widget(gxml, "categoryTextColorButton")), cat->text_color);
			}
			list = programs;
			while(list != NULL) {
				struct GtvgProgram *prog = (struct GtvgProgram *) list->data;
				gboolean b = FALSE;

				list2 = prog->categories;
				while(list2 != NULL) {
					if(list2->data != cat && g_slist_find(edited_cats, list2->data)) {
						if(!b) {
							list2->data = cat;
							b = TRUE;
							list2 = g_slist_next(list2);
						} else {
							prog->categories = g_slist_delete_link(prog->categories, list2);
							list2 = prog->categories;
						}
					} else {
						list2 = g_slist_next(list2);
					}
				}
				list = g_slist_next(list);
			}
			list = edited_cats;
			while(list != NULL) {
				gtvg_category_free((struct GtvgCategory *) list->data);
				categories = g_slist_remove(categories, list->data);
				list = g_slist_next(list);
			}
			categories = g_slist_insert_sorted(categories, cat, categories_compare_func);
			updateCategoryList(cat);
			updateProgramList();
			updateProgramGrid(FALSE);
		} else if(retval == 2) {
			unsetCategory(leader_cat);
		}
		gtk_widget_hide(dialog);
		g_list_foreach(selected, free_list_treepath, NULL);
		g_list_free(selected);
		g_slist_free(edited_cats);
	}
}

void on_editCategoryButton_clicked(GtkButton * w, gpointer user_data)
{
	editCategory();
}

void on_editCategoriesMenuItem_activate(GtkMenuItem * w, gpointer user_data)
{
	editCategory();
}

void on_unsetCategoriesMenuItem_activate(GtkMenuItem * w, gpointer user_data)
{
	GtkTreeSelection *selection;
	GtkTreeIter iter;
	GtkTreeModel *model;
	struct GtvgCategory *cat;
	GList *selected;

	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "categoriesList_view")));
	selected = gtk_tree_selection_get_selected_rows(selection, &model);
	if(selected != NULL) {
		selected = gtk_tree_selection_get_selected_rows(selection, &model);
		gtk_tree_model_get_iter(model, &iter, (GtkTreePath *) selected->data);
		gtk_tree_model_get(model, &iter, 1, &cat, -1);
		g_list_foreach(selected, free_list_treepath, NULL);
		g_list_free(selected);
		unsetCategory(cat);
	}
}

void on_blacklist_selection_changed(GtkTreeSelection * treeselection, gpointer user_data)
{
	GtkTreeIter iter;

	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "removeFromBlacklistButton"), gtk_tree_selection_get_selected(treeselection, NULL, &iter));
}

gboolean on_blacklist_view_button_press_event(GtkWidget * w, GdkEventButton * event, gpointer user_data)
{
	GtkTreePath *path;
	GtkTreeSelection *selection;

	if(event->type == GDK_BUTTON_PRESS && event->button == 3) {
		if(gtk_tree_view_get_path_at_pos(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "blacklist_view")), (gint) event->x, (gint) event->y, &path, NULL, NULL, NULL)) {
			selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "blacklist_view")));
			gtk_tree_selection_select_path(selection, path);
			gtk_tree_path_free(path);
		}
		return popup_blacklist_menu(event);
	}
	return FALSE;
}

gboolean on_blacklist_view_popup_menu(GtkWidget * w, gpointer user_data)
{
	return popup_blacklist_menu(NULL);
}

gboolean popup_blacklist_menu(GdkEventButton * event)
{
	GtkTreeSelection *selection;
	GtkTreeIter iter;
	GtkTreeModel *model;

	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "blacklist_view")));
	if(gtk_tree_selection_get_selected(selection, &model, &iter)) {
		gtk_menu_popup(GTK_MENU(glade_xml_get_widget(gxml, "blacklist_menu")), NULL, NULL, NULL, NULL, (event != NULL) ? event->button : 0, (event != NULL) ? gdk_event_get_time((GdkEvent *) event) : gtk_get_current_event_time());
		return TRUE;
	}
	return FALSE;
}

void removeTitleFavourites(gchar * title)
{
	GSList *list;
	struct GtvgFavourite *fav;

	list = favourites;
	while(list != NULL) {
		fav = (struct GtvgFavourite *) list->data;
		if(strcmp(title, fav->title) == 0) {
			removeFavourite(fav);
			list = favourites;
		} else {
			list = g_slist_next(list);
		}
	}
}

void removeProgramFavourites(struct GtvgProgram *prog)
{
	while(prog->favourites != NULL) {
		removeFavourite((struct GtvgFavourite *) prog->favourites->data);
	}
}

void on_addToBlacklistButton_clicked(GtkButton * w, gpointer user_data)
{
	GtkTreeIter iter;
	struct GtvgProgram *prog, *prog2;
	gboolean valid;
	GSList *list;

	prog = selectedProgram();
	if(prog == NULL)
		return;

	removeTitleFavourites(prog->title);
	blacklist = g_slist_insert_sorted(blacklist, prog->title, gchar_compare_func);
	gconf_client_set_list(client, "/apps/gtvg/blacklist", GCONF_VALUE_STRING, blacklist, NULL);
	valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(programList_store), &iter);
	while(valid) {
		gtk_tree_model_get(GTK_TREE_MODEL(programList_store), &iter, OBJECT_COLUMN, &prog2, -1);
		if(strcmp(prog->title, prog2->title) == 0) {
			if(iters_equal(GTK_TREE_MODEL(programList_store), &iter, first_nonpast_iter)) {
				gtk_list_store_remove(programList_store, &iter);
				gtk_tree_iter_free(first_nonpast_iter);
				if(gtk_list_store_iter_is_valid(programList_store, &iter)) {
					first_nonpast_iter = gtk_tree_iter_copy(&iter);
				} else {
					gtk_tree_iter_free(first_nonpast_iter);
					first_nonpast_iter = NULL;
				}
			} else {
				gtk_list_store_remove(programList_store, &iter);
			}
		}
		valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(programList_store), &iter);
	}
	list = programs;
	while(list != NULL) {
		prog2 = (struct GtvgProgram *) list->data;
		if(prog2->canvas_rect != NULL && strcmp(prog->title, prog2->title) == 0) {
			g_object_set(G_OBJECT(prog2->canvas_rect), "fill-color-gdk", NULL, NULL);
			if(prog2->canvas_text != NULL) {
				gridprog_items = g_slist_remove(gridprog_items, prog2->canvas_text);
				gtk_object_destroy(GTK_OBJECT(prog2->canvas_text));
				prog2->canvas_text = NULL;
			}
			if(prog2 == selected_gridprog) {
				selected_gridprog = NULL;
				gtk_text_buffer_set_text(gtk_text_view_get_buffer(GTK_TEXT_VIEW(glade_xml_get_widget(gxml, "gridDescriptionView"))), "", 0);
			}
		}
		list = g_slist_next(list);
	}

	updateBlacklist();
	programSelected(selectedProgram());
}

void removeFromBlacklist(gchar * gstr)
{
	GSList *list;

	list = g_slist_find_custom(blacklist, gstr, gchar_compare_func);
	if(list == NULL)
		return;
	blacklist = g_slist_delete_link(blacklist, list);
	gconf_client_set_list(client, "/apps/gtvg/blacklist", GCONF_VALUE_STRING, blacklist, NULL);
	updateProgramList();
	updateProgramGrid(FALSE);
	updateBlacklist();
}

void on_removeBlacklistMenuItem_activate(GtkMenuItem * w, gpointer user_data)
{
	on_removeFromBlacklistButton_clicked(NULL, NULL);
}

void on_removeFromBlacklistButton_clicked(GtkButton * w, gpointer user_data)
{
	GtkTreeSelection *selection;
	GtkTreeIter iter;
	GtkTreeModel *model;
	gchar *gstr;

	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "blacklist_view")));
	if(gtk_tree_selection_get_selected(selection, &model, &iter)) {
		gtk_tree_model_get(model, &iter, 0, &gstr, -1);
		if(gstr) {
			removeFromBlacklist(gstr);
			g_free(gstr);
		}
	}
}

void on_channelsList_selection_changed(GtkTreeSelection * treeselection, gpointer user_data)
{
	GtkTreeSelection *selection;

	updateProgramList();
	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "channelsList_view")));
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "allChannelsButton"), gtk_tree_selection_count_selected_rows(selection) > 0);
}

void on_categoriesList_selection_changed(GtkTreeSelection * treeselection, gpointer user_data)
{
	GtkTreeSelection *selection;
	gint selcount;
	GtkTreeIter iter;
	GtkTreeModel *model;
	struct GtvgCategory *cat;
	GList *selected;

	updateProgramList();
	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "categoriesList_view")));
	selcount = gtk_tree_selection_count_selected_rows(selection);
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "allCategoriesButton"), selcount > 0);
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "editCategoryButton"), selcount > 0);
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "editCategoriesMenuItem"), selcount > 0);
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "unsetCategoriesMenuItem"), FALSE);
	if(selcount == 1) {
		selected = gtk_tree_selection_get_selected_rows(selection, &model);
		if(selected != NULL) {
			gtk_tree_model_get_iter(model, &iter, (GtkTreePath *) selected->data);
			gtk_tree_model_get(model, &iter, 1, &cat, -1);
			if(cat->bg_color != NULL || cat->text_color != NULL || g_slist_length(cat->original_names) != 1 || strcmp(cat->name, (gchar *) cat->original_names->data) != 0) {
				gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "unsetCategoriesMenuItem"), TRUE);
			}
			g_list_foreach(selected, free_list_treepath, NULL);
			g_list_free(selected);
		}
	}
}

void on_channelsList_row_inserted(GtkTreeModel * model, GtkTreePath * path, GtkTreeIter * iter, gpointer user_data)
{
	channels_moved = TRUE;
	updateProgramGrid(TRUE);
}

gboolean on_channelsList_view_button_press_event(GtkWidget * w, GdkEventButton * event, gpointer user_data)
{
	GtkTreeSelection *selection;
	GtkTreePath *path;

	if(event->type == GDK_BUTTON_PRESS && event->button == 3) {
		if(gtk_tree_view_get_path_at_pos(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "channelsList_view")), (gint) event->x, (gint) event->y, &path, NULL, NULL, NULL)) {
			selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "channelsList_view")));
			g_signal_handlers_block_matched((gpointer) selection, G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_channelsList_selection_changed, NULL);
			gtk_tree_selection_unselect_all(selection);
			gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "allChannelsButton"), FALSE);
			g_signal_handlers_unblock_matched((gpointer) selection, G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_channelsList_selection_changed, NULL);
			gtk_tree_selection_select_path(selection, path);
			gtk_tree_path_free(path);
		}
		return popup_channelsList_menu(event);
	}
	return FALSE;
}

gboolean on_channelsList_view_popup_menu(GtkWidget * w, gpointer user_data)
{
	return popup_channelsList_menu(NULL);
}

gboolean popup_channelsList_menu(GdkEventButton * event)
{
	GtkTreeSelection *selection;

	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "channelsList_view")));
	if(gtk_tree_selection_count_selected_rows(selection) > 0) {
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "allChannelsMenuItem"), TRUE);
		if(gtk_tree_selection_count_selected_rows(selection) == 1) {
			gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "renameChannelMenuItem"), TRUE);
			gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "setChannelIconMenuItem"), TRUE);
		} else {
			gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "renameChannelMenuItem"), FALSE);
			gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "setChannelIconMenuItem"), FALSE);
		}
	} else {
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "allChannelsMenuItem"), FALSE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "renameChannelMenuItem"), FALSE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "setChannelIconMenuItem"), FALSE);
	}
	gtk_menu_popup(GTK_MENU(glade_xml_get_widget(gxml, "channelsList_menu")), NULL, NULL, NULL, NULL, (event != NULL) ? event->button : 0, (event != NULL) ? gdk_event_get_time((GdkEvent *) event) : gtk_get_current_event_time());
	return TRUE;
}

void on_allChannelsMenuItem_activate(GtkMenuItem * w, gpointer user_data)
{
	GtkTreeSelection *selection;

	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "channelsList_view")));
	gtk_tree_selection_unselect_all(selection);
}

void on_allChannelsButton_clicked(GtkButton * w, gpointer user_data)
{
	GtkTreeSelection *selection;

	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "channelsList_view")));
	gtk_tree_selection_unselect_all(selection);
}

void on_updateChannelIconsMenuItem_activate(GtkMenuItem * w, gpointer user_data)
{
	updateChannelIcons();
}

void on_renameEntry_changed(GtkEditable * editable, gpointer user_data)
{
	GtkWidget *dialog = (GtkWidget *) user_data;

	gtk_dialog_set_response_sensitive(GTK_DIALOG(dialog), GTK_RESPONSE_ACCEPT, strlen(gtk_entry_get_text(GTK_ENTRY(editable))) > 0);
}

void on_renameChannelMenuItem_activate(GtkMenuItem * w, gpointer user_data)
{
	GtkWidget *dialog, *entry, *box;
	const gchar *new_name;
	GtkTreeSelection *selection;
	GList *selected_rows;
	GtkTreePath *path;
	GtkTreeIter iter;
	struct GtvgChannel *ch;

	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "channelsList_view")));
	selected_rows = gtk_tree_selection_get_selected_rows(selection, NULL);
	if(selected_rows == NULL || g_list_length(selected_rows) != 1) {
		if(selected_rows != NULL) {
			g_list_foreach(selected_rows, free_list_treepath, NULL);
			g_list_free(selected_rows);
		}
		return;
	}
	path = (GtkTreePath *) selected_rows->data;
	gtk_tree_model_get_iter(GTK_TREE_MODEL(channelsList_store), &iter, path);
	g_list_foreach(selected_rows, free_list_treepath, NULL);
	g_list_free(selected_rows);

	gtk_tree_model_get(GTK_TREE_MODEL(channelsList_store), &iter, CHANNELS_OBJECT_COLUMN, &ch, -1);

	dialog = gtk_dialog_new_with_buttons(_("Rename channel"), GTK_WINDOW(window), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, NULL);
	gtk_dialog_set_has_separator(GTK_DIALOG(dialog), FALSE);
	gtk_container_set_border_width(GTK_CONTAINER(dialog), 6);
	box = gtk_hbox_new(FALSE, 12);
	gtk_container_set_border_width(GTK_CONTAINER(box), 6);
	gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox), box);
	entry = gtk_entry_new();
	gtk_entry_set_text(GTK_ENTRY(entry), ch->name);
	on_renameEntry_changed(GTK_EDITABLE(entry), dialog);
	g_signal_connect(G_OBJECT(entry), "changed", G_CALLBACK(on_renameEntry_changed), dialog);
	gtk_box_pack_start(GTK_BOX(box), gtk_label_new(_("New name:")), FALSE, TRUE, 0);
	gtk_box_pack_end(GTK_BOX(box), entry, TRUE, TRUE, 0);
	gtk_widget_show_all(box);

	if(gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_ACCEPT) {
		new_name = gtk_entry_get_text(GTK_ENTRY(entry));
		if(new_name != NULL && strlen(new_name) > 0) {
			if(ch->name)
				g_free(ch->name);
			ch->name = g_strdup(new_name);
			ch->custom_name = TRUE;
			channels = g_slist_sort(channels, channels_compare_func);
			gtk_list_store_set(channelsList_store, &iter, CHANNELS_NAME_COLUMN, new_name, -1);
			updateChannelList();
			updateProgramList();
			updateProgramGrid(TRUE);
		}
	}

	gtk_widget_destroy(dialog);

}

void on_setChannelIconMenuItem_activate(GtkMenuItem * w, gpointer user_data)
{

	GtkWidget *dialog;
	GtkFileFilter *filter;
	gchar *filename;
	GtkTreeSelection *selection;
	GList *selected_rows;
	GtkTreePath *path;
	GtkTreeIter iter;
	struct GtvgChannel *ch;

	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "channelsList_view")));
	selected_rows = gtk_tree_selection_get_selected_rows(selection, NULL);
	if(selected_rows == NULL || g_list_length(selected_rows) != 1) {
		if(selected_rows != NULL) {
			g_list_foreach(selected_rows, free_list_treepath, NULL);
			g_list_free(selected_rows);
		}
		return;
	}
	path = (GtkTreePath *) selected_rows->data;
	gtk_tree_model_get_iter(GTK_TREE_MODEL(channelsList_store), &iter, path);
	g_list_foreach(selected_rows, free_list_treepath, NULL);
	g_list_free(selected_rows);

	gtk_tree_model_get(GTK_TREE_MODEL(channelsList_store), &iter, CHANNELS_OBJECT_COLUMN, &ch, -1);

	dialog = gtk_file_chooser_dialog_new("Select Channel Image", GTK_WINDOW(window), GTK_FILE_CHOOSER_ACTION_OPEN, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT, NULL);
	filter = gtk_file_filter_new();
	gtk_file_filter_set_name(filter, _("Images"));
	gtk_file_filter_add_mime_type(filter, "image/gif");
	gtk_file_filter_add_mime_type(filter, "image/jpeg");
	gtk_file_filter_add_mime_type(filter, "image/png");
	gtk_file_chooser_add_filter(GTK_FILE_CHOOSER(dialog), filter);

	if(gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_ACCEPT) {
		filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(dialog));
		if(ch->icon != NULL)
			g_object_unref(ch->icon);
		if(ch->iconpath != NULL)
			g_free(ch->iconpath);
		ch->icon = gdk_pixbuf_new_from_file_at_scale(filename, -1, 22, TRUE, NULL);
		ch->iconpath = filename;
		ch->custom_icon = TRUE;
		gtk_list_store_set(channelsList_store, &iter, CHANNELS_ICON_COLUMN, ch->icon, -1);
		updateProgramGrid(TRUE);
	}

	gtk_widget_destroy(dialog);

}

gboolean on_categoriesList_view_button_press_event(GtkWidget * w, GdkEventButton * event, gpointer user_data)
{
	GtkTreeSelection *selection;
	GtkTreePath *path;

	if(event->type == GDK_BUTTON_PRESS && event->button == 3) {
		if(gtk_tree_view_get_path_at_pos(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "categoriesList_view")), (gint) event->x, (gint) event->y, &path, NULL, NULL, NULL)) {
			selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "categoriesList_view")));
			gtk_tree_selection_select_path(selection, path);
			gtk_tree_path_free(path);
		}
		return popup_categoriesList_menu(event);
	}
	return FALSE;
}

gboolean on_categoriesList_view_popup_menu(GtkWidget * w, gpointer user_data)
{
	return popup_categoriesList_menu(NULL);
}

gboolean popup_categoriesList_menu(GdkEventButton * event)
{
	GtkTreeSelection *selection;

	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "categoriesList_view")));
	if(gtk_tree_selection_count_selected_rows(selection) > 0) {
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "allCategoriesMenuItem"), TRUE);
	} else {
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "allCategoriesMenuItem"), FALSE);
	}
	gtk_menu_popup(GTK_MENU(glade_xml_get_widget(gxml, "categoriesList_menu")), NULL, NULL, NULL, NULL, (event != NULL) ? event->button : 0, (event != NULL) ? gdk_event_get_time((GdkEvent *) event) : gtk_get_current_event_time());
	return TRUE;
}

void on_allCategoriesMenuItem_activate(GtkMenuItem * w, gpointer user_data)
{
	GtkTreeSelection *selection;

	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "categoriesList_view")));
	gtk_tree_selection_unselect_all(selection);
}

void on_allCategoriesButton_clicked(GtkButton * w, gpointer user_data)
{
	GtkTreeSelection *selection;

	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "categoriesList_view")));
	gtk_tree_selection_unselect_all(selection);
}

void on_searchButton_clicked(GtkButton * w, gpointer user_data)
{
	updateProgramList();
}

void on_clearSearchButton_clicked(GtkButton * w, gpointer user_data)
{
	gtk_entry_set_text(GTK_ENTRY(searchEntry), "");
}

void on_searchEntry_activate(GtkEntry * entry, gpointer user_data)
{
	updateProgramList();
	gtk_editable_select_region(GTK_EDITABLE(entry), 0, -1);
}

gboolean on_searchEntry_focus_out(GtkWidget * w, GdkEventFocus * event, gpointer user_data)
{
	updateProgramList();
	gtk_editable_select_region(GTK_EDITABLE(w), 0, -1);
	return FALSE;
}

void on_searchEntry_changed(GtkEditable * entry, gpointer user_data)
{
	gboolean b = strlen(gtk_entry_get_text(GTK_ENTRY(entry))) > 0;

	gtk_widget_set_sensitive(clearSearchButton, b);
	gtk_widget_set_sensitive(searchButton, b);
	if(!b)
		updateProgramList();
}

void on_closeToolbutton_clicked(GtkToolButton * w, gpointer user_data)
{
	closeWindow();
}

void on_closeMenuItem_activate(GtkMenuItem * w, gpointer user_data)
{
	closeWindow();
}

void on_quitMenuItem_activate(GtkMenuItem * w, gpointer user_data)
{
	on_quit();
}

void on_updateToolbutton_clicked(GtkToolButton * w, gpointer user_data)
{
	updateXMLTVFile(TRUE);
}

void on_updateMenuItem_activate(GtkMenuItem * w, gpointer user_data)
{
	updateXMLTVFile(TRUE);
}

void editPreferences(void)
{
	configure(FALSE);
}

void on_preferencesToolbutton_clicked(GtkToolButton * w, gpointer user_data)
{
	editPreferences();
}

void on_preferencesMenuItem_activate(GtkMenuItem * w, gpointer user_data)
{
	editPreferences();
}

void on_showFavouritesButton_toggled(GtkToggleButton * w, gboolean b, gpointer user_data)
{
	updateProgramList();
}

void on_hidePastButton_toggled(GtkToggleButton * w, gboolean b, gpointer user_data)
{
	updateProgramList();
}

void on_dayCombo_changed(GtkComboBox * w, gpointer user_data)
{
	GtkTreeIter iter;
	long curday;

	if(gtk_combo_box_get_active_iter(w, &iter)) {
		gtk_tree_model_get(GTK_TREE_MODEL(dayCombo_store), &iter, 1, &curday, -1);
		if(curday <= 0) {
			all_days = TRUE;
			updateProgramList();
		} else if(current_day == curday) {
			all_days = FALSE;
			updateProgramList();
		} else {
			all_days = FALSE;
			current_day = curday;
			if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "hidePastButton"))) && current_day <= time(NULL) - 86400) {
				g_signal_handlers_block_matched((gpointer) glade_xml_get_widget(gxml, "hidePastButton"), G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_hidePastButton_toggled, NULL);
				gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "hidePastButton")), FALSE);
				g_signal_handlers_unblock_matched((gpointer) glade_xml_get_widget(gxml, "hidePastButton"), G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_hidePastButton_toggled, NULL);
			}
			currentDayChanged();
		}
	}
}

void on_aboutMenuItem_activate(GtkMenuItem * w, gpointer user_data)
{
	gchar *authors[] = { "Niklas Knutsson <nq@altern.org>", NULL };
	gchar *license = _("This program is free software; you can redistribute it and/or\n" "modify it under the terms of the GNU General Public License\n" "as published by the Free Software Foundation; either version 2\n" "of the License, or (at your option) any later version.\n" "\n" "This program is distributed in the hope that it will be useful,\n" "but WITHOUT ANY WARRANTY; without even the implied warranty of\n" "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n" "GNU General Public License for more details.\n" "\n" "You should have received a copy of the GNU General Public License\n" "along with this program; if not, write to the Free Software\n" "Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.");

	gtk_show_about_dialog(NULL, "name", _("gTVG TV Guide"), "comments", _("Check what's on TV"), "title", _("About TV Guide"), "copyright", "Copyright @ 2007 Niklas Knutsson", "translator-credits", _("translator-credits"), "license", license, "authors", authors, "website", "http://gtvg.sourceforge.net/", "version", VERSION, NULL);
}

gboolean checkProgramTimes(gpointer user_data)
{
	GtkTreeIter iter;
	GtkTreeModel *model;
	gboolean valid;
	gchar *gstr;
	time_t curtime;
	gboolean first_iter, show_info, b;
	struct stat buf;
	struct GtvgFavourite *fav;
	struct GtvgProgram *prog;
	GConfValue *gvalue;
	GtkWidget *dialog = NULL;
	GSList *list;

	if(update_in_progress || loading_xmltv)
		return TRUE;

	gvalue = gconf_client_get(client, "/apps/gtvg/xmltv_file", NULL);
	if(gvalue != NULL && g_stat(gconf_value_get_string(gvalue), &buf) == 0) {
		if(xml_load_time != buf.st_mtime) {
			show_info = GTK_WIDGET_VISIBLE(window);
			if(show_info) {
				dialog = gtk_message_dialog_new(GTK_WINDOW(window), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_INFO, GTK_BUTTONS_NONE, "Reloading updated TV listings");
				gtk_widget_show(dialog);
				while(gtk_events_pending())
					gtk_main_iteration();
			}
			loadXMLTV(FALSE);
			if(show_info) {
				gtk_widget_destroy(dialog);
			}
			checkFavourites(NULL);
			g_timeout_add_full(G_PRIORITY_DEFAULT_IDLE, (guint) (60 - (time(NULL) % 60)) * 1000, checkProgramTimes, NULL, NULL);
			return FALSE;
		}
	}
	if(gvalue != NULL)
		gconf_value_free(gvalue);

	if(time(NULL) >= tomorrow_time) {
		if(current_day + 86400 == tomorrow_time && !GTK_WIDGET_VISIBLE(window)) {
			current_day = tomorrow_time;
			currentDayChanged();
		}
		tomorrow_time += 86400;
		updateDays();
	}

	checkFavourites(user_data);

	updateTooltip();

	if(!GTK_WIDGET_VISIBLE(window)) {
		g_timeout_add_full(G_PRIORITY_DEFAULT_IDLE, (guint) (60 - (time(NULL) % 60)) * 1000, checkProgramTimes, NULL, NULL);
		return FALSE;
	}

	curtime = time(NULL);
	if(prevtime > curtime) {
		//time gone backwards, reload
		prevtime = curtime;
		loadXMLTV(FALSE);
		checkFavourites(NULL);
		g_timeout_add_full(G_PRIORITY_DEFAULT_IDLE, (guint) (60 - (time(NULL) % 60)) * 1000, checkProgramTimes, NULL, NULL);
		return FALSE;
	}
	prevtime = curtime;

	updateGridTime(FALSE, FALSE);

	model = gtk_tree_view_get_model(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "programList_view")));
	valid = (first_nonpast_iter != NULL);
	if(valid)
		iter = *first_nonpast_iter;
	first_iter = TRUE;
	while(valid) {
		gtk_tree_model_get(model, &iter, OBJECT_COLUMN, &prog, -1);
		if(prog->stop <= curtime) {
			if(first_iter)
				gtk_tree_iter_free(first_nonpast_iter);
			b = gtk_list_store_remove(GTK_LIST_STORE(model), &iter);
			list = prog->favourites;
			while(list != NULL) {
				fav = (struct GtvgFavourite *) list->data;
				if(fav->time > 0) {
					removeFavourite(fav);
					list = prog->favourites;
				} else {
					list = g_slist_next(list);
				}
			}
			if(!b) {
				if(first_iter) {
					first_nonpast_iter = NULL;
				}
				break;
			}
			if(first_iter) {
				first_nonpast_iter = gtk_tree_iter_copy(&iter);
			}
		} else if(prog->start > curtime) {
			break;
		} else {
			if(curtime == prog->start) {
				gstr = g_strdup_printf(_("%li:%.2li"), (long) 0, (long) 0);
				gtk_list_store_set(GTK_LIST_STORE(model), &iter, PROGRESS_COLUMN, 0, PROGRESS_TEXT_COLUMN, gstr, -1);
			} else {
				gstr = g_strdup_printf(_("%li:%.2li"), (long) (curtime - prog->start) / 3600, (long) ((curtime - prog->start) % 3600) / 60);
				gtk_list_store_set(GTK_LIST_STORE(model), &iter, PROGRESS_COLUMN, ((curtime - prog->start) * 100) / (prog->stop - prog->start), PROGRESS_TEXT_COLUMN, gstr, -1);
			}
			g_free(gstr);
			valid = gtk_tree_model_iter_next(model, &iter);
			first_iter = FALSE;
		}
	}

	g_timeout_add_full(G_PRIORITY_DEFAULT_IDLE, (guint) (60 - (time(NULL) % 60)) * 1000, checkProgramTimes, NULL, NULL);
	return FALSE;
}

extern gint channels_compare_func(gconstpointer a, gconstpointer b);

gint prog_list_sort_on_channel(gconstpointer a, gconstpointer b)
{
	return channels_compare_func(((struct GtvgProgram *) a)->channel, ((struct GtvgProgram *) b)->channel);
}

void updateTooltip(void)
{

	time_t curtime;
	gboolean first = TRUE;
	struct GtvgProgram *prog;
	GSList *list = status_list, *list2;
	GSList *curlist = NULL;
	GString *tooltip;
	gchar *gstr;
	gint index = 0, current_total = 0;

	if(!gtk_status_icon_get_visible(status_icon))
		return;

	tooltip = g_string_sized_new(tooltip_length);
	g_string_append(tooltip, _("gTVG TV Guide"));
	curtime = time(NULL);
	first = TRUE;
	while(list != NULL) {
		prog = (struct GtvgProgram *) list->data;
		if(prog->start > curtime) {
			break;
		} else if(prog->stop > curtime && g_slist_find_custom(blacklist, prog->title, gchar_compare_func) == NULL) {
			curlist = g_slist_prepend(curlist, prog);
			if(first) {
				status_list = list;
				first = FALSE;
			}
		}
		list = g_slist_next(list);
	}
	if(curlist != NULL) {
		curlist = g_slist_sort(curlist, prog_list_sort_on_channel);
		g_string_append(tooltip, "\n");
	}
	list2 = curlist;
	first = TRUE;
	while(list2 != NULL && (current_tooltip_items < 0 || index < current_tooltip_items)) {
		prog = (struct GtvgProgram *) list2->data;
		g_string_append(tooltip, "\n");
		first = FALSE;
		if(curtime == prog->start) {
			gstr = g_strdup_printf(_("%li:%.2li"), (long) 0, (long) 0);
		} else {
			gstr = g_strdup_printf(_("%li:%.2li"), (long) (curtime - prog->start) / 3600, (long) ((curtime - prog->start) % 3600) / 60);
		}
		g_string_append(tooltip, gstr);
		g_free(gstr);
		gstr = g_strdup_printf(_("%li:%.2li"), (long) (prog->stop - curtime) / 3600, (long) ((prog->stop - curtime) % 3600) / 60);
		g_string_append(tooltip, " (-");
		g_string_append(tooltip, gstr);
		g_string_append(tooltip, ") ");
		g_free(gstr);
		g_string_append(tooltip, "\t");
		if(strlen(prog->title) > 40) {
			gstr = g_strndup(prog->title, 37);
			g_string_append(tooltip, gstr);
			g_free(gstr);
			g_string_append(tooltip, "...");
		} else {
			g_string_append(tooltip, prog->title);
		}
		if(strlen(prog->title) + strlen(prog->channel->name) > 40) {
			g_string_append(tooltip, "\n\t\t\t(");
			if(strlen(prog->channel->name) > 40) {
				gstr = g_strndup(prog->channel->name, 37);
				g_string_append(tooltip, gstr);
				g_free(gstr);
				g_string_append(tooltip, "...");
			} else {
				g_string_append(tooltip, prog->channel->name);
			}
		} else {
			g_string_append(tooltip, " (");
			g_string_append(tooltip, prog->channel->name);
		}
		g_string_append(tooltip, ")");
		index++;
		current_total++;
		list2 = g_slist_next(list2);
	}
	if(list != NULL && !first)
		g_string_append(tooltip, "\n");
	if(curlist != NULL)
		g_slist_free(curlist);

	index = 0;
	while(list != NULL && index < future_tooltip_items) {
		prog = (struct GtvgProgram *) list->data;
		if(g_slist_find_custom(blacklist, prog->title, gchar_compare_func) == NULL) {
			first = FALSE;
			g_string_append(tooltip, "\n-");
			if(curtime == prog->start) {
				gstr = g_strdup_printf(_("%li:%.2li"), (long) 0, (long) 0);
			} else {
				gstr = g_strdup_printf(_("%li:%.2li"), (long) (prog->start - curtime) / 3600, (long) ((prog->start - curtime) % 3600) / 60);
			}
			g_string_append(tooltip, gstr);
			g_free(gstr);
			gstr = g_strdup_printf(_("%li:%.2li"), (long) (prog->stop - prog->start) / 3600, (long) ((prog->stop - prog->start) % 3600) / 60);
			g_string_append(tooltip, " (");
			g_string_append(tooltip, gstr);
			g_string_append(tooltip, ") ");
			g_free(gstr);
			g_string_append(tooltip, "\t");
			if(strlen(prog->title) > 40) {
				gstr = g_strndup(prog->title, 37);
				g_string_append(tooltip, gstr);
				g_free(gstr);
				g_string_append(tooltip, "...");
			} else {
				g_string_append(tooltip, prog->title);
			}
			if(strlen(prog->title) + strlen(prog->channel->name) > 40) {
				g_string_append(tooltip, "\n\t\t\t(");
				if(strlen(prog->channel->name) > 40) {
					gstr = g_strndup(prog->channel->name, 37);
					g_string_append(tooltip, gstr);
					g_free(gstr);
					g_string_append(tooltip, "...");
				} else {
					g_string_append(tooltip, prog->channel->name);
				}
			} else {
				g_string_append(tooltip, " (");
				g_string_append(tooltip, prog->channel->name);
			}
			g_string_append(tooltip, ")");
			index++;
			current_total++;
		}
		list = g_slist_next(list);
	}
	if(tooltip->len > tooltip_length)
		tooltip_length = tooltip->len;
	gtk_status_icon_set_tooltip(status_icon, tooltip->str);
	g_string_free(tooltip, TRUE);
}

void on_notification_closed(NotifyNotification * notification, gpointer user_data)
{
	GSList *list;
	struct favourite_schedule *favsched = (struct favourite_schedule *) user_data;

	if(notifying_favscheds != NULL) {
		list = g_slist_find(notifying_favscheds, favsched);
		if(list != NULL)
			notifying_favscheds = g_slist_delete_link(notifying_favscheds, list);
	}
	free_favsched(favsched);
}

gboolean on_notification_timeout(gpointer user_data)
{
	gchar *desc;
	gchar *title_str;
	gchar *gstr;
	gint timeout;
	time_t curtime;
	gint timeleft;
	GSList *list;

	if(loading_xmltv)
		return FALSE;

	curtime = time(NULL);
	struct favourite_schedule *favsched = (struct favourite_schedule *) user_data;

	if(!reminders_enabled) {
		notify_notification_close(favsched->notification, NULL);
		if(notifying_favscheds != NULL) {
			list = g_slist_find(notifying_favscheds, favsched);
			if(list != NULL)
				notifying_favscheds = g_slist_delete_link(notifying_favscheds, list);
		}
		free_favsched(favsched);
		return FALSE;
	}
	gstr = createDescription(favsched->prog, TRUE, NULL);
	desc = g_markup_escape_text(gstr, -1);
	g_free(gstr);
	if(favsched->prog->subtitle != NULL) {
		//[title]: [subtitle]
		gstr = g_strdup_printf(_("%s: %s"), favsched->prog->title, favsched->prog->subtitle);
		title_str = g_markup_escape_text(gstr, -1);
		g_free(gstr);
	} else {
		title_str = g_markup_escape_text(favsched->prog->title, -1);
	}
	notify_notification_update(favsched->notification, title_str, desc, favsched->prog->channel->iconpath);
	g_free(title_str);
	g_free(desc);
	timeleft = favsched->prog->start - curtime;
	if(favsched->fav->reminder > 0) {
		if(favsched->fav->reminder_duration > 0) {
			timeout = timeleft + (favsched->fav->reminder_duration - favsched->fav->reminder_time) * 60;
		} else {
			timeout = favsched->prog->stop - curtime;
		}
	} else {
		if(reminder_duration > 0) {
			timeout = timeleft + (reminder_duration - reminder_time) * 60;
		} else {
			timeout = favsched->prog->stop - curtime;
		}
	}
	if(timeout <= 0) {
		notify_notification_close(favsched->notification, NULL);
		if(notifying_favscheds != NULL) {
			list = g_slist_find(notifying_favscheds, favsched);
			if(list != NULL)
				notifying_favscheds = g_slist_delete_link(notifying_favscheds, list);
		}
		free_favsched(favsched);
		return FALSE;
	}
	notify_notification_set_timeout(favsched->notification, timeout * 1000);
	notify_notification_show(favsched->notification, NULL);
	if(timeleft <= 0) {
		return FALSE;
	} else if(timeleft < 62) {
		g_timeout_add_full(G_PRIORITY_DEFAULT_IDLE - 1, 1000, on_notification_timeout, (gpointer) favsched, NULL);
	} else {
		g_timeout_add_full(G_PRIORITY_DEFAULT_IDLE - 1, (guint) (60 - (time(NULL) % 60)) * 1000, on_notification_timeout, (gpointer) favsched, NULL);
	}
	return FALSE;
}

void updateWakeupTime(void)
{
	struct record_schedule *recsched;
	GSList *list = record_schedules;

	wakeup_recsched = NULL;
	if(!wakeup_enabled)
		return;

	list = record_schedules;
	while(list) {
		recsched = (struct record_schedule *) list->data;
		if(recsched->start_time > time(NULL) + 60) {
			wakeup_recsched = recsched;
			setWakeupTime(recsched->start_time - 60);
			break;
		}
		list = g_slist_next(list);
	}
}

void setWakeupTime(time_t wakeup_time)
{
	GError *error = NULL;
	gchar *command_str = g_strdup_printf("nvram-wakeup -s %li", (glong) time);

	if(!g_spawn_command_line_sync(command_str, NULL, NULL, NULL, &error)) {
		GtkWidget *dialog = gtk_message_dialog_new(GTK_WINDOW(window), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, _("Error setting wakeup time (using %s): %s"), command_str, error->message);

		gtk_dialog_run(GTK_DIALOG(dialog));
		gtk_widget_destroy(dialog);
	}
	g_free(command_str);
}

gchar *parseRecordCommand(const gchar * command, struct record_schedule *recsched)
{
	gchar **gstrv;
	size_t i = 0;
	GString *str = g_string_new("");

	if(command == NULL)
		return g_string_free(str, FALSE);
	gstrv = g_strsplit(command, "%", 100);
	while(gstrv[i] != NULL) {
		if(strlen(gstrv[i]) > 0) {
			if(i > 0) {
				switch (gstrv[i][0]) {
					case 'p':{
							g_string_append(str, recsched->prog->title);
							if(strlen(gstrv[i]) > 1)
								g_string_append(str, gstrv[i] + 1);
							break;
						}
					case 'c':{
							g_string_append(str, recsched->prog->channel->name);
							if(strlen(gstrv[i]) > 1)
								g_string_append(str, gstrv[i] + 1);
							break;
						}
					case 'i':{
							g_string_append(str, recsched->prog->channel->id);
							if(strlen(gstrv[i]) > 1)
								g_string_append(str, gstrv[i] + 1);
							break;
						}
					case 'l':{
							g_string_append_printf(str, "%li", recsched->stop_time - time(NULL));
							if(strlen(gstrv[i]) > 1)
								g_string_append(str, gstrv[i] + 1);
							break;
						}
					case 'd':{
							gchar *time_str = g_strnfill(20, '\0');

							strftime(time_str, 40, "%Y%m%d", &recsched->prog->start_tm);
							g_string_append(str, time_str);
							g_free(time_str);
							if(strlen(gstrv[i]) > 1)
								g_string_append(str, gstrv[i] + 1);
							break;
						}
					case 't':{
							gchar *time_str = g_strnfill(20, '\0');

							strftime(time_str, 40, "%H%M%S", &recsched->prog->start_tm);
							g_string_append(str, time_str);
							g_free(time_str);
							if(strlen(gstrv[i]) > 1)
								g_string_append(str, gstrv[i] + 1);
							break;
						}
					default:{
							g_string_append(str, gstrv[i]);
						}
				}
			} else {
				g_string_append(str, gstrv[i]);
			}
		}
		i++;
	}
	g_strfreev(gstrv);
	return g_string_free(str, FALSE);
}

void stopRecording(void)
{
	current_record_stop_time = 0;
	if(current_record_title != NULL) {
		g_free(current_record_title);
		current_record_title = NULL;
	}
	if(current_record_channel != NULL) {
		g_free(current_record_channel);
		current_record_channel = NULL;
	}
	current_record_prog = NULL;
	if(current_reccom_file != NULL) {
		g_free(current_reccom_file);
		g_unlink(current_reccom_file);
		current_reccom_file = NULL;
	}
	if(current_record_stop_command != NULL) {
		GError *error = NULL;
		gchar *tmpfile = NULL;
		gchar *command = NULL;
		gint tmpfd = g_file_open_tmp("gtvg-reccom-XXXXXX", &tmpfile, NULL);

		if(tmpfd >= 0) {
			write(tmpfd, current_record_stop_command, strlen(current_record_stop_command));
			fsync(tmpfd);
			close(tmpfd);
			command = g_strdup_printf("sh \"%s\"", tmpfile);
			if(!g_spawn_command_line_sync(command, NULL, NULL, NULL, &error)) {
				GtkWidget *dialog = gtk_message_dialog_new(GTK_WINDOW(window), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, _("Error stopping recording (using %s): %s"), current_record_stop_command, error->message);

				gtk_dialog_run(GTK_DIALOG(dialog));
				gtk_widget_destroy(dialog);
			}
			g_unlink(tmpfile);
			g_free(command);
		} else {
			if(!g_spawn_command_line_sync(current_record_stop_command, NULL, NULL, NULL, &error)) {
				GtkWidget *dialog = gtk_message_dialog_new(GTK_WINDOW(window), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, _("Error stopping recording (using %s): %s"), current_record_stop_command, error->message);

				gtk_dialog_run(GTK_DIALOG(dialog));
				gtk_widget_destroy(dialog);
			}
		}
		if(tmpfile != NULL)
			g_free(tmpfile);
		g_free(current_record_stop_command);
		current_record_stop_command = NULL;
	}
}

gboolean on_stopRecording_timeout(gpointer user_data)
{
	if(time(NULL) >= current_record_stop_time) {
		stopRecording();
		updateWakeupTime();
		if(record_schedules != NULL) {
			struct record_schedule *recsched = (struct record_schedule *) record_schedules->data;

			if(time(NULL) >= recsched->start_time - 1) {
				if(rec_timeout_running)
					g_source_remove(rec_timeout_id);
				rec_timeout_running = FALSE;
				on_startRecording_timeout(NULL);
			} else {
				rec_timeout_running = TRUE;
				rec_timeout_id = g_timeout_add((guint) (recsched->start_time - time(NULL) - 1) * 1000, on_startRecording_timeout, NULL);
				if(in_sleep_mode && recsched->start_time > time(NULL) + 600)
					suspendComputer();
			}
		}
	} else {
		long timeout = ((long) current_record_stop_time - time(NULL)) - 1;

		if(timeout <= 0)
			timeout = 1;
		g_timeout_add((guint) timeout * 1000, on_stopRecording_timeout, NULL);
	}
	return FALSE;
}

gboolean on_startRecording_timeout(gpointer user_data)
{
	struct record_schedule *recsched = (struct record_schedule *) record_schedules->data;

	rec_timeout_running = FALSE;
	if(current_record_stop_time == 0 && time(NULL) >= recsched->start_time - 2) {
		GError *error = NULL;
		gchar *command = NULL;
		gchar *gstr = parseRecordCommand(start_recording_command, recsched);
		gint tmpfd;

		current_reccom_file = NULL;
		tmpfd = g_file_open_tmp("gtvg-reccom-XXXXXX", &current_reccom_file, NULL);
		if(tmpfd >= 0) {
			write(tmpfd, gstr, strlen(gstr));
			fsync(tmpfd);
			close(tmpfd);
			command = g_strdup_printf("sh \"%s\"", current_reccom_file);
			if(!g_spawn_command_line_async(command, &error)) {
				GtkWidget *dialog = gtk_message_dialog_new(GTK_WINDOW(window), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, _("Error starting recording (using %s): %s"), gstr, error->message);

				gtk_dialog_run(GTK_DIALOG(dialog));
				gtk_widget_destroy(dialog);
			}
			g_free(command);
		} else {
			if(!g_spawn_command_line_async(gstr, &error)) {
				GtkWidget *dialog = gtk_message_dialog_new(GTK_WINDOW(window), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, _("Error starting recording (using %s): %s"), gstr, error->message);

				gtk_dialog_run(GTK_DIALOG(dialog));
				gtk_widget_destroy(dialog);
			}
		}
		g_free(gstr);
		current_record_stop_time = recsched->stop_time;
		current_record_program_stop = recsched->prog->stop;
		current_record_title = g_strdup(recsched->prog->title);
		current_record_channel = g_strdup(recsched->prog->channel->name);
		current_record_prog = recsched->prog;
		if(stop_recording_command != NULL && strlen(stop_recording_command) > 0) {
			current_record_stop_command = parseRecordCommand(stop_recording_command, recsched);
		}
		record_schedules = g_slist_delete_link(record_schedules, record_schedules);
		free_recsched(recsched);
		g_timeout_add((guint) (current_record_stop_time - time(NULL)) * 1000, on_stopRecording_timeout, NULL);
	} else {
		long timeout = ((long) recsched->start_time - time(NULL)) - 1;

		rec_timeout_running = TRUE;
		if(timeout <= 0)
			timeout = 1;
		rec_timeout_id = g_timeout_add((guint) timeout * 1000, on_startRecording_timeout, recsched);
	}
	return FALSE;
}

gboolean checkFavourites(gpointer user_data)
{

	time_t curtime;
	struct favourite_schedule *favsched;
	gchar *desc = NULL;
	gchar *title_str = NULL, *gstr;
	gint timeout, timeleft;
	GSList *list;
	gboolean show_reminder;

	if(update_in_progress || loading_xmltv)
		return TRUE;
	curtime = time(NULL);

	list = disabled_record_schedules;
	while(list != NULL) {
		struct record_schedule *recsched = (struct record_schedule *) list->data;

		if(recsched->start_time > curtime) {
			break;
		} else if(curtime >= recsched->prog->stop) {
			disabled_record_schedules = g_slist_delete_link(disabled_record_schedules, list);
			list = disabled_record_schedules;
		} else {
			list = g_slist_next(list);
		}
	}

	while(favourite_schedules != NULL) {
		favsched = (struct favourite_schedule *) favourite_schedules->data;
		if(favsched->prog->start - (favsched->fav->reminder < 0 ? reminder_time * 60 : favsched->fav->reminder_time * 60) <= curtime) {
			show_reminder = (reminders_enabled && favsched->fav->reminder < 0) || (favsched->fav->reminder > 0);
			if(!show_reminder && (!notify_sound_regardless || !notify_sound)) {
				favourite_schedules = g_slist_delete_link(favourite_schedules, favourite_schedules);
				free_favsched(favsched);
			} else {
				timeout = favsched->prog->start;
				if(favsched->fav->reminder > 0) {
					if(favsched->fav->reminder_duration <= 0) {
						timeout = favsched->prog->stop;
					} else if(favsched->fav->reminder_duration > favsched->fav->reminder_time) {
						timeout += (favsched->fav->reminder_duration - favsched->fav->reminder_time) * 60;
					}
				} else if(reminder_duration > reminder_time) {
					timeout += (reminder_duration - reminder_time) * 60;
				}
				if(timeout < curtime) {
					favourite_schedules = g_slist_delete_link(favourite_schedules, favourite_schedules);
					free_favsched(favsched);
				} else {
					if(show_reminder) {
						gstr = createDescription(favsched->prog, TRUE, NULL);
						desc = g_markup_escape_text(gstr, -1);
						g_free(gstr);
						if(favsched->prog->subtitle != NULL) {
							//[title]: [subtitle]
							gstr = g_strdup_printf(_("%s: %s"), favsched->prog->title, favsched->prog->subtitle);
							title_str = g_markup_escape_text(gstr, -1);
							g_free(gstr);
						} else {
							title_str = g_markup_escape_text(favsched->prog->title, -1);
						}
					}
					if(notify_sound) {
						if(notify_sound_file == NULL) {
							gdk_beep();
						} else {
#ifdef HAVE_LIBGNOME
							gnome_sound_play(notify_sound_file);
#endif
						}
					}
					if(show_reminder) {
						if(gtk_status_icon_get_visible(status_icon)) {
							favsched->notification = notify_notification_new_with_status_icon(title_str, desc, favsched->prog->channel->iconpath, status_icon);
						} else {
							favsched->notification = notify_notification_new(title_str, desc, favsched->prog->channel->iconpath, NULL);
						}
						g_signal_connect(G_OBJECT(favsched->notification), "closed", G_CALLBACK(on_notification_closed), (gpointer) favsched);
						g_free(title_str);
						g_free(desc);
						timeleft = favsched->prog->start - curtime;
						if(favsched->fav->reminder > 0) {
							if(favsched->fav->reminder_duration > 0) {
								timeout = timeleft + (favsched->fav->reminder_duration - favsched->fav->reminder_time) * 60;
							} else {
								timeout = favsched->prog->stop - curtime;
							}
						} else {
							if(reminder_duration > 0) {
								timeout = timeleft + (reminder_duration - reminder_time) * 60;
							} else {
								timeout = favsched->prog->stop - curtime;
							}
						}
						if(timeout <= 0)
							timeout = 60;
						notify_notification_set_timeout(favsched->notification, timeout * 1000);
						notify_notification_show(favsched->notification, NULL);
						favourite_schedules = g_slist_delete_link(favourite_schedules, favourite_schedules);
						notifying_favscheds = g_slist_prepend(notifying_favscheds, favsched);
						if(timeleft <= 0) {
						} else if(timeleft < 62) {
							g_timeout_add_full(G_PRIORITY_DEFAULT_IDLE - 1, 1000, on_notification_timeout, (gpointer) favsched, NULL);
						} else {
							g_timeout_add_full(G_PRIORITY_DEFAULT_IDLE - 1, (guint) (60 - (time(NULL) % 60)) * 1000, on_notification_timeout, (gpointer) favsched, NULL);
						}
					} else {
						favourite_schedules = g_slist_delete_link(favourite_schedules, favourite_schedules);
						free_favsched(favsched);
					}
				}
			}
		} else {
			break;
		}
	}

	return TRUE;
}

void on_fileButton_clicked(GtkButton * w, gpointer user_data)
{
	GtkWidget *fileChooser;
	gchar *filename;

	fileChooser = gtk_file_chooser_dialog_new(_("Select File"), GTK_WINDOW(glade_xml_get_widget(gxml, "configurationDialog")), GTK_FILE_CHOOSER_ACTION_SAVE, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, NULL);
	gtk_file_chooser_select_filename(GTK_FILE_CHOOSER(fileChooser), gtk_entry_get_text(GTK_ENTRY(glade_xml_get_widget(gxml, "fileEntry"))));
	if(gtk_dialog_run(GTK_DIALOG(fileChooser)) == GTK_RESPONSE_ACCEPT) {
		filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(fileChooser));
		gtk_entry_set_text(GTK_ENTRY(glade_xml_get_widget(gxml, "fileEntry")), filename);
		g_free(filename);
	}
	gtk_widget_destroy(fileChooser);
}

void on_grabCommandCombo_changed(GtkComboBox * w, gpointer user_data)
{
	GtkTreeIter iter;
	gchar *gstr, *gstr2;
	gint index, i;

	index = gtk_combo_box_get_active(w);

	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "commandEntry"), index > 0);
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "commandLabel"), index > 0);
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "daysSpin"), index > 0);
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "slowButton"), index > 0);
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "daysLabel"), index > 0);
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "offsetSpin"), index > 0);
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "offsetLabel"), index > 0);
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "configureInfoLabel"), index > 0);
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "configureXMLTVButton"), index > 0);

	if(index == 1) {
		gtk_widget_show(glade_xml_get_widget(gxml, "commandEntry"));
		gtk_widget_show(glade_xml_get_widget(gxml, "commandLabel"));
		gtk_widget_hide(glade_xml_get_widget(gxml, "daysSpin"));
		gtk_widget_hide(glade_xml_get_widget(gxml, "daysLabel"));
		gtk_widget_hide(glade_xml_get_widget(gxml, "slowButton"));
		gtk_widget_hide(glade_xml_get_widget(gxml, "offsetSpin"));
		gtk_widget_hide(glade_xml_get_widget(gxml, "offsetLabel"));
		gtk_widget_hide(glade_xml_get_widget(gxml, "configureInfoLabel"));
		gtk_widget_hide(glade_xml_get_widget(gxml, "configureXMLTVButton"));
	} else if(index > 1 && gtk_combo_box_get_active_iter(w, &iter)) {
		gtk_widget_hide(glade_xml_get_widget(gxml, "commandEntry"));
		gtk_widget_hide(glade_xml_get_widget(gxml, "commandLabel"));
		gtk_widget_show(glade_xml_get_widget(gxml, "daysSpin"));
		gtk_widget_show(glade_xml_get_widget(gxml, "daysLabel"));
		gtk_widget_show(glade_xml_get_widget(gxml, "slowButton"));
		gtk_widget_show(glade_xml_get_widget(gxml, "offsetSpin"));
		gtk_widget_show(glade_xml_get_widget(gxml, "offsetLabel"));
		gtk_widget_show(glade_xml_get_widget(gxml, "configureInfoLabel"));
		gtk_widget_show(glade_xml_get_widget(gxml, "configureXMLTVButton"));
		gtk_tree_model_get(gtk_combo_box_get_model(GTK_COMBO_BOX(glade_xml_get_widget(gxml, "grabCommandCombo"))), &iter, 1, &gstr, -1);
		i = 0;
		while(grabbers[i] != NULL) {
			if(strcmp(grabbers[i], gstr) == 0) {
				gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "slowButton"), grabber_supports_slow[i]);
				break;
			}
			i++;
		}
		gstr2 = g_strconcat(g_get_home_dir(), G_DIR_SEPARATOR_S ".xmltv" G_DIR_SEPARATOR_S, gstr, ".xmltv", NULL);
		gtk_entry_set_text(GTK_ENTRY(glade_xml_get_widget(gxml, "fileEntry")), gstr2);
		g_free(gstr);
		g_free(gstr2);
	}
}

void on_status_icon_activated(GtkStatusIcon * w, gpointer user_data)
{
	if((gdk_window_get_state(GTK_WIDGET(window)->window) & GDK_WINDOW_STATE_ICONIFIED) || !GTK_WIDGET_VISIBLE(window)) {
		restore_position();
		gtk_window_present(GTK_WINDOW(window));
	} else {
		save_position();
		gtk_widget_hide(window);
	}
}

void on_status_icon_popup_menu(GtkStatusIcon * w, guint button, guint activate_time, gpointer user_data)
{
	gtk_menu_popup(GTK_MENU(glade_xml_get_widget(gxml, "statusMenu")), NULL, NULL, NULL, NULL, button, activate_time);
}

void on_disableStatusMenuItem_activate(GtkMenuItem * w, gpointer user_data)
{
	gconf_client_set_bool(client, "/apps/gtvg/show_in_notification_area", FALSE, NULL);
}

void closeWindow(void)
{
	if(gtk_status_icon_get_visible(status_icon)) {
		save_position();
		gtk_widget_hide(glade_xml_get_widget(gxml, "gtvgWindow"));
	} else {
		on_quit();
	}
}

void on_window_shown(GtkWidget * w, gpointer user_data)
{
	checkProgramTimes(FALSE);
	updateGridTime(FALSE, TRUE);
}

void on_toolbarMenuItem_toggled(GtkCheckMenuItem * w, gpointer user_data)
{
	gconf_client_set_bool(client, "/apps/gtvg/show_toolbar", gtk_check_menu_item_get_active(w), NULL);
}

void on_menubarMenuItem_toggled(GtkCheckMenuItem * w, gpointer user_data)
{
	gconf_client_set_bool(client, "/apps/gtvg/show_menubar", gtk_check_menu_item_get_active(w), NULL);
}

void on_menubarToolbutton_toggled(GtkToggleToolButton * w, gpointer user_data)
{
	gconf_client_set_bool(client, "/apps/gtvg/show_menubar", gtk_toggle_tool_button_get_active(w), NULL);
}

void on_gconf_notify(GConfClient * c, guint cnxn_id, GConfEntry * entry, gpointer user_data)
{
	const char *key;
	GConfValue *value;
	gboolean b;

	key = gconf_entry_get_key(entry);
	value = gconf_entry_get_value(entry);
	if(strcmp(key, "/apps/gtvg/reminder_time") == 0) {
		reminder_time = gconf_value_get_int(value);
		favourite_schedules = g_slist_sort(favourite_schedules, favsched_compare_func);
	} else if(strcmp(key, "/apps/gtvg/reminder_duration") == 0) {
		reminder_duration = gconf_value_get_int(value);
	} else if(strcmp(key, "/apps/gtvg/reminders_enabled") == 0) {
		reminders_enabled = gconf_value_get_bool(value);
	} else if(strcmp(key, "/apps/gtvg/play_reminder_sound") == 0) {
		notify_sound = gconf_value_get_bool(value);
	} else if(strcmp(key, "/apps/gtvg/always_play_reminder_sound") == 0) {
		notify_sound_regardless = gconf_value_get_bool(value);
	} else if(strcmp(key, "/apps/gtvg/reminder_sound_file") == 0) {
		if(notify_sound_file != NULL) {
			g_free(notify_sound_file);
			notify_sound_file = NULL;
		}
		if(strlen(gconf_value_get_string(value)) > 0)
			notify_sound_file = g_strdup(gconf_value_get_string(value));
	} else if(strcmp(key, "/apps/gtvg/show_reminder_details") == 0) {
		reminder_details = gconf_value_get_bool(value);
	} else if(strcmp(key, "/apps/gtvg/current_programs_in_tooltip") == 0) {
		current_tooltip_items = gconf_value_get_int(value);
		updateTooltip();
	} else if(strcmp(key, "/apps/gtvg/upcoming_programs_in_tooltip") == 0) {
		future_tooltip_items = gconf_value_get_int(value);
		updateTooltip();
	} else if(strcmp(key, "/apps/gtvg/recordings_enabled") == 0) {
		recordings_enabled = gconf_value_get_bool(value);
		updateWakeupTime();
	} else if(strcmp(key, "/apps/gtvg/ask_if_record") == 0) {
		ask_record = gconf_value_get_bool(value);
	} else if(strcmp(key, "/apps/gtvg/wakeup_enabled") == 0) {
		wakeup_enabled = gconf_value_get_bool(value);
		updateWakeupTime();
	} else if(strcmp(key, "/apps/gtvg/record_start_margin") == 0) {
		start_margin = gconf_value_get_int(value);
		record_schedules = g_slist_sort(record_schedules, recsched_compare_func);
		updateWakeupTime();
	} else if(strcmp(key, "/apps/gtvg/record_stop_margin") == 0) {
		stop_margin = gconf_value_get_int(value);
	} else if(strcmp(key, "/apps/gtvg/show_description") == 0) {
		gtk_expander_set_expanded(GTK_EXPANDER(glade_xml_get_widget(gxml, "descriptionExpander")), gconf_value_get_bool(value));
	} else if(strcmp(key, "/apps/gtvg/show_in_notification_area") == 0) {
		b = gconf_value_get_bool(value);
		if(b != gtk_status_icon_get_visible(status_icon)) {
			if(b) {
				gtk_status_icon_set_visible(status_icon, TRUE);
				updateTooltip();
			} else {
				gtk_status_icon_set_visible(status_icon, FALSE);
				restore_position();
				gtk_window_present(GTK_WINDOW(window));
			}
		}
	} else if(strcmp(key, "/desktop/gnome/interface/toolbar_style") == 0) {
		set_toolbar_style(gconf_value_get_string(value));
	} else if(strcmp(key, "/apps/gtvg/show_toolbar") == 0) {
		b = gconf_value_get_bool(value);
		g_signal_handlers_block_matched((gpointer) glade_xml_get_widget(gxml, "toolbarMenuItem"), G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_toolbarMenuItem_toggled, NULL);
		gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(glade_xml_get_widget(gxml, "toolbarMenuItem")), b);
		g_signal_handlers_unblock_matched((gpointer) glade_xml_get_widget(gxml, "toolbarMenuItem"), G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_toolbarMenuItem_toggled, NULL);
		if(b) {
			gtk_widget_show(glade_xml_get_widget(gxml, "toolbar"));
		} else {
			gtk_widget_hide(glade_xml_get_widget(gxml, "toolbar"));
			if(!GTK_WIDGET_VISIBLE(glade_xml_get_widget(gxml, "menubar"))) {
				gconf_client_set_bool(client, "/apps/gtvg/show_menubar", TRUE, NULL);
			}
		}
	} else if(strcmp(key, "/apps/gtvg/show_menubar") == 0) {
		b = gconf_value_get_bool(value);
		g_signal_handlers_block_matched((gpointer) glade_xml_get_widget(gxml, "menubarMenuItem"), G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_menubarMenuItem_toggled, NULL);
		gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(glade_xml_get_widget(gxml, "menubarMenuItem")), b);
		g_signal_handlers_unblock_matched((gpointer) glade_xml_get_widget(gxml, "menubarMenuItem"), G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_menubarMenuItem_toggled, NULL);
		if(b) {
			gtk_widget_show(glade_xml_get_widget(gxml, "menubar"));
			gtk_widget_hide(glade_xml_get_widget(gxml, "menubarToolbutton"));
		} else {
			gtk_widget_hide(glade_xml_get_widget(gxml, "menubar"));
			if(!GTK_WIDGET_VISIBLE(glade_xml_get_widget(gxml, "toolbar"))) {
				gconf_client_set_bool(client, "/apps/gtvg/show_toolbar", TRUE, NULL);
			}
			g_signal_handlers_block_matched((gpointer) glade_xml_get_widget(gxml, "menubarToolbutton"), G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_menubarToolbutton_toggled, NULL);
			gtk_toggle_tool_button_set_active(GTK_TOGGLE_TOOL_BUTTON(glade_xml_get_widget(gxml, "menubarToolbutton")), FALSE);
			g_signal_handlers_unblock_matched((gpointer) glade_xml_get_widget(gxml, "menubarToolbutton"), G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_menubarToolbutton_toggled, NULL);
			gtk_widget_show(glade_xml_get_widget(gxml, "menubarToolbutton"));
		}
	} else if(strcmp(key, "/apps/gtvg/show_grid") == 0) {
		b = gconf_value_get_bool(value);
		g_signal_handlers_block_matched((gpointer) glade_xml_get_widget(gxml, "viewPages"), G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_viewPages_switch_page, NULL);
		gtk_notebook_set_current_page(GTK_NOTEBOOK(glade_xml_get_widget(gxml, "viewPages")), b ? 1 : 0);
		g_signal_handlers_unblock_matched((gpointer) glade_xml_get_widget(gxml, "viewPages"), G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_viewPages_switch_page, NULL);
	}
}

gboolean on_window_state_event(GtkWidget * widget, GdkEvent * event, gpointer user_data)
{
	if((event->type) == (GDK_WINDOW_STATE)) {
		GdkWindowState changed = ((GdkEventWindowState *) event)->changed_mask, state = ((GdkEventWindowState *) event)->new_window_state;

		if(changed == GDK_WINDOW_STATE_MAXIMIZED && !(state & GDK_WINDOW_STATE_WITHDRAWN)) {
			if(state & GDK_WINDOW_STATE_MAXIMIZED) {
				gconf_client_set_bool(client, "/apps/gtvg/last_window_maximized", TRUE, NULL);
			} else {
				gconf_client_set_bool(client, "/apps/gtvg/last_window_maximized", FALSE, NULL);
			}
		}
		if(state & GDK_WINDOW_STATE_ICONIFIED)
			session_set_cmd(NULL, MAINWINDOW_ICONIFIED);
		else if(state & GDK_WINDOW_STATE_WITHDRAWN)
			session_set_cmd(NULL, MAINWINDOW_HIDDEN);
		else
			session_set_cmd(NULL, MAINWINDOW_SHOWN);
	}
	return FALSE;
}

void save_position(void)
{

	GtkWidget *pane;
	gint x, y, w, h;

	if(!GTK_WIDGET_VISIBLE(window)) {
		return;
	}

	if(gconf_client_get_bool(client, "/apps/gtvg/last_window_maximized", NULL)) {
		return;
	}

	gtk_window_get_position(GTK_WINDOW(window), &x, &y);
	gtk_window_get_size(GTK_WINDOW(window), &w, &h);

	if(x + w < 0 || y + h < 0 || x > gdk_screen_width() || y > gdk_screen_height())
		return;

	/* save window position */
	gconf_client_set_int(client, "/apps/gtvg/last_window_x", x, NULL);
	gconf_client_set_int(client, "/apps/gtvg/last_window_y", y, NULL);

	/* save window size */
	gconf_client_set_int(client, "/apps/gtvg/last_window_width", w, NULL);
	gconf_client_set_int(client, "/apps/gtvg/last_window_height", h, NULL);

	/* save pane proportions */
	if(NULL != (pane = glade_xml_get_widget(gxml, "programListPanels")) && gtk_expander_get_expanded(GTK_EXPANDER(glade_xml_get_widget(gxml, "descriptionExpander")))) {
		x = gtk_paned_get_position(GTK_PANED(pane));
		gconf_client_set_int(client, "/apps/gtvg/last_hpane_pos", x, NULL);
	}
	if(NULL != (pane = glade_xml_get_widget(gxml, "programGridPanels"))) {
		x = gtk_paned_get_position(GTK_PANED(pane));
		gconf_client_set_int(client, "/apps/gtvg/last_gridpane_pos", x, NULL);
	}

}

void restore_position(void)
{
	/* load window position */
	int x, y, w, h;

	x = gconf_client_get_int(client, "/apps/gtvg/last_window_x", NULL);
	y = gconf_client_get_int(client, "/apps/gtvg/last_window_y", NULL);

	w = gconf_client_get_int(client, "/apps/gtvg/last_window_width", NULL);
	h = gconf_client_get_int(client, "/apps/gtvg/last_window_height", NULL);

	/* Restore position only if the width and height were saved */
	if(w != 0 && h != 0) {

		if(x >= gdk_screen_width()) {
			x = gdk_screen_width() - 100;
		} else if(x + w < 0) {
			x = 100;
		}

		if(y >= gdk_screen_height()) {
			y = gdk_screen_height() - 100;
		} else if(y + w < 0) {
			y = 100;
		}

		gtk_window_move(GTK_WINDOW(window), x, y);

		/* load window size */
		gtk_window_resize(GTK_WINDOW(window), w, h);
	}

	if(gconf_client_get_bool(client, "/apps/gtvg/last_window_maximized", NULL)) {
		gtk_window_maximize(GTK_WINDOW(window));
	} else {
		gtk_window_unmaximize(GTK_WINDOW(window));
	}

}

void set_toolbar_style(const gchar * toolbar_style)
{
	if(toolbar_style == NULL)	/* default to icons */
		gtk_toolbar_set_style(GTK_TOOLBAR(glade_xml_get_widget(gxml, "toolbar")), GTK_TOOLBAR_ICONS);
	else if(!strcmp(toolbar_style, "text"))
		gtk_toolbar_set_style(GTK_TOOLBAR(glade_xml_get_widget(gxml, "toolbar")), GTK_TOOLBAR_TEXT);
	else if(!strcmp(toolbar_style, "both"))
		gtk_toolbar_set_style(GTK_TOOLBAR(glade_xml_get_widget(gxml, "toolbar")), GTK_TOOLBAR_BOTH);
	else if(!strcmp(toolbar_style, "both_horiz") || !strcmp(toolbar_style, "both-horiz"))
		gtk_toolbar_set_style(GTK_TOOLBAR(glade_xml_get_widget(gxml, "toolbar")), GTK_TOOLBAR_BOTH_HORIZ);
	else			/* default to icons */
		gtk_toolbar_set_style(GTK_TOOLBAR(glade_xml_get_widget(gxml, "toolbar")), GTK_TOOLBAR_ICONS);
}
