
/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */

/*
 * main.c
 * Copyright (C) Niklas Knutsson 2007 <nq@altern.org>
 * 
 * main.c is free software.
 * 
 * You may redistribute it and/or modify it under the terms of the
 * GNU General Public License, as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option)
 * any later version.
 * 
 * main.c is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with main.c.  If not, write to:
 * 	The Free Software Foundation, Inc.,
 * 	51 Franklin Street, Fifth Floor
 * 	Boston, MA  02110-1301, USA.
 */

#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <string.h>
#include <stdio.h>
#include <langinfo.h>
#ifndef __USE_XOPEN
#define __USE_XOPEN
#include <time.h>
#undef __USE_XOPEN
#else
#include <time.h>
#endif
#ifndef __USE_ISOC99
#define __USE_ISOC99
#include <math.h>
#undef __USE_ISOC99
#else
#include <math.h>
#endif

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gdk-pixbuf/gdk-pixbuf.h>
#include <gdk/gdkkeysyms.h>
#include <glib/gstdio.h>
#include <gtk/gtk.h>
#include <glade/glade.h>
#include <libnotify/notify.h>
#include <libgnomecanvas/libgnomecanvas.h>
#ifdef HAVE_LIBGNOME
#include <libgnome/libgnome.h>
#endif
#include <dbus/dbus-glib.h>

#include <libxml/parser.h>

#include "callbacks.h"
#include "session.h"

#include "bacon-message-connection.h"

#include "e-icon-entry.h"

static BaconMessageConnection *bacon_connection = NULL;

GtkListStore *programList_store = NULL, *channelsList_store = NULL, *favouritesList_store = NULL, *blacklist_store = NULL, *categoriesList_store = NULL;
GtkListStore *grabCommandCombo_store = NULL, *dayCombo_store = NULL, *favouriteDayCombo_store = NULL, *favouriteChannelCombo_store = NULL, *recordPresetsCombo_store = NULL, *recordScheduleList_store;
GladeXML *gxml;
GConfClient *client;
GtkStatusIcon *status_icon;
GtkWidget *window;
GtkWidget *searchEntry, *searchButton, *clearSearchButton;

GSList *favourites = NULL, *blacklist = NULL;
GSList *favourite_schedules = NULL, *notifying_favscheds = NULL, *record_schedules = NULL, *disabled_record_schedules = NULL;
GSList *channels = NULL;
GHashTable *channel_hash;
GSList *programs = NULL;
GSList *categories = NULL;
GSList *original_categories = NULL;
GSList *status_list = NULL;
gboolean reminders_enabled, reminder_details;
gint reminder_time, reminder_duration;
GtkTreeIter *first_nonpast_iter = NULL;
time_t xml_load_time = 0;
time_t first_day = 0, last_day = 0, current_day = 0;
gboolean all_days = FALSE;
time_t tomorrow_time;
gboolean asked_if_download = FALSE;
gboolean loading_xmltv = FALSE;
gboolean channels_moved = FALSE;
GSList *gridch_items = NULL;
GSList *gridprog_items = NULL;
GSList *gridtime_items = NULL;
GSList *gridnw_items = NULL;
GSList *current_gridprogs = NULL;
gboolean pending_grid_updates = FALSE;
gboolean pending_grid_update_channels = FALSE;
gboolean pending_gridtime_updates = FALSE;
gboolean pending_list_updates = FALSE;
struct GtvgProgram *selected_gridprog = NULL;
GnomeCanvasItem *past_backdrop_item = NULL;
GnomeCanvasItem *future_backdrop_item = NULL;
GnomeCanvasItem *past_timebackdrop_item = NULL;
GnomeCanvasItem *future_timebackdrop_item = NULL;
GnomeCanvasItem *current_marker_item = NULL;
GnomeCanvasItem *current_timemarker_item = NULL;
gdouble channel_height = 54.0;
gdouble channel_width = 66.0;
gdouble channel_margin = 6.0;
gdouble channel_icon_x_margin = 12.0;
gdouble channel_icon_y_margin = 6.0;
gdouble progstart_y = 2.0;
gdouble progstart_x = 2.0;
gdouble text_margin = 4.0;
gdouble top_text_margin = 6.0;
gdouble time_compression = 12.0;
gdouble time_height = 20.0;
gdouble scroll_x = 0.0;
time_t prevtime;
gboolean notify_sound = FALSE, notify_sound_regardless = FALSE;
gchar *notify_sound_file = NULL;
struct record_schedule *wakeup_recsched = NULL;
gboolean wakeup_enabled = FALSE, recordings_enabled = FALSE, ask_record = FALSE;
gchar *start_recording_command = NULL, *stop_recording_command = NULL;
gint start_margin = 0, stop_margin = 0;
guint gconf_notify_id = 0;
time_t current_record_stop_time = 0;
gchar *current_record_stop_command = NULL;
gchar *current_record_title = NULL;
gchar *current_record_channel = NULL;
time_t current_record_program_stop = 0;
struct GtvgProgram *current_record_prog = NULL;
gboolean grid_at_current = FALSE;
gboolean can_display_heart, can_display_star;
gboolean rec_timeout_running = FALSE;
guint rec_timeout_id = 0;
gint day_starts_at = 360;
gint future_tooltip_items = 10;
gint current_tooltip_items = 20;
DBusGConnection *connection = NULL;
DBusGProxy *proxy = NULL;
gboolean in_sleep_mode = FALSE, can_suspend = FALSE;

GdkColor future_bg_color, past_bg_color;
GdkColor default_bg_color, selected_bg_color, favourite_bg_color, current_bg_color;
GdkColor default_border_color, selected_border_color, favourite_border_color, current_border_color;
GdkColor default_text_color, selected_text_color, favourite_text_color, current_text_color;

void updateProgramList(void);
void updateProgramGrid(gboolean update_channels);

#define GLADE_FILE PACKAGE_DATA_DIR "/gtvg/glade/gtvg.glade"

static const char *grabber_names[] = {
	N_("Argentina"),
	N_("Australia"),
	N_("Belgium and Luxemburg"),
	N_("Brazil"),
	N_("Brazil Cable"),
	N_("Switzerland (alt.)"),
	N_("Switzerland Bluewin"),
	N_("Switzerland Search"),
	N_("Czech Republic"),
	N_("Germany"),
	N_("Denmark"),
	N_("Latin America (Direct TV)"),
	N_("Estonia"),
	N_("Spain"),
	N_("Spain (alt.)"),
	N_("Finland"),
	N_("France"),
	N_("Croatia"),
	"tv_grab_huro",
	N_("Israel"),
	N_("Iceland"),
	N_("Italy"),
	N_("Japan"),
	N_("North America using DataDirect"),
	N_("Nouvelle Caledonie"),
	N_("Netherlands"),
	N_("Netherlands (alt.)"),
	N_("Norway"),
	N_("Norway (alt.)"),
	N_("Portugal"),
	N_("Reunion Island"),
	N_("Sweden"),
	N_("Brittain (alt.)"),
	N_("Brittain (alt. 2)"),
	N_("South Africa"),
	NULL
};

void progColor(struct GtvgProgram *prog, GdkColor ** bg_color, GdkColor ** fg_color)
{
	GSList *list2 = prog->categories;
	struct GtvgCategory *cat;

	while(list2 != NULL) {
		cat = (struct GtvgCategory *) list2->data;
		if(cat->text_color != NULL || cat->bg_color != NULL) {
			if(bg_color != NULL)
				*bg_color = cat->bg_color;
			if(fg_color != NULL)
				*fg_color = cat->text_color;
			return;
		}
		list2 = g_slist_next(list2);
	}
	if(bg_color != NULL)
		*bg_color = NULL;
	if(fg_color != NULL)
		*fg_color = NULL;
}

GdkColor *favBgColor(struct GtvgProgram *prog)
{
	GdkColor *bg_color = NULL;

	progColor(prog, &bg_color, NULL);
	if(bg_color != NULL)
		return bg_color;
	return &favourite_bg_color;
}

GdkColor *defBgColor(struct GtvgProgram * prog)
{
	GdkColor *bg_color = NULL;

	progColor(prog, &bg_color, NULL);
	if(bg_color != NULL)
		return bg_color;
	return &default_bg_color;
}

GdkColor *favTextColor(struct GtvgProgram * prog)
{
	GdkColor *text_color = NULL;

	progColor(prog, NULL, &text_color);
	if(text_color != NULL)
		return text_color;
	return &favourite_text_color;
}

GdkColor *defTextColor(struct GtvgProgram * prog)
{
	GdkColor *text_color = NULL;

	progColor(prog, NULL, &text_color);
	if(text_color != NULL)
		return text_color;
	return &default_text_color;
}

static void show_help(void)
{
	GString *str = g_string_new(NULL);

	g_string_append_c(str, '\n');
	g_string_append_printf(str, "gTVG TV Guide %s\n\n", VERSION);
	g_string_append_printf(str, "%s\n", _("  --version        Print version information and exit"));
	g_string_append_printf(str, "%s\n", _("  --help           Print this help and exit"));
	g_string_append_printf(str, "%s\n", _("  --mainwindow-state=STATE"));
	g_string_append_printf(str, "%s\n", _("                   Start gTVG with its main window in STATE."));
	g_string_append_printf(str, "%s\n", _("                   STATE may be `shown', `iconified', or `hidden'"));
	g_string_append_c(str, '\n');
	g_print("%s", str->str);
	g_string_free(str, TRUE);
}

void clearFavouritesConf(void)
{
	gconf_client_recursive_unset(client, "/apps/gtvg/favourites", GCONF_UNSET_INCLUDING_SCHEMA_NAMES, NULL);
}

void saveFavourites(void)
{
	GSList *list;
	gchar *path, *key;
	struct GtvgFavourite *fav;

	clearFavouritesConf();
	list = favourites;
	while(list != NULL) {
		fav = (struct GtvgFavourite *) list->data;
		key = gconf_unique_key();
		path = g_strconcat("/apps/gtvg/favourites/", key, "/title", NULL);
		gconf_client_set_string(client, path, fav->title, NULL);
		g_free(path);
		path = g_strconcat("/apps/gtvg/favourites/", key, "/match_partial_title", NULL);
		gconf_client_set_bool(client, path, fav->partial_title, NULL);
		g_free(path);
		path = g_strconcat("/apps/gtvg/favourites/", key, "/time", NULL);
		gconf_client_set_int(client, path, (int) fav->time, NULL);
		g_free(path);
		path = g_strconcat("/apps/gtvg/favourites/", key, "/day_of_week", NULL);
		gconf_client_set_int(client, path, (int) fav->dayofweek, NULL);
		g_free(path);
		path = g_strconcat("/apps/gtvg/favourites/", key, "/time_of_day", NULL);
		gconf_client_set_int(client, path, (int) fav->timeofday, NULL);
		g_free(path);
		if(fav->channel != NULL) {
			path = g_strconcat("/apps/gtvg/favourites/", key, "/channel", NULL);
			gconf_client_set_string(client, path, fav->channel, NULL);
			g_free(path);
		}
		if(fav->reminder >= 0) {
			path = g_strconcat("/apps/gtvg/favourites/", key, "/reminder_enabled", NULL);
			gconf_client_set_bool(client, path, fav->reminder > 0, NULL);
			g_free(path);
			if(fav->reminder > 0) {
				path = g_strconcat("/apps/gtvg/favourites/", key, "/reminder_time", NULL);
				gconf_client_set_int(client, path, fav->reminder_time, NULL);
				g_free(path);
				path = g_strconcat("/apps/gtvg/favourites/", key, "/reminder_duration", NULL);
				gconf_client_set_int(client, path, fav->reminder_duration, NULL);
				g_free(path);
			}
		}
		if(fav->record >= 0) {
			path = g_strconcat("/apps/gtvg/favourites/", key, "/recordings_enabled", NULL);
			gconf_client_set_bool(client, path, fav->record > 0, NULL);
			g_free(path);
			if(fav->record > 0) {
				path = g_strconcat("/apps/gtvg/favourites/", key, "/start_recording_margin", NULL);
				gconf_client_set_int(client, path, fav->record_start_margin, NULL);
				g_free(path);
				path = g_strconcat("/apps/gtvg/favourites/", key, "/stop_recording_margin", NULL);
				gconf_client_set_int(client, path, fav->record_stop_margin, NULL);
				g_free(path);
			}
		}
		if(fav->prioritise) {
			path = g_strconcat("/apps/gtvg/favourites/", key, "/prioritise", NULL);
			gconf_client_set_bool(client, path, TRUE, NULL);
			g_free(path);
		}
		if(fav->disabled_recordings != NULL) {
			gchar *path2 = g_strconcat("/apps/gtvg/favourites/", key, "/occasions/", NULL);
			GSList *list2 = fav->disabled_recordings;

			while(list2 != NULL) {
				struct recording_occasion *recocc = (struct recording_occasion *) list2->data;
				gchar *key2 = gconf_unique_key();

				path = g_strconcat(path2, key2, "/time", NULL);
				gconf_client_set_int(client, path, recocc->time, NULL);
				g_free(path);
				if(fav->channel == NULL) {
					path = g_strconcat(path2, key2, "/channel", NULL);
					gconf_client_set_string(client, path, recocc->channel, NULL);
					g_free(path);
				}
				path = g_strconcat(path2, key2, "/recording_disabled", NULL);
				gconf_client_set_bool(client, path, TRUE, NULL);
				g_free(path);
				g_free(key2);
				list2 = g_slist_next(list2);
			}
			g_free(path2);
		}
		if(fav->prioritised_recordings != NULL) {
			gchar *path2 = g_strconcat("/apps/gtvg/favourites/", key, "/occasions/", NULL);
			GSList *list2 = fav->prioritised_recordings;

			while(list2 != NULL) {
				struct recording_occasion *recocc = (struct recording_occasion *) list2->data;
				gchar *key2 = gconf_unique_key();

				path = g_strconcat(path2, key2, "/time", NULL);
				gconf_client_set_int(client, path, recocc->time, NULL);
				g_free(path);
				if(fav->channel == NULL) {
					path = g_strconcat(path2, key2, "/channel", NULL);
					gconf_client_set_string(client, path, recocc->channel, NULL);
					g_free(path);
				}
				path = g_strconcat(path2, key2, "/recording_prioritised", NULL);
				gconf_client_set_bool(client, path, TRUE, NULL);
				g_free(path);
				g_free(key2);
				list2 = g_slist_next(list2);
			}
			g_free(path2);
		}
		g_free(key);
		list = g_slist_next(list);
	}
	gconf_client_suggest_sync(client, NULL);
}
void loadFavourites(void)
{
	GSList *dirs, *dirs_first, *dirs2, *dirs_first2;
	gchar *dirpath, *path, *title_str, *dirpath2, *channel = NULL;
	time_t occtime, curtime;
	struct GtvgFavourite *fav;
	GConfValue *gvalue;

	curtime = time(NULL);
	dirs = gconf_client_all_dirs(client, "/apps/gtvg/favourites", NULL);
	dirs_first = dirs;
	while(dirs != NULL) {
		dirpath = (gchar *) dirs->data;
		if(dirpath != NULL) {
			path = g_strconcat(dirpath, "/title", NULL);
			title_str = gconf_client_get_string(client, path, NULL);
			g_free(path);
			if(title_str != NULL) {
				fav = gtvg_favourite_new();
				fav->title = title_str;
				path = g_strconcat(dirpath, "/match_partial_title", NULL);
				fav->partial_title = gconf_client_get_bool(client, path, NULL);
				g_free(path);
				path = g_strconcat(dirpath, "/time", NULL);
				fav->time = (time_t) gconf_client_get_int(client, path, NULL);
				g_free(path);
				path = g_strconcat(dirpath, "/day_of_week", NULL);
				fav->dayofweek = gconf_client_get_int(client, path, NULL);
				g_free(path);
				path = g_strconcat(dirpath, "/time_of_day", NULL);
				fav->timeofday = gconf_client_get_int(client, path, NULL);
				g_free(path);
				path = g_strconcat(dirpath, "/channel", NULL);
				fav->channel = gconf_client_get_string(client, path, NULL);
				g_free(path);
				if(fav->channel != NULL && strlen(fav->channel) == 0) {
					g_free(fav->channel);
					fav->channel = NULL;
				}
				path = g_strconcat(dirpath, "/reminder_enabled", NULL);
				gvalue = gconf_client_get(client, path, NULL);
				g_free(path);
				if(gvalue != NULL) {
					if(gconf_value_get_bool(gvalue))
						fav->reminder = 1;
					else
						fav->reminder = 0;
					gconf_value_free(gvalue);
				}
				if(fav->reminder > 0) {
					path = g_strconcat(dirpath, "/reminder_time", NULL);
					fav->reminder_time = gconf_client_get_int(client, path, NULL);
					g_free(path);
					if(fav->reminder_time < 0)
						fav->reminder_time = reminder_time;
					path = g_strconcat(dirpath, "/reminder_duration", NULL);
					fav->reminder_duration = gconf_client_get_int(client, path, NULL);
					g_free(path);
				}
				path = g_strconcat(dirpath, "/recordings_enabled", NULL);
				gvalue = gconf_client_get(client, path, NULL);
				g_free(path);
				if(gvalue != NULL) {
					if(gconf_value_get_bool(gvalue))
						fav->record = 1;
					else
						fav->record = 0;
					gconf_value_free(gvalue);
				}
				if(fav->record > 0) {
					path = g_strconcat(dirpath, "/start_recording_margin", NULL);
					fav->record_start_margin = gconf_client_get_int(client, path, NULL);
					if(fav->record_start_margin < 0)
						fav->record_start_margin = 0;
					g_free(path);
					path = g_strconcat(dirpath, "/stop_recording_margin", NULL);
					fav->record_stop_margin = gconf_client_get_int(client, path, NULL);
					if(fav->record_stop_margin < 0)
						fav->record_stop_margin = 0;
					g_free(path);
				}
				path = g_strconcat(dirpath, "/prioritise", NULL);
				fav->prioritise = gconf_client_get_bool(client, path, NULL);
				g_free(path);
				path = g_strconcat(dirpath, "/occasions", NULL);
				dirs2 = gconf_client_all_dirs(client, path, NULL);
				dirs_first2 = dirs2;
				while(dirs2 != NULL) {
					dirpath2 = (gchar *) dirs2->data;
					if(dirpath2 != NULL) {
						path = g_strconcat(dirpath2, "/time", NULL);
						occtime = gconf_client_get_int(client, path, NULL);
						g_free(path);
						if(occtime > curtime - 86400) {
							if(fav->channel == NULL) {
								path = g_strconcat(dirpath2, "/channel", NULL);
								channel = gconf_client_get_string(client, path, NULL);
								g_free(path);
							}
							if(fav->channel != NULL || channel != NULL) {
								path = g_strconcat(dirpath2, "/recording_disabled", NULL);
								if(gconf_client_get_bool(client, path, NULL)) {
									struct recording_occasion *recocc = g_slice_new(struct recording_occasion);

									if(channel != NULL)
										recocc->channel = g_strdup(channel);
									else
										recocc->channel = NULL;
									recocc->time = occtime;
									fav->disabled_recordings = g_slist_prepend(fav->disabled_recordings, recocc);
								} else {
									g_free(path);
									path = g_strconcat(dirpath2, "/recording_prioritised", NULL);
									if(gconf_client_get_bool(client, path, NULL)) {
										struct recording_occasion *recocc = g_slice_new(struct recording_occasion);

										if(channel != NULL)
											recocc->channel = g_strdup(channel);
										else
											recocc->channel = NULL;
										recocc->time = occtime;
										fav->prioritised_recordings = g_slist_prepend(fav->prioritised_recordings, recocc);
									}
								}
								g_free(path);
								if(channel != NULL)
									g_free(channel);
							}
						}
						g_free(dirpath2);
					}
					dirs2 = g_slist_next(dirs2);
				}
				if(dirs_first2 != NULL)
					g_slist_free(dirs_first2);
				if(fav->disabled_recordings != NULL)
					fav->disabled_recordings = g_slist_sort(fav->disabled_recordings, recocc_compare_func);
				if(fav->prioritised_recordings != NULL)
					fav->prioritised_recordings = g_slist_sort(fav->prioritised_recordings, recocc_compare_func);
				favourites = g_slist_prepend(favourites, fav);
			}
			g_free(dirpath);
		}
		dirs = g_slist_next(dirs);
	}
	if(favourites != NULL)
		favourites = g_slist_sort(favourites, favourite_sort_compare_func);
	if(dirs_first != NULL)
		g_slist_free(dirs_first);
}

void saveChannelConf(void)
{
	GtkTreeIter iter;
	gchar *gstr, *gstr2;
	struct GtvgChannel *ch;
	gboolean b;
	gint i = 0;

	gconf_client_recursive_unset(client, "/apps/gtvg/channels", GCONF_UNSET_INCLUDING_SCHEMA_NAMES, NULL);
	b = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(channelsList_store), &iter);
	while(b) {
		gtk_tree_model_get(GTK_TREE_MODEL(channelsList_store), &iter, CHANNELS_OBJECT_COLUMN, &ch, -1);
		if(ch != NULL) {
			gstr = gconf_concat_dir_and_key("/apps/gtvg/channels/", ch->id);
			if(channels_moved) {
				gstr2 = gconf_concat_dir_and_key(gstr, "index");
				gconf_client_set_int(client, gstr2, i, NULL);
				g_free(gstr2);
			}
			if(ch->custom_name) {
				gstr2 = gconf_concat_dir_and_key(gstr, "name");
				gconf_client_set_string(client, gstr2, ch->name, NULL);
				g_free(gstr2);
			}
			if(ch->custom_icon) {
				gstr2 = gconf_concat_dir_and_key(gstr, "icon");
				gconf_client_set_string(client, gstr2, ch->iconpath, NULL);
				g_free(gstr2);
			}
			g_free(gstr);
		}
		i++;
		b = gtk_tree_model_iter_next(GTK_TREE_MODEL(channelsList_store), &iter);
	}
	gconf_client_suggest_sync(client, NULL);
}

void loadChannelConf(void)
{
	gchar *gstr, *gstr2;
	GSList *list = channels;
	struct GtvgChannel *ch;
	GConfValue *gvalue;

	while(list != NULL) {
		ch = (struct GtvgChannel *) list->data;
		gstr = gconf_concat_dir_and_key("/apps/gtvg/channels/", ch->id);
		gstr2 = gconf_concat_dir_and_key(gstr, "index");
		gvalue = gconf_client_get(client, gstr2, NULL);
		if(gvalue != NULL) {
			channels_moved = TRUE;
			ch->index = gconf_value_get_int(gvalue);
			gconf_value_free(gvalue);
		} else {
			ch->index = -1;
		}
		g_free(gstr2);
		gstr2 = gconf_concat_dir_and_key(gstr, "name");
		gvalue = gconf_client_get(client, gstr2, NULL);
		if(gvalue != NULL) {
			if(ch->name != NULL)
				g_free(ch->name);
			ch->name = g_strdup(gconf_value_get_string(gvalue));
			ch->custom_name = TRUE;
			gconf_value_free(gvalue);
		}
		g_free(gstr2);
		gstr2 = gconf_concat_dir_and_key(gstr, "icon");
		gvalue = gconf_client_get(client, gstr2, NULL);
		if(gvalue != NULL) {
			if(ch->iconpath != NULL)
				g_free(ch->iconpath);
			ch->iconpath = g_strdup(gconf_value_get_string(gvalue));
			ch->custom_icon = TRUE;
			gconf_value_free(gvalue);
		}
		g_free(gstr2);
		g_free(gstr);
		list = g_slist_next(list);
	}
}

void saveCategories(void)
{
	gchar *path, *key, *gstr;
	struct GtvgCategory *cat;
	GSList *list = categories;
	PangoColor pango_color;

	gconf_client_recursive_unset(client, "/apps/gtvg/categories", GCONF_UNSET_INCLUDING_SCHEMA_NAMES, NULL);
	while(list != NULL) {
		cat = (struct GtvgCategory *) list->data;
		if(cat->bg_color != NULL || cat->text_color != NULL || g_slist_length(cat->original_names) != 1 || strcmp(cat->name, (gchar *) cat->original_names->data) != 0) {
			key = gconf_unique_key();
			path = g_strconcat("/apps/gtvg/categories/", key, "/name", NULL);
			gconf_client_set_string(client, path, cat->name, NULL);
			g_free(path);
			path = g_strconcat("/apps/gtvg/categories/", key, "/original_names", NULL);
			gconf_client_set_list(client, path, GCONF_VALUE_STRING, cat->original_names, NULL);
			g_free(path);
			if(cat->bg_color != NULL) {
				path = g_strconcat("/apps/gtvg/categories/", key, "/background_color", NULL);
				pango_color.red = cat->bg_color->red;
				pango_color.green = cat->bg_color->green;
				pango_color.blue = cat->bg_color->blue;
				gstr = pango_color_to_string(&pango_color);
				gconf_client_set_string(client, path, gstr, NULL);
				g_free(gstr);
				g_free(path);
			}
			if(cat->text_color != NULL) {
				path = g_strconcat("/apps/gtvg/categories/", key, "/text_color", NULL);
				pango_color.red = cat->text_color->red;
				pango_color.green = cat->text_color->green;
				pango_color.blue = cat->text_color->blue;
				gstr = pango_color_to_string(&pango_color);
				gconf_client_set_string(client, path, gstr, NULL);
				g_free(gstr);
				g_free(path);
			}
			g_free(key);
		}
		list = g_slist_next(list);
	}
	gconf_client_suggest_sync(client, NULL);
}

gint categories_compare_func(gconstpointer a, gconstpointer b)
{
	struct GtvgCategory *c1 = (struct GtvgCategory *) a;
	struct GtvgCategory *c2 = (struct GtvgCategory *) b;

	return strcmp(c1->name, c2->name);
}

void loadCategories(void)
{
	GSList *dirs, *dirs_first;
	gchar *dirpath, *path, *gstr;
	struct GtvgCategory *cat;

	dirs = gconf_client_all_dirs(client, "/apps/gtvg/categories", NULL);
	dirs_first = dirs;
	while(dirs != NULL) {
		dirpath = (gchar *) dirs->data;
		if(dirpath != NULL) {
			path = g_strconcat(dirpath, "/name", NULL);
			gstr = gconf_client_get_string(client, path, NULL);
			g_free(path);
			if(gstr != NULL) {
				cat = gtvg_category_new();
				cat->name = gstr;
				path = g_strconcat(dirpath, "/original_names", NULL);
				cat->original_names = gconf_client_get_list(client, path, GCONF_VALUE_STRING, NULL);
				g_free(path);
				path = g_strconcat(dirpath, "/background_color", NULL);
				gstr = gconf_client_get_string(client, path, NULL);
				if(gstr != NULL) {
					cat->bg_color = g_slice_new(GdkColor);
					gdk_color_parse(gstr, cat->bg_color);
					g_free(gstr);
				}
				g_free(path);
				path = g_strconcat(dirpath, "/text_color", NULL);
				gstr = gconf_client_get_string(client, path, NULL);
				if(gstr != NULL) {
					cat->text_color = g_slice_new(GdkColor);
					gdk_color_parse(gstr, cat->text_color);
					g_free(gstr);
				}
				g_free(path);
				categories = g_slist_prepend(categories, cat);
			}
			g_free(dirpath);
		}
		dirs = g_slist_next(dirs);
	}
	if(categories != NULL)
		categories = g_slist_sort(categories, categories_compare_func);
	if(dirs_first != NULL)
		g_slist_free(dirs_first);
}

gint sort_grab_commands(GtkTreeModel * model, GtkTreeIter * a, GtkTreeIter * b, gpointer user_data)
{
	gchar *gstr, *gstr2;
	gint retval;

	gtk_tree_model_get(model, a, 0, &gstr, -1);
	gtk_tree_model_get(model, b, 0, &gstr2, -1);
	if(gstr == NULL) {
		if(gstr2 != NULL) {
			g_free(gstr2);
			return -1;
		}
		return 0;
	}
	if(gstr2 == NULL) {
		g_free(gstr);
		return 1;
	}
	if(strcmp(gstr, _("External updates only")) == 0) {
		retval = -1;
	} else if(strcmp(gstr2, _("External updates only")) == 0) {
		retval = 1;
	} else if(strcmp(gstr, _("Custom command")) == 0) {
		retval = -1;
	} else if(strcmp(gstr2, _("Custom command")) == 0) {
		retval = 1;
	} else {
		retval = strcmp(gstr, gstr2);
	}
	g_free(gstr);
	g_free(gstr2);
	return retval;
}

void updateRecordScheduleList(void)
{
	GSList *list, *list2;
	gboolean b;
	gchar *start_str, *stop_str, *time_str;
	struct tm recstm, recetm;
	GtkTreeIter iter;
	GtkTreeModel *model;
	GtkTreeSelection *selection;
	struct record_schedule *selected_recsched = NULL;

	if(GTK_WIDGET_VISIBLE(glade_xml_get_widget(gxml, "recordScheduleDialog"))) {

		selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "recordScheduleList_view")));
		if(gtk_tree_selection_get_selected(selection, &model, &iter))
			gtk_tree_model_get(model, &iter, 4, &selected_recsched, -1);

		gtk_list_store_clear(recordScheduleList_store);

		start_str = g_strnfill(80, '\0');
		stop_str = g_strnfill(80, '\0');
		time_str = g_strnfill(200, '\0');

		if(current_record_stop_time > 0) {
			gtk_list_store_append(recordScheduleList_store, &iter);
			gtk_list_store_set(recordScheduleList_store, &iter, 0, current_record_title, 1, current_record_channel, -1);
			if(selected_recsched == NULL)
				gtk_tree_selection_select_iter(selection, &iter);
			localtime_r(&current_record_program_stop, &recetm);
			strftime(stop_str, 80, "%R", &recetm);
			//ongoing interval (" - 21:30")
			g_snprintf(time_str, 200, _("\342\200\223%s"), stop_str);
			gtk_list_store_set(recordScheduleList_store, &iter, 2, time_str, -1);
			localtime_r(&current_record_stop_time, &recetm);
			strftime(stop_str, 80, "%R", &recetm);
			g_snprintf(time_str, 200, _("\342\200\223%s"), stop_str);
			gtk_list_store_set(recordScheduleList_store, &iter, 3, time_str, -1);
		}

		list = record_schedules;
		list2 = disabled_record_schedules;
		while(list != NULL || list2 != NULL) {
			struct record_schedule *recsched;

			if(list2 == NULL || (list != NULL && ((struct record_schedule *) list->data)->start_time <= ((struct record_schedule *) list2->data)->prog->start)) {
				b = TRUE;
				recsched = (struct record_schedule *) list->data;
			} else {
				b = FALSE;
				recsched = (struct record_schedule *) list2->data;
			}
			gtk_list_store_append(recordScheduleList_store, &iter);
			gtk_list_store_set(recordScheduleList_store, &iter, 0, recsched->prog->title, 1, recsched->prog->channel->name, 4, (gpointer) recsched, -1);
			if(selected_recsched == recsched)
				gtk_tree_selection_select_iter(selection, &iter);
			strftime(stop_str, 80, "%R", &recsched->prog->stop_tm);
			if(recsched->prog->start < tomorrow_time) {
				strftime(start_str, 80, "%R", &recsched->prog->start_tm);
			} else if(recsched->prog->start >= tomorrow_time + 518400) {
				//date and time in list (ex. "7 May 20:00")
				strftime(start_str, 80, _("%e %b %R"), &recsched->prog->start_tm);
			} else {
				//day of week and time in (ex. "Thu 20:00")
				strftime(start_str, 80, _("%a %R"), &recsched->prog->start_tm);
			}
			//time interval ("20:00 - 21:30")
			g_snprintf(time_str, 200, _("%s\342\200\223%s"), start_str, stop_str);
			gtk_list_store_set(recordScheduleList_store, &iter, 2, time_str, -1);
			if(b) {
				localtime_r(&recsched->start_time, &recstm);
				localtime_r(&recsched->stop_time, &recetm);
				strftime(stop_str, 80, "%R", &recetm);
				if(recsched->start_time < tomorrow_time) {
					strftime(start_str, 80, "%R", &recstm);
				} else if(recsched->start_time >= tomorrow_time + 518400) {
					//date and time in list (ex. "7 May 20:00")
					strftime(start_str, 80, _("%e %b %R"), &recstm);
				} else {
					//day of week and time in (ex. "Thu 20:00")
					strftime(start_str, 80, _("%a %R"), &recstm);
				}
				//time interval ("20:00 - 21:30")
				g_snprintf(time_str, 200, _("%s\342\200\223%s"), start_str, stop_str);
				gtk_list_store_set(recordScheduleList_store, &iter, 3, time_str, -1);
				list = g_slist_next(list);
			} else {
				if(recsched->disabled > 1)
					gtk_list_store_set(recordScheduleList_store, &iter, 3, _("Disabled"), -1);
				else
					gtk_list_store_set(recordScheduleList_store, &iter, 3, _("Conflicting"), -1);
				list2 = g_slist_next(list2);
			}
		}

		g_free(start_str);
		g_free(stop_str);
		g_free(time_str);
	}
}

GtkWidget *getCategoryDialog(void)
{

	gtk_button_set_image(GTK_BUTTON(glade_xml_get_widget(gxml, "categoryUnsetButton")), gtk_image_new_from_stock("gtk-delete", GTK_ICON_SIZE_BUTTON));

	return glade_xml_get_widget(gxml, "categoryDialog");

}

GtkWidget *getRecordScheduleDialog(void)
{

	GtkCellRenderer *renderer;
	GtkTreeViewColumn *column;
	GtkTreeSelection *selection;
	GtkWidget *recschedDialog;

	recschedDialog = glade_xml_get_widget(gxml, "recordScheduleDialog");

	if(recordScheduleList_store == NULL) {

		gtk_button_set_label(GTK_BUTTON(glade_xml_get_widget(gxml, "recordingsPrioritiseButton")), _("Prioritise"));
		gtk_button_set_image(GTK_BUTTON(glade_xml_get_widget(gxml, "recordingsPrioritiseButton")), gtk_image_new_from_stock("gtk-yes", GTK_ICON_SIZE_BUTTON));
		gtk_button_set_label(GTK_BUTTON(glade_xml_get_widget(gxml, "recordingsDisableButton")), _("Disable"));
		gtk_button_set_image(GTK_BUTTON(glade_xml_get_widget(gxml, "recordingsDisableButton")), gtk_image_new_from_stock("gtk-no", GTK_ICON_SIZE_BUTTON));

		recordScheduleList_store = gtk_list_store_new(5, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_POINTER);
		gtk_tree_view_set_model(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "recordScheduleList_view")), GTK_TREE_MODEL(recordScheduleList_store));
		selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "recordScheduleList_view")));
		gtk_tree_selection_set_mode(selection, GTK_SELECTION_SINGLE);
		renderer = gtk_cell_renderer_text_new();
		column = gtk_tree_view_column_new_with_attributes(_("Program Title"), renderer, "text", 0, NULL);
		gtk_tree_view_append_column(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "recordScheduleList_view")), column);
		renderer = gtk_cell_renderer_text_new();
		column = gtk_tree_view_column_new_with_attributes(_("Channel"), renderer, "text", 1, NULL);
		gtk_tree_view_append_column(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "recordScheduleList_view")), column);
		renderer = gtk_cell_renderer_text_new();
		column = gtk_tree_view_column_new_with_attributes(_("Program Time"), renderer, "text", 2, NULL);
		gtk_tree_view_append_column(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "recordScheduleList_view")), column);
		renderer = gtk_cell_renderer_text_new();
		column = gtk_tree_view_column_new_with_attributes(_("Recording Time"), renderer, "text", 3, NULL);
		gtk_tree_view_append_column(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "recordScheduleList_view")), column);
		g_signal_connect(G_OBJECT(selection), "changed", G_CALLBACK(on_recordScheduleList_selection_changed), NULL);
	}

	return recschedDialog;

}

GtkWidget *getFavouriteDialog(void)
{
	GtkTreeIter iter;
	GtkCellRenderer *renderer;
	GtkWidget *favouriteDialog;
	GSList *list;

	favouriteDialog = glade_xml_get_widget(gxml, "favouriteDialog");

	gtk_notebook_set_current_page(GTK_NOTEBOOK(glade_xml_get_widget(gxml, "favouriteTabs")), 0);

	if(favouriteDayCombo_store == NULL) {
		favouriteDayCombo_store = gtk_list_store_new(1, G_TYPE_STRING);
		gtk_combo_box_set_model(GTK_COMBO_BOX(glade_xml_get_widget(gxml, "favouriteDayCombo")), GTK_TREE_MODEL(favouriteDayCombo_store));
		renderer = gtk_cell_renderer_text_new();
		gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(glade_xml_get_widget(gxml, "favouriteDayCombo")), renderer, TRUE);
		gtk_cell_layout_add_attribute(GTK_CELL_LAYOUT(glade_xml_get_widget(gxml, "favouriteDayCombo")), renderer, "text", 0);
		gtk_list_store_append(favouriteDayCombo_store, &iter);
		gtk_list_store_set(favouriteDayCombo_store, &iter, 0, nl_langinfo(DAY_1), -1);
		gtk_list_store_append(favouriteDayCombo_store, &iter);
		gtk_list_store_set(favouriteDayCombo_store, &iter, 0, nl_langinfo(DAY_2), -1);
		gtk_list_store_append(favouriteDayCombo_store, &iter);
		gtk_list_store_set(favouriteDayCombo_store, &iter, 0, nl_langinfo(DAY_3), -1);
		gtk_list_store_append(favouriteDayCombo_store, &iter);
		gtk_list_store_set(favouriteDayCombo_store, &iter, 0, nl_langinfo(DAY_4), -1);
		gtk_list_store_append(favouriteDayCombo_store, &iter);
		gtk_list_store_set(favouriteDayCombo_store, &iter, 0, nl_langinfo(DAY_5), -1);
		gtk_list_store_append(favouriteDayCombo_store, &iter);
		gtk_list_store_set(favouriteDayCombo_store, &iter, 0, nl_langinfo(DAY_6), -1);
		gtk_list_store_append(favouriteDayCombo_store, &iter);
		gtk_list_store_set(favouriteDayCombo_store, &iter, 0, nl_langinfo(DAY_7), -1);
	}

	if(favouriteChannelCombo_store == NULL) {
		favouriteChannelCombo_store = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_POINTER);
		gtk_combo_box_set_model(GTK_COMBO_BOX(glade_xml_get_widget(gxml, "favouriteChannelCombo")), GTK_TREE_MODEL(favouriteChannelCombo_store));
		renderer = gtk_cell_renderer_text_new();
		gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(glade_xml_get_widget(gxml, "favouriteChannelCombo")), renderer, TRUE);
		gtk_cell_layout_add_attribute(GTK_CELL_LAYOUT(glade_xml_get_widget(gxml, "favouriteChannelCombo")), renderer, "text", 0);
		list = channels;
		while(list != NULL) {
			gtk_list_store_append(favouriteChannelCombo_store, &iter);
			gtk_list_store_set(favouriteChannelCombo_store, &iter, 0, ((struct GtvgChannel *) list->data)->name, 1, list->data, -1);
			list = g_slist_next(list);
		}
	}

	return favouriteDialog;

}

GtkWidget *getConfigurationDialog(void)
{
	GtkTreeIter iter;
	GtkCellRenderer *renderer;
	GtkWidget *configurationDialog;
	GConfValue *gvalue_command, *gvalue_file;
	const gchar *str_command = NULL, *str_file = NULL;
	gchar *gstr;
	gint i;
	gboolean b;

	configurationDialog = glade_xml_get_widget(gxml, "configurationDialog");

	if(grabCommandCombo_store == NULL) {

#ifndef HAVE_LIBGNOME
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "reminderSoundFileButton"), FALSE);
#endif

		grabCommandCombo_store = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_STRING);
		gtk_combo_box_set_model(GTK_COMBO_BOX(glade_xml_get_widget(gxml, "grabCommandCombo")), GTK_TREE_MODEL(grabCommandCombo_store));
		renderer = gtk_cell_renderer_text_new();
		gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(glade_xml_get_widget(gxml, "grabCommandCombo")), renderer, TRUE);
		gtk_cell_layout_add_attribute(GTK_CELL_LAYOUT(glade_xml_get_widget(gxml, "grabCommandCombo")), renderer, "text", 0);
		renderer = gtk_cell_renderer_text_new();
		gtk_cell_layout_pack_end(GTK_CELL_LAYOUT(glade_xml_get_widget(gxml, "grabCommandCombo")), renderer, FALSE);
		gtk_cell_layout_add_attribute(GTK_CELL_LAYOUT(glade_xml_get_widget(gxml, "grabCommandCombo")), renderer, "text", 1);

		recordPresetsCombo_store = gtk_list_store_new(1, G_TYPE_STRING);
		gtk_combo_box_set_model(GTK_COMBO_BOX(glade_xml_get_widget(gxml, "recordPresetsCombo")), GTK_TREE_MODEL(recordPresetsCombo_store));
		renderer = gtk_cell_renderer_text_new();
		gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(glade_xml_get_widget(gxml, "recordPresetsCombo")), renderer, TRUE);
		gtk_cell_layout_add_attribute(GTK_CELL_LAYOUT(glade_xml_get_widget(gxml, "recordPresetsCombo")), renderer, "text", 0);
		gtk_list_store_append(recordPresetsCombo_store, &iter);
		gtk_list_store_set(recordPresetsCombo_store, &iter, 0, _("Select a preset"), -1);
		i = 0;
		while(record_presets[i] != 0) {
			gtk_list_store_append(recordPresetsCombo_store, &iter);
			gtk_list_store_set(recordPresetsCombo_store, &iter, 0, record_presets[i], -1);
			i++;
		}
		gtk_combo_box_set_active(GTK_COMBO_BOX(glade_xml_get_widget(gxml, "recordPresetsCombo")), 0);
	}
	gvalue_file = gconf_client_get(client, "/apps/gtvg/xmltv_file", NULL);
	gvalue_command = gconf_client_get(client, "/apps/gtvg/grabber_command", NULL);
	if(gvalue_file != NULL)
		str_file = gconf_value_get_string(gvalue_file);
	if(gvalue_command != NULL)
		str_command = gconf_value_get_string(gvalue_command);
	gtk_list_store_clear(grabCommandCombo_store);
	i = 0;
	gtk_list_store_append(grabCommandCombo_store, &iter);
	gtk_list_store_set(grabCommandCombo_store, &iter, 0, _("External updates only"), -1);
	gtk_combo_box_set_active(GTK_COMBO_BOX(glade_xml_get_widget(gxml, "grabCommandCombo")), 0);
	gtk_list_store_append(grabCommandCombo_store, &iter);
	gtk_list_store_set(grabCommandCombo_store, &iter, 0, _("Custom command"), -1);
	b = FALSE;
	while(grabbers[i] != NULL) {
		gstr = g_find_program_in_path(grabbers[i]);
		if(gstr != NULL) {
			gtk_list_store_append(grabCommandCombo_store, &iter);
			gtk_list_store_set(grabCommandCombo_store, &iter, 0, dgettext(PACKAGE, grabber_names[i]), 1, grabbers[i], -1);
			g_free(gstr);
		}
		i++;
	}
	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(grabCommandCombo_store), 0, sort_grab_commands, NULL, NULL);
	gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(grabCommandCombo_store), 0, GTK_SORT_ASCENDING);
	b = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(grabCommandCombo_store), &iter);
	if(b)
		b = gtk_tree_model_iter_next(GTK_TREE_MODEL(grabCommandCombo_store), &iter);
	if(b)
		b = gtk_tree_model_iter_next(GTK_TREE_MODEL(grabCommandCombo_store), &iter);
	while(str_command != NULL && b) {
		gtk_tree_model_get(GTK_TREE_MODEL(grabCommandCombo_store), &iter, 1, &gstr, -1);
		if(strcmp(str_command, gstr) == 0) {
			gtk_combo_box_set_active_iter(GTK_COMBO_BOX(glade_xml_get_widget(gxml, "grabCommandCombo")), &iter);
			g_free(gstr);
			break;
		}
		g_free(gstr);
		b = gtk_tree_model_iter_next(GTK_TREE_MODEL(grabCommandCombo_store), &iter);
	}
	if(!b && str_command != NULL && strlen(str_command) > 0) {
		gtk_combo_box_set_active(GTK_COMBO_BOX(glade_xml_get_widget(gxml, "grabCommandCombo")), 1);
		gtk_entry_set_text(GTK_ENTRY(glade_xml_get_widget(gxml, "commandEntry")), str_command);
	}
	if(str_file != NULL)
		gtk_entry_set_text(GTK_ENTRY(glade_xml_get_widget(gxml, "fileEntry")), str_file);
	else
		on_grabCommandCombo_changed(GTK_COMBO_BOX(glade_xml_get_widget(gxml, "grabCommandCombo")), NULL);
	if(gvalue_file != NULL)
		gconf_value_free(gvalue_file);
	if(gvalue_command != NULL)
		gconf_value_free(gvalue_command);
	return configurationDialog;
}

GtkWidget *create_window(void)
{

	GtkCellRenderer *renderer;
	GtkTreeViewColumn *column;
	GtkTreeSelection *selection;
	gchar *gstr;
	GtkWidget *searchIconEntry;
	GtkAdjustment *programCanvas_hadj, *programCanvas_vadj;
	gboolean b;

	window = glade_xml_get_widget(gxml, "gtvgWindow");

	gtk_text_buffer_create_tag(gtk_text_view_get_buffer(GTK_TEXT_VIEW(glade_xml_get_widget(gxml, "programInfoView"))), "title", "weight", PANGO_WEIGHT_BOLD, "pixels-above-lines", 6, NULL);
#if GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION <= 10
	gtk_text_buffer_create_tag(gtk_text_view_get_buffer(GTK_TEXT_VIEW(glade_xml_get_widget(gxml, "programInfoView"))), "description", NULL);
#else
	gtk_text_buffer_create_tag(gtk_text_view_get_buffer(GTK_TEXT_VIEW(glade_xml_get_widget(gxml, "programInfoView"))), "description", "justification", GTK_JUSTIFY_FILL, NULL);
#endif
	gtk_text_buffer_create_tag(gtk_text_view_get_buffer(GTK_TEXT_VIEW(glade_xml_get_widget(gxml, "programInfoView"))), "property", "style", PANGO_STYLE_ITALIC, NULL);
	gtk_text_buffer_create_tag(gtk_text_view_get_buffer(GTK_TEXT_VIEW(glade_xml_get_widget(gxml, "programInfoView"))), "value", NULL);
	gtk_text_buffer_create_tag(gtk_text_view_get_buffer(GTK_TEXT_VIEW(glade_xml_get_widget(gxml, "programInfoView"))), "line", "scale", 0.4, NULL);

	gtk_text_buffer_create_tag(gtk_text_view_get_buffer(GTK_TEXT_VIEW(glade_xml_get_widget(gxml, "gridDescriptionView"))), "title", "weight", PANGO_WEIGHT_BOLD, "pixels-above-lines", 6, NULL);
#if GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION <= 10
	gtk_text_buffer_create_tag(gtk_text_view_get_buffer(GTK_TEXT_VIEW(glade_xml_get_widget(gxml, "gridDescriptionView"))), "description", NULL);
#else
	gtk_text_buffer_create_tag(gtk_text_view_get_buffer(GTK_TEXT_VIEW(glade_xml_get_widget(gxml, "gridDescriptionView"))), "description", "justification", GTK_JUSTIFY_FILL, NULL);
#endif
	gtk_text_buffer_create_tag(gtk_text_view_get_buffer(GTK_TEXT_VIEW(glade_xml_get_widget(gxml, "gridDescriptionView"))), "property", "style", PANGO_STYLE_ITALIC, NULL);
	gtk_text_buffer_create_tag(gtk_text_view_get_buffer(GTK_TEXT_VIEW(glade_xml_get_widget(gxml, "gridDescriptionView"))), "value", NULL);
	gtk_text_buffer_create_tag(gtk_text_view_get_buffer(GTK_TEXT_VIEW(glade_xml_get_widget(gxml, "gridDescriptionView"))), "line", "scale", 0.4, NULL);

	searchIconEntry = e_icon_entry_new();
	searchEntry = e_icon_entry_get_entry(E_ICON_ENTRY(searchIconEntry));
	g_signal_connect(G_OBJECT(searchEntry), "activate", G_CALLBACK(on_searchEntry_activate), NULL);
	g_signal_connect(G_OBJECT(searchEntry), "focus-out-event", G_CALLBACK(on_searchEntry_focus_out), NULL);
	g_signal_connect(G_OBJECT(searchEntry), "changed", G_CALLBACK(on_searchEntry_changed), NULL);
	clearSearchButton = e_icon_entry_create_button("gtk-clear");
	gtk_widget_set_sensitive(clearSearchButton, FALSE);
	g_signal_connect(G_OBJECT(clearSearchButton), "button-press-event", G_CALLBACK(on_clearSearchButton_clicked), NULL);
	e_icon_entry_pack_widget(E_ICON_ENTRY(searchIconEntry), clearSearchButton, FALSE);
	searchButton = e_icon_entry_create_button("gtk-find");
	gtk_widget_set_sensitive(searchButton, FALSE);
	g_signal_connect(G_OBJECT(searchButton), "button-press-event", G_CALLBACK(on_searchButton_clicked), NULL);
	e_icon_entry_pack_widget(E_ICON_ENTRY(searchIconEntry), searchButton, FALSE);
	gtk_box_pack_start(GTK_BOX(glade_xml_get_widget(gxml, "searchBox")), searchIconEntry, TRUE, TRUE, 0);
	gtk_widget_show_all(searchIconEntry);

	gtk_button_set_label(GTK_BUTTON(glade_xml_get_widget(gxml, "allChannelsButton")), _("Show All"));
	gtk_button_set_image(GTK_BUTTON(glade_xml_get_widget(gxml, "allChannelsButton")), gtk_image_new_from_stock("gtk-clear", GTK_ICON_SIZE_BUTTON));

	gtk_button_set_label(GTK_BUTTON(glade_xml_get_widget(gxml, "allCategoriesButton")), _("Show All"));
	gtk_button_set_image(GTK_BUTTON(glade_xml_get_widget(gxml, "allCategoriesButton")), gtk_image_new_from_stock("gtk-clear", GTK_ICON_SIZE_BUTTON));

	/*gtk_button_set_label(GTK_BUTTON(glade_xml_get_widget(gxml, "editCategoryButton")), _("Edit"));
	   gtk_button_set_image(GTK_BUTTON(glade_xml_get_widget(gxml, "editCategoryButton")), gtk_image_new_from_stock("gtk-edit", GTK_ICON_SIZE_BUTTON)); */

	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "sleepModeStatusMenuItem"), can_suspend);
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "sleepModeMenuItem"), can_suspend);

	programCanvas_hadj = gtk_scrolled_window_get_hadjustment(GTK_SCROLLED_WINDOW(glade_xml_get_widget(gxml, "programCanvas_scrolled")));
	programCanvas_vadj = gtk_scrolled_window_get_vadjustment(GTK_SCROLLED_WINDOW(glade_xml_get_widget(gxml, "programCanvas_scrolled")));
	g_signal_connect(G_OBJECT(programCanvas_hadj), "value-changed", G_CALLBACK(on_programCanvas_hadj_changed), NULL);
	g_signal_connect(G_OBJECT(programCanvas_vadj), "value-changed", G_CALLBACK(on_programCanvas_vadj_changed), NULL);

	b = gconf_client_get_bool(client, "/apps/gtvg/show_grid", NULL);
	g_signal_handlers_block_matched((gpointer) glade_xml_get_widget(gxml, "viewPages"), G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_viewPages_switch_page, NULL);
	gtk_notebook_set_current_page(GTK_NOTEBOOK(glade_xml_get_widget(gxml, "viewPages")), b ? 1 : 0);
	g_signal_handlers_unblock_matched((gpointer) glade_xml_get_widget(gxml, "viewPages"), G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_viewPages_switch_page, NULL);
	g_signal_handlers_block_matched((gpointer) glade_xml_get_widget(gxml, "viewListToolbutton"), G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_viewListToolbutton_toggled, NULL);
	g_signal_handlers_block_matched((gpointer) glade_xml_get_widget(gxml, "viewListMenuItem"), G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_viewListMenuItem_toggled, NULL);
	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(glade_xml_get_widget(gxml, "viewListMenuItem")), !b);
	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(glade_xml_get_widget(gxml, "viewGridMenuItem")), b);
	gtk_toggle_tool_button_set_active(GTK_TOGGLE_TOOL_BUTTON(glade_xml_get_widget(gxml, "viewListToolbutton")), !b);
	gtk_toggle_tool_button_set_active(GTK_TOGGLE_TOOL_BUTTON(glade_xml_get_widget(gxml, "viewGridToolbutton")), b);
	g_signal_handlers_unblock_matched((gpointer) glade_xml_get_widget(gxml, "viewListMenuItem"), G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_viewListMenuItem_toggled, NULL);
	g_signal_handlers_unblock_matched((gpointer) glade_xml_get_widget(gxml, "viewListToolbutton"), G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_viewListToolbutton_toggled, NULL);

	programList_store = gtk_list_store_new(8, G_TYPE_INT, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, GDK_TYPE_COLOR, GDK_TYPE_COLOR, G_TYPE_POINTER);
	gtk_tree_view_set_model(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "programList_view")), GTK_TREE_MODEL(programList_store));
	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "programList_view")));
	gtk_tree_selection_set_mode(selection, GTK_SELECTION_SINGLE);
	renderer = gtk_cell_renderer_progress_new();
	column = gtk_tree_view_column_new_with_attributes(_("Progress"), renderer, "value", PROGRESS_COLUMN, "text", PROGRESS_TEXT_COLUMN, NULL);
	gtk_tree_view_column_set_resizable(column, TRUE);
	gtk_tree_view_append_column(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "programList_view")), column);
	renderer = gtk_cell_renderer_text_new();
	g_object_set(G_OBJECT(renderer), (gpointer) "ellipsize", PANGO_ELLIPSIZE_END, NULL);
	column = gtk_tree_view_column_new_with_attributes(_("Title"), renderer, "markup", TITLE_COLUMN, "background-gdk", BACKGROUND_COLUMN, "foreground-gdk", FOREGROUND_COLUMN, NULL);
	gtk_tree_view_column_set_sizing(column, GTK_TREE_VIEW_COLUMN_AUTOSIZE);
	gtk_tree_view_column_set_resizable(column, TRUE);
	gtk_tree_view_column_set_expand(column, TRUE);
	gtk_tree_view_append_column(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "programList_view")), column);
	renderer = gtk_cell_renderer_text_new();
	g_object_set(G_OBJECT(renderer), "xalign", 1.0, "xpad", 3, NULL);
	column = gtk_tree_view_column_new_with_attributes(_("Time"), renderer, "text", TIME_COLUMN, NULL);
	gtk_tree_view_column_set_resizable(column, TRUE);
	gtk_tree_view_column_set_sort_indicator(column, TRUE);
	gtk_tree_view_append_column(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "programList_view")), column);
	renderer = gtk_cell_renderer_text_new();
	column = gtk_tree_view_column_new_with_attributes(_("Channel"), renderer, "text", CHANNEL_COLUMN, NULL);
	gtk_tree_view_column_set_resizable(column, TRUE);
	gtk_tree_view_append_column(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "programList_view")), column);
	g_signal_connect(G_OBJECT(selection), "changed", G_CALLBACK(on_programList_selection_changed), NULL);
	gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "programList_view")), TRUE);
	gtk_tree_view_set_search_column(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "programList_view")), TITLE_COLUMN);

	channelsList_store = gtk_list_store_new(4, G_TYPE_STRING, G_TYPE_OBJECT, G_TYPE_POINTER, G_TYPE_STRING);
	gtk_tree_view_set_model(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "channelsList_view")), GTK_TREE_MODEL(channelsList_store));
	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "channelsList_view")));
	gtk_tree_selection_set_mode(selection, GTK_SELECTION_MULTIPLE);
	renderer = gtk_cell_renderer_pixbuf_new();
	column = gtk_tree_view_column_new_with_attributes("Icon", renderer, "pixbuf", CHANNELS_ICON_COLUMN, NULL);
	gtk_tree_view_append_column(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "channelsList_view")), column);
	renderer = gtk_cell_renderer_text_new();
	column = gtk_tree_view_column_new_with_attributes("Channel", renderer, "text", CHANNELS_NAME_COLUMN, NULL);
	gtk_tree_view_append_column(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "channelsList_view")), column);
	gtk_tree_view_set_reorderable(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "channelsList_view")), TRUE);
	g_signal_connect(G_OBJECT(selection), "changed", G_CALLBACK(on_channelsList_selection_changed), NULL);
	g_signal_connect(G_OBJECT(channelsList_store), "row-inserted", G_CALLBACK(on_channelsList_row_inserted), NULL);

	favouritesList_store = gtk_list_store_new(3, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_POINTER);
	gtk_tree_view_set_model(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "favouritesList_view")), GTK_TREE_MODEL(favouritesList_store));
	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "favouritesList_view")));
	gtk_tree_selection_set_mode(selection, GTK_SELECTION_SINGLE);
	renderer = gtk_cell_renderer_text_new();
	column = gtk_tree_view_column_new_with_attributes("Title", renderer, "text", CHANNELS_NAME_COLUMN, NULL);
	gtk_tree_view_append_column(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "favouritesList_view")), column);
	g_signal_connect(G_OBJECT(selection), "changed", G_CALLBACK(on_favouritesList_selection_changed), NULL);

	blacklist_store = gtk_list_store_new(1, G_TYPE_STRING);
	gtk_tree_view_set_model(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "blacklist_view")), GTK_TREE_MODEL(blacklist_store));
	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "blacklist_view")));
	gtk_tree_selection_set_mode(selection, GTK_SELECTION_SINGLE);
	renderer = gtk_cell_renderer_text_new();
	column = gtk_tree_view_column_new_with_attributes("Title", renderer, "text", 0, NULL);
	gtk_tree_view_append_column(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "blacklist_view")), column);
	g_signal_connect(G_OBJECT(selection), "changed", G_CALLBACK(on_blacklist_selection_changed), NULL);

	categoriesList_store = gtk_list_store_new(4, G_TYPE_STRING, G_TYPE_POINTER, GDK_TYPE_COLOR, GDK_TYPE_COLOR);
	gtk_tree_view_set_model(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "categoriesList_view")), GTK_TREE_MODEL(categoriesList_store));
	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "categoriesList_view")));
	gtk_tree_selection_set_mode(selection, GTK_SELECTION_MULTIPLE);
	renderer = gtk_cell_renderer_text_new();
	column = gtk_tree_view_column_new_with_attributes("Category", renderer, "text", 0, "background-gdk", 2, "foreground-gdk", 3, NULL);
	gtk_tree_view_append_column(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "categoriesList_view")), column);
	g_signal_connect(G_OBJECT(selection), "changed", G_CALLBACK(on_categoriesList_selection_changed), NULL);

	dayCombo_store = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_LONG);
	gtk_combo_box_set_model(GTK_COMBO_BOX(glade_xml_get_widget(gxml, "dayCombo")), GTK_TREE_MODEL(dayCombo_store));
	renderer = gtk_cell_renderer_text_new();
	gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(glade_xml_get_widget(gxml, "dayCombo")), renderer, TRUE);
	gtk_cell_layout_add_attribute(GTK_CELL_LAYOUT(glade_xml_get_widget(gxml, "dayCombo")), renderer, "text", 0);

	if(!gconf_client_get_bool(client, "/apps/gtvg/show_toolbar", NULL)) {
		gtk_widget_hide(glade_xml_get_widget(gxml, "toolbar"));
		g_signal_handlers_block_matched((gpointer) glade_xml_get_widget(gxml, "toolbarMenuItem"), G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_toolbarMenuItem_toggled, NULL);
		gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(glade_xml_get_widget(gxml, "toolbarMenuItem")), FALSE);
		g_signal_handlers_unblock_matched((gpointer) glade_xml_get_widget(gxml, "toolbarMenuItem"), G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_toolbarMenuItem_toggled, NULL);
	} else if(!gconf_client_get_bool(client, "/apps/gtvg/show_menubar", NULL)) {
		gtk_widget_hide(glade_xml_get_widget(gxml, "menubar"));
		gtk_widget_show(glade_xml_get_widget(gxml, "menubarToolbutton"));
		g_signal_handlers_block_matched((gpointer) glade_xml_get_widget(gxml, "menubarMenuItem"), G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_menubarMenuItem_toggled, NULL);
		gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(glade_xml_get_widget(gxml, "menubarMenuItem")), FALSE);
		g_signal_handlers_unblock_matched((gpointer) glade_xml_get_widget(gxml, "menubarMenuItem"), G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_menubarMenuItem_toggled, NULL);
	}

	gstr = gconf_client_get_string(client, "/desktop/gnome/interface/toolbar_style", NULL);
	set_toolbar_style(gstr);
	g_free(gstr);

	restore_position();

	gtk_expander_set_expanded(GTK_EXPANDER(glade_xml_get_widget(gxml, "descriptionExpander")), gconf_client_get_bool(client, "/apps/gtvg/show_description", NULL));

	while(gtk_events_pending())
		gtk_main_iteration();

	if(gtk_expander_get_expanded(GTK_EXPANDER(glade_xml_get_widget(gxml, "descriptionExpander"))) && gconf_client_get_int(client, "/apps/gtvg/last_hpane_pos", NULL) > 0) {
		gtk_paned_set_position(GTK_PANED(glade_xml_get_widget(gxml, "programListPanels")), gconf_client_get_int(client, "/apps/gtvg/last_hpane_pos", NULL));
	}

	if(gconf_client_get_int(client, "/apps/gtvg/last_gridpane_pos", NULL) > 0) {
		gtk_paned_set_position(GTK_PANED(glade_xml_get_widget(gxml, "programGridPanels")), gconf_client_get_int(client, "/apps/gtvg/last_gridpane_pos", NULL));
	}

	g_signal_connect(G_OBJECT(glade_xml_get_widget(gxml, "descriptionExpander")), "notify::expanded", G_CALLBACK(on_descriptionExpander_expanded), NULL);

	gstr = gconf_client_get_string(client, "/apps/gtvg/grabber_command", NULL);
	if(gstr == NULL || strlen(gstr) == 0) {
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "updateMenuItem"), FALSE);
		gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "updateToolbutton"), FALSE);
	}
	if(gstr != NULL)
		g_free(gstr);

	return window;
}

gboolean searchNoCase(gchar * str, gchar * lower, gchar * upper)
{
	gchar *p = str, *p2, *p_bak, *pn, *pl, *pu, *pln, *pun;
	gboolean equals = FALSE;

	if(str == NULL)
		return FALSE;
	if(lower == NULL || strlen(lower) == 0)
		return TRUE;
	while(p[0] != '\0') {
		if(p[0] == lower[0] || p[0] == upper[0]) {
			p_bak = p;
			pl = lower;
			pu = upper;
			while(TRUE) {
				if(pu[0] == '\0' || pl[0] == '\0')
					break;
				if(p[0] == '\0')
					return FALSE;
				pn = g_utf8_next_char(p);
				pun = g_utf8_next_char(pu);
				pln = g_utf8_next_char(pl);
				equals = TRUE;
				p2 = p;
				while(p != pn) {
					if(p[0] != pl[0]) {
						equals = FALSE;
					}
					p++;
					pl++;
				}
				if(!equals) {
					equals = TRUE;
					p = p2;
					while(p != pn) {
						if(p[0] != pu[0]) {
							equals = FALSE;
						}
						p++;
						pu++;
					}
				}
				if(!equals)
					break;
				pu = pun;
				pl = pln;
				p = pn;
			}
			if(equals)
				return TRUE;
			p = p_bak;
		}
		p = g_utf8_next_char(p);
	}
	return FALSE;
}

gboolean search_program(struct GtvgProgram * prog, gchar * lower, gchar * upper)
{

	GSList *list;

	if(lower == NULL || strlen(lower) == 0)
		return TRUE;
	if(searchNoCase(prog->title, lower, upper))
		return TRUE;
	if(searchNoCase(prog->channel->name, lower, upper))
		return TRUE;
	if(searchNoCase(prog->subtitle, lower, upper))
		return TRUE;
	if(searchNoCase(prog->description, lower, upper))
		return TRUE;
	if(searchNoCase(prog->short_description, lower, upper))
		return TRUE;
	if(searchNoCase(prog->language, lower, upper))
		return TRUE;
	if(searchNoCase(prog->original_language, lower, upper))
		return TRUE;
	if(searchNoCase(prog->country, lower, upper))
		return TRUE;
	if(searchNoCase(prog->aspect, lower, upper))
		return TRUE;
	if(searchNoCase(prog->quality, lower, upper))
		return TRUE;
	if(searchNoCase(prog->star_rating, lower, upper))
		return TRUE;
	if(searchNoCase(prog->rating, lower, upper))
		return TRUE;
	if(searchNoCase(prog->audio_stereo, lower, upper))
		return TRUE;
	list = prog->categories;
	while(list != NULL) {
		if(searchNoCase(((struct GtvgCategory *) list->data)->name, lower, upper))
			return TRUE;
		list = g_slist_next(list);
	}
	list = prog->directors;
	while(list != NULL) {
		if(searchNoCase((gchar *) list->data, lower, upper))
			return TRUE;
		list = g_slist_next(list);
	}
	list = prog->actors;
	while(list != NULL) {
		if(searchNoCase((gchar *) list->data, lower, upper))
			return TRUE;
		list = g_slist_next(list);
	}
	list = prog->writers;
	while(list != NULL) {
		if(searchNoCase((gchar *) list->data, lower, upper))
			return TRUE;
		list = g_slist_next(list);
	}
	list = prog->adapters;
	while(list != NULL) {
		if(searchNoCase((gchar *) list->data, lower, upper))
			return TRUE;
		list = g_slist_next(list);
	}
	list = prog->producers;
	while(list != NULL) {
		if(searchNoCase((gchar *) list->data, lower, upper))
			return TRUE;
		list = g_slist_next(list);
	}
	list = prog->presenters;
	while(list != NULL) {
		if(searchNoCase((gchar *) list->data, lower, upper))
			return TRUE;
		list = g_slist_next(list);
	}
	list = prog->commentators;
	while(list != NULL) {
		if(searchNoCase((gchar *) list->data, lower, upper))
			return TRUE;
		list = g_slist_next(list);
	}
	list = prog->guests;
	while(list != NULL) {
		if(searchNoCase((gchar *) list->data, lower, upper))
			return TRUE;
		list = g_slist_next(list);
	}
	return FALSE;
}

void updateDays(void)
{
	GtkTreeIter iter, today_iter;
	time_t day_time, today_time, yesterday_time;
	struct tm day_tp, curtp;
	gboolean b, b2, today_added = FALSE;
	gchar *time_str, *gstr;

	today_time = time(NULL);
	localtime_r(&today_time, &curtp);
	curtp.tm_sec = 0;
	b = FALSE;
	if(curtp.tm_hour * 60 + curtp.tm_min < day_starts_at) {
		b = TRUE;
	}
	curtp.tm_hour = day_starts_at / 60;
	curtp.tm_min = day_starts_at % 60;
	today_time = mktime(&curtp);
	if(b)
		today_time -= 86400;
	tomorrow_time = today_time + 86400;
	yesterday_time = today_time - 86400;
	time_str = g_strnfill(80, '\0');
	b = FALSE;
	b2 = FALSE;

	g_signal_handlers_block_matched((gpointer) glade_xml_get_widget(gxml, "dayCombo"), G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_dayCombo_changed, NULL);
	gtk_list_store_clear(dayCombo_store);
	gtk_list_store_append(dayCombo_store, &iter);
	gtk_list_store_set(dayCombo_store, &iter, 0, _("All Days"), 1, (long) 0, -1);

	if(all_days || first_day == 0) {
		if(first_day == 0) {
			b2 = TRUE;
			current_day = today_time;
		}
		b = TRUE;
		if(!all_days) {
			all_days = TRUE;
			gtk_combo_box_set_active_iter(GTK_COMBO_BOX(glade_xml_get_widget(gxml, "dayCombo")), &iter);
			updateProgramList();
			b = TRUE;
		}
	}

	if(first_day != 0) {
		day_time = first_day;
		while(day_time <= last_day) {
			localtime_r(&day_time, &day_tp);
			gtk_list_store_append(dayCombo_store, &iter);
			if(day_time == yesterday_time) {
				//Yesterday ([date])
				strftime(time_str, 80, _("Yesterday (%F)"), &day_tp);
			} else if(day_time == today_time) {
				//Today ([date])
				strftime(time_str, 80, _("Today (%F)"), &day_tp);
				today_iter = iter;
				today_added = TRUE;
			} else if(day_time == tomorrow_time) {
				//Tomorrow ([date])
				strftime(time_str, 80, _("Tomorrow (%F)"), &day_tp);
			} else {
				//Day of week ([date])
				strftime(time_str, 80, _("%A (%F)"), &day_tp);
			}
			gtk_list_store_set(dayCombo_store, &iter, 0, time_str, 1, (long) day_time, -1);
			if(!b && day_time == current_day) {
				b = TRUE;
				gtk_combo_box_set_active_iter(GTK_COMBO_BOX(glade_xml_get_widget(gxml, "dayCombo")), &iter);
			}
			if(!b2 && day_time == current_day)
				b2 = TRUE;
			day_time += 86400;
		}
	}

	if(!b || !b2) {
		if(today_added) {
			current_day = today_time;
			if(!b) {
				gtk_combo_box_set_active_iter(GTK_COMBO_BOX(glade_xml_get_widget(gxml, "dayCombo")), &today_iter);
				updateProgramList();
			}
		} else {
			current_day = day_time - 86400;
			if(!b) {
				gtk_combo_box_set_active_iter(GTK_COMBO_BOX(glade_xml_get_widget(gxml, "dayCombo")), &iter);
				updateProgramList();
			}
		}
		updateProgramGrid(FALSE);
	}

	localtime_r(&current_day, &day_tp);
	if(current_day == yesterday_time) {
		//Yesterday [date]
		strftime(time_str, 80, _("Yesterday\n%F"), &day_tp);
	} else if(current_day == today_time) {
		//Today [date]
		strftime(time_str, 80, _("Today\n%F"), &day_tp);
	} else if(current_day == tomorrow_time) {
		//Tomorrow [date]
		strftime(time_str, 80, _("Tomorrow\n%F"), &day_tp);
	} else {
		//Day of week [date]
		strftime(time_str, 80, _("%A\n%F"), &day_tp);
	}
	gstr = g_strdup_printf("<big>%s</big>", time_str);
	gtk_label_set_markup(GTK_LABEL(glade_xml_get_widget(gxml, "gridDateLabel")), gstr);
	g_free(gstr);
	g_free(time_str);

	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "gridForwardButton"), first_day != 0 && last_day > current_day);
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "gridBackButton"), first_day != 0 && first_day < current_day);
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "gridHomeButton"), current_day != tomorrow_time - 86400);

	g_signal_handlers_unblock_matched((gpointer) glade_xml_get_widget(gxml, "dayCombo"), G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_dayCombo_changed, NULL);

}

void gfree_hashtable_values(gpointer key, gpointer value, gpointer user_data)
{
	if(value != NULL)
		g_free(value);
}

void unref_hashtable_values(gpointer key, gpointer value, gpointer user_data)
{
	if(value != NULL)
		g_object_unref(G_OBJECT(value));
}

void gfree_hashtable_value(gpointer value)
{
	if(value != NULL)
		g_free(value);
}

void unref_hashtable_value(gpointer value)
{
	if(value != NULL)
		g_object_unref(G_OBJECT(value));
}

void free_list_category(gpointer data, gpointer user_data)
{
	gtvg_category_free((struct GtvgCategory *) data);
}

void free_slist_favsched(gpointer data, gpointer user_data)
{
	free_favsched((struct favourite_schedule *) data);
}

void free_slist_recsched(gpointer data, gpointer user_data)
{
	free_recsched((struct record_schedule *) data);
}

void free_slist_favourite(gpointer data, gpointer user_data)
{
	gtvg_favourite_free((struct GtvgFavourite *) data);
}

void free_slist_program(gpointer data, gpointer user_data)
{
	gtvg_program_free((struct GtvgProgram *) data);
}

void free_slist_channel(gpointer data, gpointer user_data)
{
	gtvg_channel_free((struct GtvgChannel *) data);
}

void free_slist_gchar(gpointer data, gpointer user_data)
{
	g_free((gchar *) data);
}

void updateChannelIcons(void)
{
	GtkTreeIter iter;
	gchar *gstr, *tmpstr;
	struct GtvgChannel *ch;
	GtkWidget *dialog, *progressDialog;
	GdkPixbuf *iconbuf;
	gboolean valid;
	gboolean dir_created = FALSE;
	gboolean has_gnomevfs = FALSE, has_wget = FALSE;
	GError *error = NULL;
	gint item_count;
	gfloat progress_step;

	gstr = g_find_program_in_path("gnomevfs-copy");
	if(gstr) {
		g_free(gstr);
		has_gnomevfs = TRUE;
	} else {
		gstr = g_find_program_in_path("wget");
		if(gstr) {
			has_wget = TRUE;
			g_free(gstr);
		} else {
			dialog = gtk_message_dialog_new(GTK_WINDOW(window), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, _("wget or gnomevfs is needed for channel icon downloads."));
			gtk_dialog_run(GTK_DIALOG(dialog));
			gtk_widget_destroy(dialog);
			return;
		}
	}
	valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(channelsList_store), &iter);
	if(!valid)
		return;
	item_count = gtk_tree_model_iter_n_children(GTK_TREE_MODEL(channelsList_store), NULL);
	progress_step = 1.0 / (item_count + 1);
	progressDialog = glade_xml_get_widget(gxml, "progressDialog");
	gtk_label_set_text(GTK_LABEL(glade_xml_get_widget(gxml, "progressLabel")), _("Downloading channel icons..."));
	gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(glade_xml_get_widget(gxml, "loadingProgressBar")), 0.0);
	gtk_widget_show(progressDialog);
	while(gtk_events_pending())
		gtk_main_iteration();
	item_count = 0;
	while(valid) {
		gtk_tree_model_get(GTK_TREE_MODEL(channelsList_store), &iter, CHANNELS_OBJECT_COLUMN, &ch, -1);
		item_count++;
		if(ch != NULL) {
			if(!ch->custom_icon && ch->iconurl != NULL) {
				iconbuf = NULL;
				gstr = g_path_get_basename(ch->iconurl);
				tmpstr = g_build_path(G_DIR_SEPARATOR_S, g_get_home_dir(), ".xmltv", "icons", gstr, NULL);
				g_free(gstr);
				if(!dir_created) {
					gstr = g_path_get_dirname(tmpstr);
					g_mkdir_with_parents(gstr, S_IRWXU);
					g_free(gstr);
					dir_created = TRUE;
				}
				if(has_gnomevfs) {
					gstr = g_strdup_printf("gnomevfs-copy %s %s", ch->iconurl, tmpstr);
					if(g_spawn_command_line_sync(gstr, NULL, NULL, NULL, &error)) {
						iconbuf = gdk_pixbuf_new_from_file_at_scale(tmpstr, -1, 22, TRUE, NULL);
					} else {
						g_printerr(_("Failed to download channel icon (using %s): %s"), gstr, error->message);
						g_error_free(error);
					}
					g_free(gstr);
				} else if(has_wget) {
					gstr = g_strdup_printf("wget --output-document=%s %s", tmpstr, ch->iconurl);
					if(g_spawn_command_line_sync(gstr, NULL, NULL, NULL, &error)) {
						iconbuf = gdk_pixbuf_new_from_file_at_scale(tmpstr, -1, 22, TRUE, NULL);
					} else {
						g_printerr(_("Failed to download channel icon (using %s): %s"), gstr, error->message);
						g_error_free(error);
					}
					g_free(gstr);
				}
				if(iconbuf != NULL) {
					gtk_list_store_set(channelsList_store, &iter, 1, iconbuf, -1);
					if(ch->icon)
						g_object_unref(ch->icon);
					if(ch->iconpath)
						g_free(ch->iconpath);
					ch->icon = iconbuf;
					ch->iconpath = tmpstr;
				} else {
					g_free(tmpstr);
				}
			}
		}
		gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(glade_xml_get_widget(gxml, "loadingProgressBar")), item_count * progress_step);
		while(gtk_events_pending())
			gtk_main_iteration();
		valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(channelsList_store), &iter);
	}
	gtk_widget_hide(progressDialog);
	updateProgramGrid(TRUE);
}

gint channels_compare_func(gconstpointer a, gconstpointer b)
{
	struct GtvgChannel *c1 = (struct GtvgChannel *) a;
	struct GtvgChannel *c2 = (struct GtvgChannel *) b;

	if(channels_moved) {
		if(c1->index < 0 && c2->index < 0)
			return strcmp(c1->name, c2->name);
		if(c1->index < 0)
			return 1;
		if(c2->index < 0)
			return -1;
		if(c1->index > c2->index)
			return 1;
		if(c1->index < c2->index)
			return -1;
	}
	return strcmp(c1->name, c2->name);
}

gint programs_compare_func(gconstpointer a, gconstpointer b)
{
	struct GtvgProgram *p1 = (struct GtvgProgram *) a;
	struct GtvgProgram *p2 = (struct GtvgProgram *) b;

	if(p1->start < p2->start)
		return -1;
	if(p1->start > p2->start)
		return 1;
	if(p1->stop < p2->stop)
		return -1;
	if(p1->stop > p2->stop)
		return 1;
	if(p1->channel == NULL)
		return -1;
	if(p2->channel == NULL)
		return 1;
	return channels_compare_func(p1->channel, p2->channel);
}

gint prch_compare_func(gconstpointer a, gconstpointer b)
{
	struct GtvgProgram *p1 = (struct GtvgProgram *) a;
	struct GtvgProgram *p2 = (struct GtvgProgram *) b;

	if(p1->start < p2->start)
		return -1;
	if(p1->start > p2->start)
		return 1;
	return 0;
}

gchar *createDescription(struct GtvgProgram * prog, gboolean for_reminder, GtkTextBuffer * tb)
{

	gchar *time_str, *start_str, *stop_str, *gstr, *title_str;
	GString *str;
	GSList *list;
	time_t curtime;
	struct tm curtp, tmptp;
	time_t first_time, last_time, today_start;
	GtkTextIter iter;

	if(all_days) {
		first_time = 0;
		last_time = 0;
	} else {
		first_time = current_day;
		last_time = first_time + 86400;
	}

	curtime = time(NULL);
	localtime_r(&curtime, &curtp);

	tmptp = curtp;
	tmptp.tm_sec = 0;
	tmptp.tm_min = 0;
	tmptp.tm_hour = 0;
	today_start = mktime(&tmptp);

	start_str = g_strnfill(80, '\0');
	stop_str = g_strnfill(80, '\0');
	time_str = g_strnfill(200, '\0');

	if(!for_reminder) {
		gtk_text_buffer_set_text(tb, "", 0);
		gtk_text_buffer_get_start_iter(tb, &iter);
	}
	//Time (hh:mm)
	strftime(stop_str, 80, "%R", &prog->stop_tm);
	if(first_time > 0 || (curtp.tm_year == prog->start_tm.tm_year && curtp.tm_mon == prog->start_tm.tm_mon && curtp.tm_mday == prog->start_tm.tm_mday)) {
		strftime(start_str, 80, "%R", &prog->start_tm);
	} else if(prog->start >= today_start + 604800 || prog->start < today_start - 86400) {
		//date and time in description (ex. "Wednesday 7 May 20:00")
		strftime(start_str, 80, _("%A %e %B %R"), &prog->start_tm);
	} else {
		//day of week and time in description (ex. "Thursday 20:00")
		strftime(start_str, 80, _("%A %R"), &prog->start_tm);
	}
	//time interval ("20:00 - 21:30")
	g_snprintf(time_str, 200, _("%s\342\200\223%s"), start_str, stop_str);
	g_free(start_str);
	g_free(stop_str);
	str = g_string_sized_new(100);
	if(for_reminder) {
		if(prog->start <= curtime) {
			//Has started on [channel] ([time interval])
			g_string_append_printf(str, _("Has started on %s (%s)"), prog->channel->name, time_str);
		} else if(prog->start - curtime < 60) {
			//starts in [time left] seconds(s) on [channel] ([time interval])
			g_string_append_printf(str, ngettext("Starts in %i second on %s (%s)", "Starts in %i seconds on %s (%s)", prog->start - curtime), (int) (prog->start - curtime), prog->channel->name, time_str);
		} else {
			//starts in [time left] minute(s) on [channel] ([time interval])
			g_string_append_printf(str, ngettext("Starts in %i minute on %s (%s)", "Starts in %i minutes on %s (%s)", (unsigned long int) roundf((float) (prog->start - curtime) / 60.0)), (int) roundf((float) (prog->start - curtime) / 60.0), prog->channel->name, time_str);
		}
	} else {
		if(prog->subtitle != NULL) {
			//[title]: [subtitle]
			title_str = g_strdup_printf(_("%s: %s"), prog->title, prog->subtitle);
		} else {
			title_str = prog->title;
		}
		//[title] ([time interval] on [channel])
		g_string_append_printf(str, _("%s (%s on %s)"), title_str, time_str, prog->channel->name);
		gtk_text_buffer_insert_with_tags_by_name(tb, &iter, str->str, -1, "title", NULL);
		if(prog->subtitle != NULL) {
			g_free(title_str);
		}
		g_string_truncate(str, 0);
	}
	g_free(time_str);

	if(for_reminder && !reminder_details) {
		return g_string_free(str, FALSE);
	}

	if(for_reminder)
		g_string_append(str, "\n");
	else
		gtk_text_buffer_insert_with_tags_by_name(tb, &iter, "\n", -1, "line", NULL);

	if(prog->description != NULL) {
		if(for_reminder) {
			g_string_append(str, "\n");
			if(for_reminder && prog->short_description != NULL)
				g_string_append(str, prog->short_description);
			else
				g_string_append(str, prog->description);
			g_string_append(str, "\n");
		} else {
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, "\n", -1, "line", NULL);
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, prog->description, -1, "description", NULL);
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, "\n", -1, "line", NULL);
		}
	}
	if(prog->date != NULL && prog->country != NULL) {
		if(for_reminder)
			g_string_append(str, "\n");
		else
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, "\n", -1, "line", NULL);
		g_string_append(str, prog->country);
		g_string_append(str, ", ");
		g_string_append(str, prog->date);
		if(!for_reminder) {
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, str->str, -1, "value", NULL);
			g_string_truncate(str, 0);
		}
	}
	//Time (ex. 20:00)
	gstr = g_strdup_printf(_("%li:%.2li"), (long) (prog->stop - prog->start) / 3600, (long) ((prog->stop - prog->start) % 3600) / 60);
	if(for_reminder) {
		g_string_append(str, "\n");
		g_string_append(str, _("Duration:"));
		g_string_append(str, " ");
		g_string_append(str, gstr);
	} else {
		gtk_text_buffer_insert_with_tags_by_name(tb, &iter, "\n", -1, "line", NULL);
		gtk_text_buffer_insert_with_tags_by_name(tb, &iter, _("Duration:"), -1, "property", NULL);
		gtk_text_buffer_insert(tb, &iter, " ", -1);
		gtk_text_buffer_insert_with_tags_by_name(tb, &iter, gstr, -1, "value", NULL);
	}
	g_free(gstr);
	if(!for_reminder && prog->length != NULL) {
		if(for_reminder) {
			g_string_append(str, "\n");
			g_string_append(str, _("Actual length:"));
			g_string_append(str, " ");
		} else {
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, "\n", -1, "line", NULL);
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, _("Actual length:"), -1, "property", NULL);
			gtk_text_buffer_insert(tb, &iter, " ", -1);
		}
		if(prog->length_units != NULL) {
			if(strcmp(prog->length_units, "seconds") == 0) {
				//Second(s)
				gstr = g_strdup_printf(_("%s s"), prog->length);
				g_string_append(str, gstr);
				g_free(gstr);
			} else if(strcmp(prog->length_units, "minutes") == 0) {
				//Minute(s)
				gstr = g_strdup_printf(_("%s min"), prog->length);
				g_string_append(str, gstr);
				g_free(gstr);
			} else if(strcmp(prog->length_units, "hours") == 0) {
				//Hour(s)
				gstr = g_strdup_printf(_("%s h"), prog->length);
				g_string_append(str, gstr);
				g_free(gstr);
			} else {
				g_string_append(str, prog->length);
			}
		} else {
			g_string_append(str, prog->length);
		}
		if(!for_reminder) {
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, str->str, -1, "value", NULL);
			g_string_truncate(str, 0);
		}
	}
	if(prog->episode != NULL) {
		if(for_reminder) {
			g_string_append(str, "\n");
			g_string_append(str, _("Episode:"));
			g_string_append(str, " ");
			g_string_append(str, prog->episode);
		} else {
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, "\n", -1, "line", NULL);
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, _("Episode:"), -1, "property", NULL);
			gtk_text_buffer_insert(tb, &iter, " ", -1);
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, prog->episode, -1, "value", NULL);
		}
	}
	if(!for_reminder && (prog->date == NULL || prog->country == NULL)) {
		if(prog->date != NULL) {
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, "\n", -1, "line", NULL);
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, _("Date:"), -1, "property", NULL);
			gtk_text_buffer_insert(tb, &iter, " ", -1);
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, prog->date, -1, "value", NULL);
		}
		if(prog->country != NULL) {
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, "\n", -1, "line", NULL);
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, _("Country:"), -1, "property", NULL);
			gtk_text_buffer_insert(tb, &iter, " ", -1);
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, prog->country, -1, "value", NULL);
		}
	}
	if(!for_reminder && prog->language != NULL) {
		gtk_text_buffer_insert_with_tags_by_name(tb, &iter, "\n", -1, "line", NULL);
		gtk_text_buffer_insert_with_tags_by_name(tb, &iter, _("Language:"), -1, "property", NULL);
		gtk_text_buffer_insert(tb, &iter, " ", -1);
		gtk_text_buffer_insert_with_tags_by_name(tb, &iter, prog->language, -1, "value", NULL);
	}
	if(!for_reminder && prog->original_language != NULL) {
		gtk_text_buffer_insert_with_tags_by_name(tb, &iter, "\n", -1, "line", NULL);
		gtk_text_buffer_insert_with_tags_by_name(tb, &iter, _("Original language:"), -1, "property", NULL);
		gtk_text_buffer_insert(tb, &iter, " ", -1);
		gtk_text_buffer_insert_with_tags_by_name(tb, &iter, prog->original_language, -1, "value", NULL);
	}
	if(prog->directors != NULL) {
		if(for_reminder) {
			g_string_append(str, "\n");
			g_string_append(str, ngettext("Director:", "Directors:", g_slist_length(prog->directors)));
			g_string_append(str, " ");
		} else {
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, "\n", -1, "line", NULL);
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, ngettext("Director:", "Directors:", g_slist_length(prog->directors)), -1, "property", NULL);
			gtk_text_buffer_insert(tb, &iter, " ", -1);
		}
		list = prog->directors;
		while(list != NULL) {
			if(list != prog->directors)
				g_string_append(str, ", ");
			g_string_append(str, (gchar *) list->data);
			list = g_slist_next(list);
		}
		if(!for_reminder) {
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, str->str, -1, "value", NULL);
			g_string_truncate(str, 0);
		}
	}
	if(prog->actors != NULL) {
		if(for_reminder) {
			g_string_append(str, "\n");
			g_string_append(str, ngettext("Actor:", "Actors:", g_slist_length(prog->actors)));
			g_string_append(str, " ");
		} else {
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, "\n", -1, "line", NULL);
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, ngettext("Actor:", "Actors:", g_slist_length(prog->actors)), -1, "property", NULL);
			gtk_text_buffer_insert(tb, &iter, " ", -1);
		}
		list = prog->actors;
		while(list != NULL) {
			if(list != prog->actors)
				g_string_append(str, ", ");
			g_string_append(str, (gchar *) list->data);
			list = g_slist_next(list);
		}
		if(!for_reminder) {
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, str->str, -1, "value", NULL);
			g_string_truncate(str, 0);
		}
	}
	if(prog->writers != NULL) {
		if(for_reminder) {
			g_string_append(str, "\n");
			g_string_append(str, ngettext("Writer:", "Writers:", g_slist_length(prog->writers)));
			g_string_append(str, " ");
		} else {
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, "\n", -1, "line", NULL);
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, ngettext("Writer:", "Writers:", g_slist_length(prog->writers)), -1, "property", NULL);
			gtk_text_buffer_insert(tb, &iter, " ", -1);
		}
		list = prog->writers;
		while(list != NULL) {
			if(list != prog->writers)
				g_string_append(str, ", ");
			g_string_append(str, (gchar *) list->data);
			list = g_slist_next(list);
		}
		if(!for_reminder) {
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, str->str, -1, "value", NULL);
			g_string_truncate(str, 0);
		}
	}
	if(prog->adapters != NULL) {
		if(for_reminder) {
			g_string_append(str, "\n");
			g_string_append(str, ngettext("Adapter:", "Adapters:", g_slist_length(prog->adapters)));
			g_string_append(str, " ");
		} else {
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, "\n", -1, "line", NULL);
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, ngettext("Adapter:", "Adapters:", g_slist_length(prog->adapters)), -1, "property", NULL);
			gtk_text_buffer_insert(tb, &iter, " ", -1);
		}
		list = prog->adapters;
		while(list != NULL) {
			if(list != prog->adapters)
				g_string_append(str, ", ");
			g_string_append(str, (gchar *) list->data);
			list = g_slist_next(list);
		}
		if(!for_reminder) {
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, str->str, -1, "value", NULL);
			g_string_truncate(str, 0);
		}
	}
	if(prog->producers != NULL) {
		if(for_reminder) {
			g_string_append(str, "\n");
			g_string_append(str, ngettext("Producer:", "Producers:", g_slist_length(prog->producers)));
			g_string_append(str, " ");
		} else {
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, "\n", -1, "line", NULL);
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, ngettext("Producer:", "Producers:", g_slist_length(prog->producers)), -1, "property", NULL);
			gtk_text_buffer_insert(tb, &iter, " ", -1);
		}
		list = prog->producers;
		while(list != NULL) {
			if(list != prog->producers)
				g_string_append(str, ", ");
			g_string_append(str, (gchar *) list->data);
			list = g_slist_next(list);
		}
		if(!for_reminder) {
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, str->str, -1, "value", NULL);
			g_string_truncate(str, 0);
		}
	}
	if(prog->presenters != NULL) {
		if(for_reminder) {
			g_string_append(str, "\n");
			g_string_append(str, ngettext("Presenter:", "Presenters:", g_slist_length(prog->presenters)));
			g_string_append(str, " ");
		} else {
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, "\n", -1, "line", NULL);
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, ngettext("Presenter:", "Presenters:", g_slist_length(prog->presenters)), -1, "property", NULL);
			gtk_text_buffer_insert(tb, &iter, " ", -1);
		}
		list = prog->presenters;
		while(list != NULL) {
			if(list != prog->presenters)
				g_string_append(str, ", ");
			g_string_append(str, (gchar *) list->data);
			list = g_slist_next(list);
		}
		if(!for_reminder) {
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, str->str, -1, "value", NULL);
			g_string_truncate(str, 0);
		}
	}
	if(prog->commentators != NULL) {
		if(for_reminder) {
			g_string_append(str, "\n");
			g_string_append(str, ngettext("Commentator:", "Commentators:", g_slist_length(prog->commentators)));
			g_string_append(str, " ");
		} else {
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, "\n", -1, "line", NULL);
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, ngettext("Commentator:", "Commentators:", g_slist_length(prog->commentators)), -1, "property", NULL);
			gtk_text_buffer_insert(tb, &iter, " ", -1);
		}
		list = prog->commentators;
		while(list != NULL) {
			if(list != prog->commentators)
				g_string_append(str, ", ");
			g_string_append(str, (gchar *) list->data);
			list = g_slist_next(list);
		}
		if(!for_reminder) {
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, str->str, -1, "value", NULL);
			g_string_truncate(str, 0);
		}
	}
	if(prog->guests != NULL) {
		if(for_reminder) {
			g_string_append(str, "\n");
			g_string_append(str, ngettext("Guest:", "Guests:", g_slist_length(prog->guests)));
			g_string_append(str, " ");
		} else {
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, "\n", -1, "line", NULL);
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, ngettext("Guest:", "Guests:", g_slist_length(prog->guests)), -1, "property", NULL);
			gtk_text_buffer_insert(tb, &iter, " ", -1);
		}
		list = prog->guests;
		while(list != NULL) {
			if(list != prog->guests)
				g_string_append(str, ", ");
			g_string_append(str, (gchar *) list->data);
			list = g_slist_next(list);
		}
		if(!for_reminder) {
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, str->str, -1, "value", NULL);
			g_string_truncate(str, 0);
		}
	}
	if(!for_reminder && prog->categories != NULL) {
		gboolean different_origcats = FALSE;
		if(for_reminder) {
			g_string_append(str, "\n");
			g_string_append(str, ngettext("Category:", "Categories:", g_slist_length(prog->categories)));
			g_string_append(str, " ");
		} else {
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, "\n", -1, "line", NULL);
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, ngettext("Category:", "Categories:", g_slist_length(prog->categories)), -1, "property", NULL);
			gtk_text_buffer_insert(tb, &iter, " ", -1);
		}
		list = prog->categories;
		while(list != NULL) {
			struct GtvgCategory *cat = (struct GtvgCategory *) list->data;
			if(list != prog->categories)
				g_string_append(str, ", ");			
			if(!different_origcats && g_slist_length(cat->original_names) > 1) {
				different_origcats = TRUE;
			}
			g_string_append(str, cat->name);
			list = g_slist_next(list);
		}
		if(different_origcats) {
			g_string_append(str, " (");
			list = prog->original_categories;
			while(list != NULL) {
				if(list != prog->original_categories)
					g_string_append(str, ", ");
				g_string_append(str, (gchar*) list->data);
				list = g_slist_next(list);
			}
			g_string_append(str, ")");
		}
		if(!for_reminder) {
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, str->str, -1, "value", NULL);
			g_string_truncate(str, 0);
		}
	}
	if(prog->previously_shown) {
		if(for_reminder)
			g_string_append(str, "\n");
		else
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, "\n", -1, "line", NULL);
		if(prog->previous_start || prog->previous_channel) {
			if(prog->previous_start != NULL && prog->previous_channel != NULL) {
				//Previously shown on [channel] [time]
				gstr = g_strdup_printf(_("Previously shown on %s %s"), prog->previous_channel->name, prog->previous_start);
			} else if(prog->previous_start) {
				//Previously shown [time]
				gstr = g_strdup_printf(_("Previously shown %s"), prog->previous_start);
			} else {
				//Previously shown on [channel]
				gstr = g_strdup_printf(_("Previously shown on %s"), prog->previous_channel->name);
			}
			if(for_reminder) {
				g_string_append(str, gstr);
			} else {
				gtk_text_buffer_insert_with_tags_by_name(tb, &iter, gstr, -1, "value", NULL);
			}
			g_free(gstr);
		} else {
			if(for_reminder) {
				g_string_append(str, _("Previously shown"));
			} else {
				gtk_text_buffer_insert_with_tags_by_name(tb, &iter, _("Previously shown"), -1, "value", NULL);
			}
		}
	}
	if(prog->new_program) {
		if(for_reminder) {
			g_string_append(str, "\n\n");
			g_string_append(str, _("This is a new program."));
		} else {
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, "\n", -1, "line", NULL);
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, "\n", -1, "line", NULL);
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, _("This is a new program"), -1, "value", NULL);
		}
	}
	if(prog->star_rating != NULL) {
		int i_rating, i_max_rating;
		size_t i1, i2;
		char c;

		if(for_reminder) {
			g_string_append(str, "\n\n");
			g_string_append(str, _("Rating:"));
			g_string_append(str, " ");
		} else {
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, "\n", -1, "line", NULL);
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, "\n", -1, "line", NULL);
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, _("Rating:"), -1, "property", NULL);
			gtk_text_buffer_insert(tb, &iter, " ", -1);
		}
		i1 = 0;
		i2 = strlen(prog->star_rating);
		while(i1 < i2 && g_ascii_isdigit(prog->star_rating[i1])) {
			i1++;
		}
		if(i1 == 0) {
			g_string_append(str, prog->star_rating);
		} else {
			if(i1 != i2) {
				c = prog->star_rating[i1];
				prog->star_rating[i1] = '\0';
			}
			i_rating = (int) g_ascii_strtod(prog->star_rating, NULL);
			i_max_rating = 0;
			if(i1 != i2) {
				prog->star_rating[i1] = c;
				while(i1 < i2 && !g_ascii_isdigit(prog->star_rating[i1])) {
					i1++;
				}
				if(i1 != i2) {
					i_max_rating = (int) g_ascii_strtod(prog->star_rating + i1, NULL);
				}
			}
			if(!can_display_star) {
				while(i_rating > 0) {
					g_string_append(str, "* ");
					i_rating--;
				}
				if(i_max_rating > 0) {
					g_string_append(str, "(");
					g_string_append(str, prog->star_rating);
					g_string_append(str, ")");
				}
			} else {
				i_max_rating -= i_rating;
				while(i_rating > 0) {
					g_string_append(str, "\342\230\205 ");
					i_rating--;
				}
				while(i_max_rating > 0) {
					g_string_append(str, "\342\230\206 ");
					i_max_rating--;
				}
			}
		}
		if(!for_reminder) {
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, str->str, -1, "value", NULL);
			g_string_truncate(str, 0);
		}
	}
	if(prog->rating != NULL) {
		if(for_reminder) {
			g_string_append(str, "\n");
			g_string_append(str, _("Parental rating:"));
			g_string_append(str, " ");
			g_string_append(str, prog->rating);
		} else {
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, "\n", -1, "line", NULL);
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, _("Parental rating:"), -1, "property", NULL);
			gtk_text_buffer_insert(tb, &iter, " ", -1);
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, prog->rating, -1, "value", NULL);
		}
	}
	if(!for_reminder) {
		if(prog->aspect != NULL || prog->quality != NULL || prog->color != NULL || prog->showview != NULL || prog->videoplus != NULL) {
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, "\n", -1, "line", NULL);
		}
		if(prog->aspect != NULL) {
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, "\n", -1, "line", NULL);
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, _("Aspect ratio:"), -1, "property", NULL);
			gtk_text_buffer_insert(tb, &iter, " ", -1);
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, prog->aspect, -1, "value", NULL);
		}
		if(prog->quality != NULL) {
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, "\n", -1, "line", NULL);
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, _("Quality:"), -1, "property", NULL);
			gtk_text_buffer_insert(tb, &iter, " ", -1);
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, prog->quality, -1, "value", NULL);
		}
		if(prog->color != NULL) {
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, "\n", -1, "line", NULL);
			if(strcmp(prog->color, "no") == 0) {
				gtk_text_buffer_insert_with_tags_by_name(tb, &iter, _("In black & white"), -1, "value", NULL);
			} else if(strcmp(prog->color, "yes") == 0) {
				gtk_text_buffer_insert_with_tags_by_name(tb, &iter, _("In color"), -1, "value", NULL);
			} else {
				gtk_text_buffer_insert_with_tags_by_name(tb, &iter, _("Color:"), -1, "property", NULL);
				gtk_text_buffer_insert(tb, &iter, " ", -1);
				gtk_text_buffer_insert_with_tags_by_name(tb, &iter, prog->color, -1, "value", NULL);
			}
		}
		if(prog->audio_present != NULL && strcmp(prog->audio_present, "no") == 0) {
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, "\n", -1, "line", NULL);
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, _("Audio:"), -1, "property", NULL);
			gtk_text_buffer_insert(tb, &iter, " ", -1);
			//no audio
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, _("none"), -1, "value", NULL);
		} else if(prog->audio_stereo != NULL) {
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, "\n", -1, "line", NULL);
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, _("Audio:"), -1, "property", NULL);
			gtk_text_buffer_insert(tb, &iter, " ", -1);
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, prog->audio_stereo, -1, "value", NULL);
		}
		if(prog->showview != NULL) {
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, "\n", -1, "line", NULL);
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, _("Showview:"), -1, "property", NULL);
			gtk_text_buffer_insert(tb, &iter, " ", -1);
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, prog->showview, -1, "value", NULL);
		}
		if(prog->videoplus != NULL) {
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, "\n", -1, "line", NULL);
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, _("Videoplus:"), -1, "property", NULL);
			gtk_text_buffer_insert(tb, &iter, " ", -1);
			gtk_text_buffer_insert_with_tags_by_name(tb, &iter, prog->videoplus, -1, "value", NULL);
		}
	}
	if(for_reminder)
		g_string_append(str, "\n");
	else
		gtk_text_buffer_insert_with_tags_by_name(tb, &iter, "\n", -1, "line", NULL);

	if(for_reminder) {
		return g_string_free(str, FALSE);
	}

	g_string_free(str, TRUE);
	return NULL;

}

void markFavourite(GtkListStore * store, GtkTreeIter * iter, gboolean onlyfavs, struct GtvgProgram *prog)
{
	gchar *gstr1 = g_markup_escape_text(prog->title, -1);

	if(prog->favourites != NULL) {
		GSList *list2 = prog->favourites;

		while(list2 != NULL) {
			struct GtvgFavourite *fav = (struct GtvgFavourite *) list2->data;

			if(fav->record > 0 || (recordings_enabled && fav->record < 0)) {
				gchar *gstr2;

				if(onlyfavs)
					gstr2 = g_strconcat("<span weight=\"bold\" foreground=\"red\"><sup>R</sup></span> ", gstr1, NULL);
				else
					gstr2 = g_strconcat("<span weight=\"bold\" foreground=\"red\"><sup>R</sup></span> <span size=\"larger\" weight=\"bold\">", gstr1, "</span>", NULL);
				gtk_list_store_set(programList_store, iter, TITLE_COLUMN, gstr2, -1);
				g_free(gstr2);
				break;
			}
			list2 = g_slist_next(list2);
		}
		if(list2 == NULL) {
			if(onlyfavs) {
				if(can_display_heart) {
					gchar *gstr2 = g_strconcat("<span weight=\"bold\" foreground=\"deep pink\"><sup>&#9829;</sup></span> ", gstr1, NULL);

					gtk_list_store_set(programList_store, iter, TITLE_COLUMN, gstr2, -1);
					g_free(gstr2);
				} else {
					gtk_list_store_set(programList_store, iter, TITLE_COLUMN, gstr1, -1);
				}
			} else {
				gchar *gstr2;

				if(can_display_heart)
					gstr2 = g_strconcat("<span weight=\"bold\" foreground=\"deep pink\"><sup>&#9829;</sup></span> <span size=\"larger\" weight=\"bold\">", gstr1, "</span>", NULL);
				else
					gstr2 = g_strconcat("<span size=\"larger\" weight=\"bold\">", gstr1, "</span>", NULL);
				gtk_list_store_set(programList_store, iter, TITLE_COLUMN, gstr2, -1);
				g_free(gstr2);
			}
		}
	} else {
		gtk_list_store_set(programList_store, iter, TITLE_COLUMN, gstr1, -1);
	}
	g_free(gstr1);
}

void markFavourites(void)
{

	GtkTreeIter iter;
	GtkTreeModel *model;
	gboolean valid, onlyfavs;
	struct GtvgProgram *prog;
	GSList *list, *list2;
	time_t curtime;
	gchar *gstr, *gstr2;
	gchar *start_str, *stop_str, *time_str;

	start_str = g_strnfill(80, '\0');
	stop_str = g_strnfill(80, '\0');
	time_str = g_strnfill(200, '\0');

	curtime = time(NULL);

	onlyfavs = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "showFavouritesButton")));
	model = GTK_TREE_MODEL(programList_store);
	valid = gtk_tree_model_get_iter_first(model, &iter);
	while(valid) {
		gtk_tree_model_get(model, &iter, OBJECT_COLUMN, &prog, -1);
		markFavourite(GTK_LIST_STORE(model), &iter, onlyfavs, prog);
		valid = gtk_tree_model_iter_next(model, &iter);
	}

	list = programs;
	while(list != NULL) {
		prog = (struct GtvgProgram *) list->data;
		if(prog->canvas_rect != NULL && prog->canvas_text != NULL && prog->canvas_favourite != (prog->favourites != NULL)) {
			prog->canvas_favourite = (prog->favourites != NULL);
			g_object_set(G_OBJECT(prog->canvas_rect), "fill-color-gdk", prog == selected_gridprog ? &selected_bg_color : (prog->start <= curtime && prog->stop > curtime ? &current_bg_color : (prog->favourites != NULL ? favBgColor(prog) : defBgColor(prog))), "outline-color-gdk", prog == selected_gridprog ? &selected_border_color : (prog->start <= curtime && prog->stop > curtime ? &current_border_color : (prog->favourites != NULL ? &favourite_border_color : &default_border_color)), NULL);
			strftime(stop_str, 80, "%R", &prog->stop_tm);
			strftime(start_str, 80, "%R", &prog->start_tm);
			//time interval ("20:00 - 21:30")
			g_snprintf(time_str, 200, _("%s\342\200\223%s"), start_str, stop_str);
			if(prog->favourites != NULL) {
				gstr = g_markup_escape_text(prog->title, -1);
				gstr2 = g_strdup_printf("%s\n%s", gstr, time_str);
				g_free(gstr);
				list2 = prog->favourites;
				while(list2 != NULL) {
					struct GtvgFavourite *fav = (struct GtvgFavourite *) list2->data;

					if(fav->record > 0 || (recordings_enabled && fav->record < 0)) {
						gstr = g_strconcat(gstr2, " <span weight=\"bold\" foreground=\"red\">R</span>", NULL);
						break;
					}
					list2 = g_slist_next(list2);
				}
				if(list2 == NULL) {
					if(can_display_heart) {
						gstr = g_strconcat(gstr2, " <span weight=\"bold\" foreground=\"deep pink\">&#9829;</span>", NULL);
					} else {
						gstr = g_strconcat(gstr2, " <span weight=\"bold\" foreground=\"deep pink\">*</span>", NULL);
					}
				}
				g_free(gstr2);
				prog->canvas_favourite = TRUE;
			} else {
				gstr = g_strdup_printf("%s\n%s", prog->title, time_str);
				prog->canvas_favourite = FALSE;
			}
			if(prog->favourites != NULL) {
				g_object_set(G_OBJECT(prog->canvas_text), "markup", gstr, NULL);
			} else {
				g_object_set(G_OBJECT(prog->canvas_text), "markup", "", NULL);
				g_object_set(G_OBJECT(prog->canvas_text), "text", gstr, NULL);
			}
			g_free(gstr);
			g_object_set(G_OBJECT(prog->canvas_text), "fill-color-gdk", prog == selected_gridprog ? &selected_text_color : (prog->start <= curtime && prog->stop > curtime ? &current_text_color : (prog->favourites != NULL ? favTextColor(prog) : defTextColor(prog))), "weight", prog->favourites != NULL ? PANGO_WEIGHT_BOLD : PANGO_WEIGHT_NORMAL, NULL);
		}
		list = g_slist_next(list);
	}
	g_free(start_str);
	g_free(stop_str);
	g_free(time_str);
}

void updateRecSchedule(void)
{
	struct GtvgProgram *prog;
	struct record_schedule *recsched = NULL, *prev_recsched = NULL;
	gboolean b, has_conflicts = FALSE, b_disabled;
	gint priority;
	size_t starttime;
	gint startm = 0, endm = 0;
	GSList *list = programs;

	if(rec_timeout_running)
		g_source_remove(rec_timeout_id);

	rec_timeout_running = FALSE;

	if(record_schedules != NULL) {
		g_slist_foreach(record_schedules, free_slist_recsched, NULL);
		g_slist_free(record_schedules);
		record_schedules = NULL;
	}
	if(disabled_record_schedules != NULL) {
		g_slist_foreach(disabled_record_schedules, free_slist_recsched, NULL);
		g_slist_free(disabled_record_schedules);
		disabled_record_schedules = NULL;
	}
	if(current_record_stop_time > 0)
		starttime = current_record_stop_time;
	else
		starttime = time(NULL);
	while(list != NULL) {
		prog = (struct GtvgProgram *) list->data;
		if(prog->stop > starttime) {
			GSList *list2 = prog->favourites;

			startm = 0, endm = 0;
			b = FALSE;
			b_disabled = FALSE;
			priority = 0;
			while(list2 != NULL) {
				struct GtvgFavourite *fav = (struct GtvgFavourite *) list2->data;

				if(fav->record > 0 || (recordings_enabled && fav->record < 0)) {
					b = TRUE;
					if(gtvg_favourite_recording_disabled(fav, prog->channel->id, prog->start)) {
						b_disabled = TRUE;
						break;
					} else {
						if(priority < 2) {
							gint i = gtvg_favourite_recording_priority(fav, prog->channel->id, prog->start);

							if(i > priority)
								priority = i;
						}
						if(fav->record < 0) {
							if(start_margin > startm)
								startm = start_margin;
							if(stop_margin > endm)
								endm = stop_margin;
						} else {
							if(fav->record_start_margin > startm)
								startm = fav->record_start_margin;
							if(fav->record_stop_margin > endm)
								endm = fav->record_stop_margin;
						}
					}
				}
				list2 = g_slist_next(list2);
			}
			if(b && !b_disabled && (prev_recsched == NULL || prog->stop > prev_recsched->prog->stop)) {
				recsched = g_slice_new(struct record_schedule);

				recsched->prog = prog;
				recsched->start_time = prog->start - startm * 60;
				recsched->priority = priority;
				recsched->disabled = 0;
				if(prev_recsched != NULL && prev_recsched->stop_time > recsched->start_time) {
					if(priority > prev_recsched->priority) {
						if(prev_recsched->prog->stop > recsched->start_time) {
						} else if(prev_recsched->prog->stop < recsched->prog->start) {
							recsched->start_time = prev_recsched->prog->stop;
						} else {
							recsched->start_time = recsched->prog->start;
							has_conflicts = TRUE;
						}
						prev_recsched->stop_time = recsched->start_time;
						b = prev_recsched->stop_time < prev_recsched->start_time;
						if(prev_recsched->stop_time <= prev_recsched->start_time || prev_recsched->stop_time <= prev_recsched->prog->start) {
							prev_recsched->start_time = prev_recsched->prog->start;
							prev_recsched->stop_time = prev_recsched->prog->stop;
							prev_recsched->disabled = 1;
							disabled_record_schedules = g_slist_prepend(disabled_record_schedules, prev_recsched);
							record_schedules = g_slist_delete_link(record_schedules, g_slist_last(record_schedules));
							if(record_schedules != NULL)
								prev_recsched = (struct record_schedule *) g_slist_last(record_schedules)->data;
							else
								prev_recsched = NULL;
							has_conflicts = TRUE;
						}
						while(b && prev_recsched != NULL && prev_recsched->stop_time > recsched->start_time) {
							if(priority <= prev_recsched->priority) {
								if(recsched->prog->start > prev_recsched->stop_time) {
								} else if(recsched->prog->start > prev_recsched->prog->stop) {
									prev_recsched->stop_time = recsched->prog->start;
								} else {
									prev_recsched->stop_time = prev_recsched->prog->stop;
									has_conflicts = TRUE;
								}
								recsched->start_time = prev_recsched->stop_time;
								break;
							}
							if(prev_recsched->prog->stop > recsched->start_time) {
							} else if(prev_recsched->prog->stop < recsched->prog->start) {
								recsched->start_time = prev_recsched->prog->stop;
							} else {
								recsched->start_time = recsched->prog->start;
							}
							b = prev_recsched->stop_time < prev_recsched->start_time;
							if(prev_recsched->stop_time <= prev_recsched->start_time || prev_recsched->stop_time <= prev_recsched->prog->start) {
								prev_recsched->start_time = prev_recsched->prog->start;
								prev_recsched->stop_time = prev_recsched->prog->stop;
								prev_recsched->disabled = 1;
								disabled_record_schedules = g_slist_prepend(disabled_record_schedules, prev_recsched);
								record_schedules = g_slist_delete_link(record_schedules, g_slist_last(record_schedules));
								if(record_schedules != NULL)
									prev_recsched = (struct record_schedule *) g_slist_last(record_schedules)->data;
								else
									prev_recsched = NULL;
							}
						}
					} else {
						if(recsched->prog->start > prev_recsched->stop_time) {
						} else if(recsched->prog->start > prev_recsched->prog->stop) {
							prev_recsched->stop_time = recsched->prog->start;
						} else {
							prev_recsched->stop_time = prev_recsched->prog->stop;
							has_conflicts = TRUE;
						}
						recsched->start_time = prev_recsched->stop_time;
					}
				} else if(prev_recsched == NULL && starttime > recsched->start_time) {
					recsched->start_time = current_record_stop_time;
					has_conflicts = TRUE;
				}
				recsched->stop_time = prog->stop + endm * 60;
				record_schedules = g_slist_prepend(record_schedules, recsched);
				prev_recsched = recsched;
			} else if(b) {
				recsched = g_slice_new(struct record_schedule);

				recsched->prog = prog;
				recsched->start_time = recsched->prog->start;
				recsched->stop_time = recsched->prog->stop;
				recsched->priority = priority;
				disabled_record_schedules = g_slist_prepend(disabled_record_schedules, recsched);
				if(!b_disabled) {
					recsched->disabled = 1;
					has_conflicts = TRUE;
				} else {
					recsched->disabled = 2;
				}
			}
		}
		list = g_slist_next(list);
	}
	if(record_schedules != NULL) {
		record_schedules = g_slist_sort(record_schedules, recsched_compare_func);
		updateWakeupTime();
		if(current_record_stop_time == 0) {
			recsched = (struct record_schedule *) record_schedules->data;
			if(time(NULL) >= recsched->start_time - 1) {
				on_startRecording_timeout(NULL);
			} else {
				rec_timeout_running = TRUE;
				rec_timeout_id = g_timeout_add((guint) (recsched->start_time - time(NULL) - 1) * 1000, on_startRecording_timeout, NULL);
			}
		}
	} else {
		wakeup_recsched = NULL;
	}

	if(disabled_record_schedules != NULL) {
		disabled_record_schedules = g_slist_sort(disabled_record_schedules, recsched_compare_func);
	}
	if(has_conflicts && !GTK_WIDGET_VISIBLE(glade_xml_get_widget(gxml, "recordScheduleDialog"))) {
		GtkWidget *dialog = gtk_message_dialog_new(GTK_WINDOW(window), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_WARNING, GTK_BUTTONS_YES_NO, _("Conlicting scheduled recordings discovered. You will miss the beginning (and possibly the whole program) of one or more TV programs.\n\nDo you want to view the recording schedule?"));

		if((gdk_window_get_state(GTK_WIDGET(window)->window) & GDK_WINDOW_STATE_ICONIFIED) || !GTK_WIDGET_VISIBLE(window)) {
			restore_position();
			gtk_window_present(GTK_WINDOW(window));
		}
		if(gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_YES) {
			GtkWidget *dialog2 = getRecordScheduleDialog();

			gtk_window_present(GTK_WINDOW(dialog2));
		}
		gtk_widget_destroy(dialog);
	}
	updateRecordScheduleList();
}

void updateReminders(struct GtvgFavourite *onlyfav, struct GtvgProgram *onlyprog)
{

	GSList *list, *favs = favourites;
	struct GtvgFavourite *fav;
	struct favourite_schedule *favsched;
	struct GtvgProgram *prog;
	gchar *upper = NULL, *lower = NULL;

	if(onlyfav == NULL && onlyprog == NULL) {
		if(favourite_schedules != NULL) {
			g_slist_foreach(favourite_schedules, free_slist_favsched, NULL);
			g_slist_free(favourite_schedules);
			favourite_schedules = NULL;
		}
		if(notifying_favscheds != NULL) {
			g_slist_foreach(notifying_favscheds, free_slist_favsched, NULL);
			g_slist_free(notifying_favscheds);
			notifying_favscheds = NULL;
		}
	}

	if(onlyfav == NULL && onlyprog == NULL) {
		list = programs;
		while(list != NULL) {
			prog = (struct GtvgProgram *) list->data;
			if(prog->favourites) {
				g_slist_free(prog->favourites);
				prog->favourites = NULL;
			}
			list = g_slist_next(list);
		}
	}

	while(onlyfav != NULL || favs != NULL) {
		if(onlyfav != NULL)
			fav = onlyfav;
		else
			fav = (struct GtvgFavourite *) favs->data;
		if(upper != NULL) {
			g_free(upper);
			upper = NULL;
		}
		if(lower != NULL) {
			g_free(lower);
			lower = NULL;
		}
		if(fav->partial_title) {
			upper = g_utf8_strup(fav->title, -1);
			lower = g_utf8_strdown(fav->title, -1);
			g_strstrip(upper);
			g_strstrip(lower);
		}
		list = programs;
		while(list != NULL || onlyprog != NULL) {
			if(onlyprog != NULL)
				prog = onlyprog;
			else
				prog = (struct GtvgProgram *) list->data;
			if(favouriteIncludesProgram(fav, prog, lower, upper)) {
				if(fav->reminder != 0 && prog->favourites == NULL && prog->start > time(NULL)) {
					favsched = g_slice_new(struct favourite_schedule);

					favsched->notification = NULL;
					favsched->prog = prog;
					favsched->fav = fav;
					if(onlyfav != NULL || onlyprog != NULL) {
						favourite_schedules = g_slist_insert_sorted(favourite_schedules, favsched, favsched_compare_func);
					} else {
						favourite_schedules = g_slist_prepend(favourite_schedules, favsched);
					}
				}
				prog->favourites = g_slist_prepend(prog->favourites, fav);
			}
			if(onlyprog != NULL)
				break;
			list = g_slist_next(list);
		}
		if(onlyfav != NULL)
			break;
		favs = g_slist_next(favs);
	}
	if(onlyfav == NULL && onlyprog == NULL) {
		if(favourite_schedules != NULL)
			favourite_schedules = g_slist_sort(favourite_schedules, favsched_compare_func);
	}

	updateRecSchedule();

}

void removeReminders(struct GtvgFavourite *fav)
{

	GSList *list, *favlist;
	struct GtvgProgram *prog;
	gboolean b, only_past = TRUE;

	list = favourite_schedules;
	while(list) {
		if(((struct favourite_schedule *) list->data)->fav == fav) {
			free_favsched((struct favourite_schedule *) list->data);
			favourite_schedules = g_slist_delete_link(favourite_schedules, list);
			list = favourite_schedules;
		} else {
			list = g_slist_next(list);
		}
	}

	list = notifying_favscheds;
	while(list) {
		if(((struct favourite_schedule *) list->data)->fav == fav) {
			free_favsched((struct favourite_schedule *) list->data);
			notifying_favscheds = g_slist_delete_link(notifying_favscheds, list);
			list = notifying_favscheds;
		} else {
			list = g_slist_next(list);
		}
	}

	list = programs;
	while(list != NULL) {
		prog = (struct GtvgProgram *) list->data;
		favlist = g_slist_find(prog->favourites, fav);
		if(favlist != NULL) {
			b = (favlist == g_slist_last(prog->favourites));
			prog->favourites = g_slist_delete_link(prog->favourites, favlist);
			if(only_past && prog->start >= time(NULL))
				only_past = FALSE;
			if(b && prog->favourites != NULL) {
				g_slist_free(prog->favourites);
				prog->favourites = NULL;
				updateReminders(NULL, prog);
			}
		}
		list = g_slist_next(list);
	}

	if(!only_past && ((recordings_enabled && fav->record < 0) || fav->record > 0)) {
		updateRecSchedule();
	}

}

void updateCategoryList(struct GtvgCategory *selcat)
{
	GSList *list = categories;
	GtkTreeIter iter;
	struct GtvgCategory *cat;
	GtkTreeSelection *selection;
	gboolean categories_selected = FALSE;
	GHashTable *category_selected = NULL;

	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "categoriesList_view")));
	if(selcat == NULL) {
		category_selected = g_hash_table_new(NULL, NULL);
		categories_selected = gtk_tree_selection_count_selected_rows(selection) > 0;
		if(categories_selected && gtk_tree_model_get_iter_first(GTK_TREE_MODEL(categoriesList_store), &iter)) {
			do {
				gtk_tree_model_get(GTK_TREE_MODEL(categoriesList_store), &iter, 1, &cat, -1);
				g_hash_table_insert(category_selected, cat, (gpointer) gtk_tree_selection_iter_is_selected(selection, &iter));
			} while(gtk_tree_model_iter_next(GTK_TREE_MODEL(categoriesList_store), &iter));
		}
	}
	g_signal_handlers_block_matched((gpointer) selection, G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_categoriesList_selection_changed, NULL);
	gtk_list_store_clear(categoriesList_store);
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "allCategoriesButton"), FALSE);
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "editCategoryButton"), FALSE);

	while(list != NULL) {
		cat = (struct GtvgCategory *) list->data;
		gtk_list_store_append(categoriesList_store, &iter);
		gtk_list_store_set(categoriesList_store, &iter, 0, cat->name, 1, cat, 2, cat->bg_color, 3, cat->text_color, -1);
		if((selcat != NULL && cat == selcat) || (selcat == NULL && categories_selected && g_hash_table_lookup(category_selected, cat))) {
			gtk_tree_selection_select_iter(selection, &iter);
			gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "allCategoriesButton"), TRUE);
			gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "editCategoryButton"), TRUE);
		}
		list = g_slist_next(list);
	}

	g_signal_handlers_unblock_matched((gpointer) selection, G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_categoriesList_selection_changed, NULL);

	if(selcat == NULL)
		g_hash_table_destroy(category_selected);

}

void updateChannelList(void)
{

	GSList *list = channels;
	GtkTreeIter iter;
	gchar *gstr;
	struct GtvgChannel *ch;
	GtkTreeSelection *selection;
	gboolean channels_selected;
	GHashTable *channel_selected;

	g_signal_handlers_block_matched((gpointer) channelsList_store, G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_channelsList_row_inserted, NULL);

	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "channelsList_view")));
	channel_selected = g_hash_table_new_full(NULL, g_str_equal, gfree_hashtable_value, NULL);
	channels_selected = gtk_tree_selection_count_selected_rows(selection) > 0;
	if(channels_selected && gtk_tree_model_get_iter_first(GTK_TREE_MODEL(channelsList_store), &iter)) {
		do {
			gtk_tree_model_get(GTK_TREE_MODEL(channelsList_store), &iter, CHANNELS_ID_COLUMN, &gstr, -1);
			g_hash_table_insert(channel_selected, gstr, (gpointer) gtk_tree_selection_iter_is_selected(selection, &iter));
		} while(gtk_tree_model_iter_next(GTK_TREE_MODEL(channelsList_store), &iter));
	}
	g_signal_handlers_block_matched((gpointer) selection, G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_channelsList_selection_changed, NULL);
	gtk_list_store_clear(channelsList_store);
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "allChannelsButton"), FALSE);
	while(list != NULL) {
		ch = (struct GtvgChannel *) list->data;
		gtk_list_store_append(channelsList_store, &iter);
		gtk_list_store_set(channelsList_store, &iter, CHANNELS_NAME_COLUMN, ch->name, CHANNELS_ICON_COLUMN, ch->icon, CHANNELS_OBJECT_COLUMN, ch, CHANNELS_ID_COLUMN, ch->id, -1);
		if(channels_selected && g_hash_table_lookup(channel_selected, ch->id)) {
			gtk_tree_selection_select_iter(selection, &iter);
			gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "allChannelsButton"), TRUE);
		}
		list = g_slist_next(list);
	}

	g_signal_handlers_unblock_matched((gpointer) selection, G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_channelsList_selection_changed, NULL);
	g_signal_handlers_unblock_matched((gpointer) channelsList_store, G_SIGNAL_MATCH_FUNC, 0, 0, NULL, (gpointer) on_channelsList_row_inserted, NULL);
	g_hash_table_destroy(channel_selected);
}

gboolean programInFilter(struct GtvgProgram *prog)
{
	const gchar *search_str;
	gchar *search_str_upper, *search_str_lower;
	gboolean b;

	search_str = gtk_entry_get_text(GTK_ENTRY(searchEntry));
	if(search_str != NULL) {
		search_str_upper = g_utf8_strup(search_str, -1);
		search_str_lower = g_utf8_strdown(search_str, -1);
		g_strstrip(search_str_upper);
		g_strstrip(search_str_lower);
	} else {
		return TRUE;
	}
	b = search_program(prog, search_str_lower, search_str_upper);
	g_free(search_str_upper);
	g_free(search_str_lower);
	return b;
}

gboolean programInChannels(struct GtvgProgram * prog)
{
	GtkTreeSelection *selection;
	GtkTreeIter iter;
	struct GtvgChannel *ch;

	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "channelsList_view")));
	if(gtk_tree_selection_count_selected_rows(selection) == 0)
		return TRUE;
	if(gtk_tree_model_get_iter_first(GTK_TREE_MODEL(channelsList_store), &iter)) {
		do {
			if(gtk_tree_selection_iter_is_selected(selection, &iter)) {
				gtk_tree_model_get(GTK_TREE_MODEL(channelsList_store), &iter, CHANNELS_OBJECT_COLUMN, &ch, -1);
				if(ch == prog->channel)
					return TRUE;
			}
		} while(gtk_tree_model_iter_next(GTK_TREE_MODEL(channelsList_store), &iter));
	}
	return FALSE;
}

gboolean programInCategories(struct GtvgProgram * prog)
{
	GtkTreeSelection *selection;
	GtkTreeIter iter;
	struct GtvgCategory *cat;

	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "categoriesList_view")));
	if(gtk_tree_selection_count_selected_rows(selection) == 0)
		return TRUE;
	if(prog->categories == NULL)
		return FALSE;
	if(gtk_tree_model_get_iter_first(GTK_TREE_MODEL(categoriesList_store), &iter)) {
		do {
			if(gtk_tree_selection_iter_is_selected(selection, &iter)) {
				gtk_tree_model_get(GTK_TREE_MODEL(categoriesList_store), &iter, 1, &cat, -1);
				if(cat != NULL) {
					if(g_slist_find(prog->categories, cat) != NULL) {
						return TRUE;
					}
				}
			}
		} while(gtk_tree_model_iter_next(GTK_TREE_MODEL(categoriesList_store), &iter));
	}
	return FALSE;
}

void checkEnableClearFilters(void)
{
	GtkTreeSelection *selection;
	glong daytime;
	gboolean b;
	GtkTreeIter iter;

	b = strlen(gtk_entry_get_text(GTK_ENTRY(searchEntry))) > 0;
	if(!b) {
		selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "channelsList_view")));
		b = gtk_tree_selection_count_selected_rows(selection) > 0;
	}
	if(!b) {
		selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "categoriesList_view")));
		b = gtk_tree_selection_count_selected_rows(selection) > 0;
	}
	if(!b)
		b = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "showFavouritesButton")));
	if(!b)
		b = !gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "hidePastButton")));
	if(!b) {
		if(gtk_combo_box_get_active_iter(GTK_COMBO_BOX(glade_xml_get_widget(gxml, "dayCombo")), &iter)) {
			gtk_tree_model_get(GTK_TREE_MODEL(dayCombo_store), &iter, 1, &daytime, -1);
			b = (daytime != (glong) tomorrow_time - 86400);
		}
	}
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "clearFiltersToolbutton"), b);
	gtk_widget_set_sensitive(glade_xml_get_widget(gxml, "clearFiltersMenuItem"), b);
}

void updateProgramList_sub(void)
{

	GSList *list = programs, *catlist, *list2;
	GtkTreeIter iter;
	struct GtvgProgram *prog;
	gchar *time_str, *start_str, *stop_str, *gstr;
	time_t curtime;
	struct tm curtp, tmptp;
	gboolean only_favourites, hide_past;
	gboolean b;
	gboolean channels_selected;
	GHashTable *channel_selected;
	const gchar *search_str;
	gchar *search_str_upper, *search_str_lower;
	struct GtvgChannel *ch;
	struct GtvgCategory *cat;
	gboolean categories_selected;
	GHashTable *category_selected;
	GtkTreeSelection *selection;
	time_t first_time, last_time, today_start;

	pending_list_updates = FALSE;

	only_favourites = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "showFavouritesButton")));
	hide_past = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(glade_xml_get_widget(gxml, "hidePastButton")));

	curtime = time(NULL);
	localtime_r(&curtime, &curtp);

	tmptp = curtp;
	tmptp.tm_sec = 0;
	tmptp.tm_min = 0;
	tmptp.tm_hour = 0;
	today_start = mktime(&tmptp);

	if(all_days) {
		first_time = 0;
		last_time = 0;
	} else {
		first_time = current_day;
		last_time = first_time + 86400;
	}

	if(first_nonpast_iter != NULL) {
		gtk_tree_iter_free(first_nonpast_iter);
		first_nonpast_iter = NULL;
	}

	start_str = g_strnfill(80, '\0');
	stop_str = g_strnfill(80, '\0');
	time_str = g_strnfill(200, '\0');

	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "channelsList_view")));
	channel_selected = g_hash_table_new(NULL, NULL);
	channels_selected = gtk_tree_selection_count_selected_rows(selection) > 0 && gtk_tree_selection_count_selected_rows(selection) < g_slist_length(channels);
	if(channels_selected && gtk_tree_model_get_iter_first(GTK_TREE_MODEL(channelsList_store), &iter)) {
		do {
			gtk_tree_model_get(GTK_TREE_MODEL(channelsList_store), &iter, CHANNELS_OBJECT_COLUMN, &ch, -1);
			g_hash_table_insert(channel_selected, (gpointer) ch, (gpointer) gtk_tree_selection_iter_is_selected(selection, &iter));
		} while(gtk_tree_model_iter_next(GTK_TREE_MODEL(channelsList_store), &iter));
	}

	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "categoriesList_view")));
	category_selected = g_hash_table_new_full(NULL, NULL, NULL, NULL);
	categories_selected = gtk_tree_selection_count_selected_rows(selection) > 0;
	if(categories_selected && gtk_tree_model_get_iter_first(GTK_TREE_MODEL(categoriesList_store), &iter)) {
		do {
			gtk_tree_model_get(GTK_TREE_MODEL(categoriesList_store), &iter, 1, &cat, -1);
			g_hash_table_insert(category_selected, cat, (gpointer) gtk_tree_selection_iter_is_selected(selection, &iter));
		} while(gtk_tree_model_iter_next(GTK_TREE_MODEL(categoriesList_store), &iter));
	}

	search_str = gtk_entry_get_text(GTK_ENTRY(searchEntry));
	if(search_str != NULL) {
		search_str_upper = g_utf8_strup(search_str, -1);
		search_str_lower = g_utf8_strdown(search_str, -1);
		g_strstrip(search_str_upper);
		g_strstrip(search_str_lower);
	} else {
		search_str_upper = NULL;
		search_str_lower = NULL;
	}

	gtk_list_store_clear(programList_store);

	while(list != NULL) {

		prog = (struct GtvgProgram *) list->data;

		b = TRUE;
		if(b && first_time != 0) {
			if(prog->stop <= first_time)
				b = FALSE;
			else if(prog->start >= last_time)
				break;
		}
		if(b && hide_past && prog->stop <= curtime)
			b = FALSE;
		if(b && only_favourites && prog->favourites == NULL)
			b = FALSE;
		if(b && channels_selected && !g_hash_table_lookup(channel_selected, prog->channel))
			b = FALSE;
		if(b && (g_slist_find_custom(blacklist, prog->title, gchar_compare_func) != NULL))
			b = FALSE;
		if(b && categories_selected) {
			b = FALSE;
			catlist = prog->categories;
			while(catlist != NULL) {
				if(g_hash_table_lookup(category_selected, catlist->data)) {
					b = TRUE;
					break;
				}
				catlist = g_slist_next(catlist);
			}
		}
		if(b && !search_program(prog, search_str_lower, search_str_upper))
			b = FALSE;

		if(b) {

			strftime(stop_str, 80, "%R", &prog->stop_tm);
			if(first_time > 0 || (curtp.tm_year == prog->start_tm.tm_year && curtp.tm_mon == prog->start_tm.tm_mon && curtp.tm_mday == prog->start_tm.tm_mday)) {
				strftime(start_str, 80, "%R", &prog->start_tm);
			} else if(prog->start >= today_start + 604800 || prog->start < today_start - 86400) {
				//date and time in list (ex. "7 May 20:00")
				strftime(start_str, 80, _("%e %b %R"), &prog->start_tm);
			} else {
				//day of week and time in (ex. "Thu 20:00")
				strftime(start_str, 80, _("%a %R"), &prog->start_tm);
			}
			//time interval ("20:00 - 21:30")
			g_snprintf(time_str, 200, _("%s\342\200\223%s"), start_str, stop_str);

			gtk_list_store_append(programList_store, &iter);
			gtk_list_store_set(programList_store, &iter, OBJECT_COLUMN, prog, -1);
			gtk_list_store_set(programList_store, &iter, -1);
			gtk_list_store_set(programList_store, &iter, TIME_COLUMN, time_str, -1);
			if(curtime < prog->stop && curtime > prog->start) {
				gstr = g_strdup_printf(_("%li:%.2li"), (long) (curtime - prog->start) / 3600, (long) ((curtime - prog->start) % 3600) / 60);
				gtk_list_store_set(programList_store, &iter, PROGRESS_COLUMN, ((curtime - prog->start) * 100) / (prog->stop - prog->start), PROGRESS_TEXT_COLUMN, gstr, -1);
				g_free(gstr);
			} else {
				gtk_list_store_set(programList_store, &iter, PROGRESS_COLUMN, 0, PROGRESS_TEXT_COLUMN, "", -1);
			}
			gtk_list_store_set(programList_store, &iter, CHANNEL_COLUMN, prog->channel->name, -1);

			list2 = prog->categories;
			while(list2 != NULL) {
				cat = (struct GtvgCategory *) list2->data;
				if(cat->text_color != NULL || cat->bg_color != NULL) {
					gtk_list_store_set(programList_store, &iter, BACKGROUND_COLUMN, cat->bg_color, FOREGROUND_COLUMN, cat->text_color, -1);
					break;
				}
				list2 = g_slist_next(list2);
			}

			markFavourite(programList_store, &iter, only_favourites, prog);

			if(first_nonpast_iter == NULL && prog->stop > curtime)
				first_nonpast_iter = gtk_tree_iter_copy(&iter);

		}
		list = g_slist_next(list);
	}

	g_free(stop_str);
	g_free(start_str);
	g_free(time_str);
	if(search_str_upper != NULL)
		g_free(search_str_upper);
	if(search_str_lower != NULL)
		g_free(search_str_lower);

	if(GTK_WIDGET_REALIZED(glade_xml_get_widget(gxml, "programList_view")))
		gtk_tree_view_scroll_to_point(GTK_TREE_VIEW(glade_xml_get_widget(gxml, "programList_view")), 0, 0);

	g_hash_table_destroy(channel_selected);
	g_hash_table_destroy(category_selected);

	checkEnableClearFilters();

}

void updateProgramList(void)
{
	if(gtk_notebook_get_current_page(GTK_NOTEBOOK(glade_xml_get_widget(gxml, "viewPages"))) != 0) {
		pending_list_updates = TRUE;
		return;
	}
	updateProgramList_sub();
}

void list_object_destroy(gpointer data, gpointer user_data)
{
	gtk_object_destroy(GTK_OBJECT(data));
}

void updateGridTime(gboolean force, gboolean move_to_current)
{
	GSList *list, *list2;
	time_t curtime;
	gdouble x1, x2, x_prev;
	struct GtvgProgram *prog, *prog2;
	GnomeCanvas *canvas = GNOME_CANVAS(glade_xml_get_widget(gxml, "programCanvas"));
	GnomeCanvasItem *item;

	if(!force && gtk_notebook_get_current_page(GTK_NOTEBOOK(glade_xml_get_widget(gxml, "viewPages"))) != 1) {
		pending_gridtime_updates = TRUE;
		return;
	}
	if(current_marker_item == NULL)
		return;
	pending_gridtime_updates = FALSE;
	curtime = time(NULL);
	if(move_to_current)
		scroll_x = progstart_x + (curtime - current_day - 1800) / time_compression;
	list = current_gridprogs;
	while(list != NULL) {
		list2 = (GSList *) list->data;
		if(list2 != NULL) {
			prog = (struct GtvgProgram *) list2->data;
			if(prog->start > curtime) {
			} else if(prog->stop <= curtime) {
				if(prog->canvas_text != NULL) {
					if(prog != selected_gridprog) {
						g_object_set(G_OBJECT(prog->canvas_rect), "fill-color-gdk", prog->favourites != NULL ? favBgColor(prog) : defBgColor(prog), "outline-color-gdk", prog->favourites != NULL ? &favourite_border_color : &default_border_color, NULL);
						g_object_set(G_OBJECT(prog->canvas_text), "fill-color-gdk", prog->favourites != NULL ? favTextColor(prog) : defTextColor(prog), NULL);
					}
					g_object_get(G_OBJECT(prog->canvas_rect), "x1", &x1, "x2", &x2, NULL);
					g_object_set(G_OBJECT(prog->canvas_text), "x", x1 + text_margin, "clip-width", x2 - x1 - (text_margin * 2), NULL);
				}
				list2 = g_slist_next(list2);
				while(list2 != NULL) {
					prog2 = (struct GtvgProgram *) list2->data;
					if(prog2->channel == prog->channel) {
						if(prog2->stop > curtime) {
							if(prog2->start <= curtime) {
								if(prog2->canvas_text != NULL) {
									if(prog2 != selected_gridprog) {
										g_object_set(G_OBJECT(prog2->canvas_rect), "fill-color-gdk", &current_bg_color, "outline-color-gdk", &current_border_color, NULL);
										g_object_set(G_OBJECT(prog2->canvas_text), "fill-color-gdk", &current_text_color, NULL);
									}
									if(move_to_current) {
										g_object_get(G_OBJECT(prog2->canvas_rect), "x1", &x1, "x2", &x2, NULL);
										if(x1 < scroll_x)
											g_object_set(G_OBJECT(prog2->canvas_text), "x", scroll_x + text_margin, "clip-width", x2 - scroll_x - (text_margin * 2), NULL);
									}
								}
							}
							break;
						}
					}
					list2 = g_slist_next(list2);
				}
				list->data = list2;
			} else if(prog->canvas_text != NULL) {
				if(prog != selected_gridprog) {
					g_object_set(G_OBJECT(prog->canvas_rect), "fill-color-gdk", &current_bg_color, "outline-color-gdk", &current_border_color, NULL);
					g_object_set(G_OBJECT(prog->canvas_text), "fill-color-gdk", &current_text_color, NULL);
				}
				if(move_to_current) {
					g_object_get(G_OBJECT(prog->canvas_rect), "x1", &x1, "x2", &x2, NULL);
					if(x1 < scroll_x)
						g_object_set(G_OBJECT(prog->canvas_text), "x", scroll_x + text_margin, "clip-width", x2 - scroll_x - (text_margin * 2), NULL);
				}
			}
		}
		list = g_slist_next(list);
	}
	x1 = progstart_x + (curtime - current_day) / time_compression;
	g_object_set(G_OBJECT(current_timemarker_item), "x1", x1 - 1, "x2", x1 + 1, NULL);
	g_object_set(G_OBJECT(current_marker_item), "x1", x1 - 1, "x2", x1 + 1, NULL);
	g_object_get(G_OBJECT(past_backdrop_item), "x2", &x_prev, NULL);
	item = gnome_canvas_item_new(gnome_canvas_root(canvas), gnome_canvas_rect_get_type(), "x1", x_prev, "x2", x1, "y1", 0.0, "y2", progstart_y + g_slist_length(channels) * channel_height, "fill-color-gdk", &past_bg_color, "outline-color-gdk", &past_bg_color, NULL);
	gnome_canvas_item_hide(item);
	gnome_canvas_item_lower_to_bottom(item);
	gnome_canvas_item_raise(item, 1);
	gnome_canvas_item_show(item);
	past_backdrop_item = item;
	gridprog_items = g_slist_prepend(gridprog_items, item);
	if(move_to_current) {
		grid_at_current = FALSE;
		gtk_adjustment_set_value(gtk_scrolled_window_get_hadjustment(GTK_SCROLLED_WINDOW(glade_xml_get_widget(gxml, "programCanvas_scrolled"))), scroll_x);
		grid_at_current = TRUE;
	}
}

#define BORDER_WIDTH							2

void updateProgramGrid_sub(gboolean update_channels)
{
	GnomeCanvas *canvas = GNOME_CANVAS(glade_xml_get_widget(gxml, "programCanvas"));
	GtkWidget *canvas_widget = glade_xml_get_widget(gxml, "programCanvas");
	GnomeCanvas *ch_canvas = GNOME_CANVAS(glade_xml_get_widget(gxml, "channelsCanvas"));
	GnomeCanvas *time_canvas = GNOME_CANVAS(glade_xml_get_widget(gxml, "timeCanvas"));
	GnomeCanvas *nw_canvas = GNOME_CANVAS(glade_xml_get_widget(gxml, "nwCanvas"));
	GnomeCanvasItem *item;
	GSList *list, *list_begin, *list2;
	struct GtvgProgram *prog;
	struct GtvgChannel *ch;
	GHashTable *chindex_hash;
	GHashTable *chcurrent_hash;
	GtkTreeIter iter;
	gboolean b, b2, blacklisted;
	gint i = 0;
	time_t curtime, tmp_time;
	struct tm tmptm;
	gchar *time_str, *start_str, *stop_str, *gstr, *gstr2;
	gdouble x1, x2, y1, y2, width, height;
	GdkPixbuf *icon;
	guint16 ui, treshold;
	guint32 ui2;

	future_bg_color = canvas_widget->style->base[GTK_STATE_NORMAL];
	past_bg_color = canvas_widget->style->base[GTK_STATE_INSENSITIVE];
	default_bg_color = canvas_widget->style->bg[GTK_STATE_NORMAL];
	selected_bg_color = canvas_widget->style->bg[GTK_STATE_SELECTED];
	favourite_bg_color = canvas_widget->style->bg[GTK_STATE_NORMAL];
	current_bg_color = canvas_widget->style->bg[GTK_STATE_SELECTED];
	ui2 = current_bg_color.green + current_bg_color.red + current_bg_color.blue;
	treshold = (guint16) ((65535 * 3 - ui2) / 5 + 10);
	if((current_bg_color.red > current_bg_color.blue && current_bg_color.red - current_bg_color.blue > treshold) || (current_bg_color.red < current_bg_color.blue && current_bg_color.blue - current_bg_color.red > treshold)) {
		ui = current_bg_color.red;
		current_bg_color.red = current_bg_color.blue;
		current_bg_color.blue = ui;
	} else if((current_bg_color.red > current_bg_color.green && current_bg_color.red - current_bg_color.green > treshold) || (current_bg_color.red < current_bg_color.green && current_bg_color.green - current_bg_color.red > treshold)) {
		ui = current_bg_color.red;
		current_bg_color.red = current_bg_color.green;
		current_bg_color.green = ui;
	} else if((current_bg_color.green > current_bg_color.blue && current_bg_color.green - current_bg_color.blue > treshold) || (current_bg_color.green < current_bg_color.blue && current_bg_color.blue - current_bg_color.green > treshold)) {
		ui = current_bg_color.blue;
		current_bg_color.blue = current_bg_color.green;
		current_bg_color.green = ui;
	} else {
		current_bg_color.blue += treshold;
		if(current_bg_color.green > treshold / 2)
			current_bg_color.green -= treshold / 2;
		else
			current_bg_color.green = 0;
		if(current_bg_color.red > treshold / 2)
			current_bg_color.red -= treshold / 2;
		else
			current_bg_color.red = 0;
	}
	default_border_color = canvas_widget->style->fg[GTK_STATE_NORMAL];
	selected_border_color = canvas_widget->style->fg[GTK_STATE_NORMAL];
	favourite_border_color = canvas_widget->style->fg[GTK_STATE_NORMAL];
	current_border_color = canvas_widget->style->fg[GTK_STATE_NORMAL];
	default_text_color = canvas_widget->style->text[GTK_STATE_NORMAL];
	selected_text_color = canvas_widget->style->text[GTK_STATE_SELECTED];
	favourite_text_color = canvas_widget->style->text[GTK_STATE_NORMAL];
	current_text_color = canvas_widget->style->text[GTK_STATE_SELECTED];

	if(update_channels) {
		channel_height = 54.0;
		channel_width = channel_height;
	}

	selected_gridprog = NULL;

	pending_grid_updates = FALSE;
	pending_grid_update_channels = FALSE;
	pending_gridtime_updates = FALSE;

	if(current_gridprogs != NULL) {
		g_slist_free(current_gridprogs);
		current_gridprogs = NULL;
	}

	past_backdrop_item = NULL;
	future_backdrop_item = NULL;
	past_timebackdrop_item = NULL;
	future_timebackdrop_item = NULL;
	current_marker_item = NULL;
	current_timemarker_item = NULL;

	start_str = g_strnfill(80, '\0');
	stop_str = g_strnfill(80, '\0');
	time_str = g_strnfill(200, '\0');

	if(update_channels) {
		if(gridch_items != NULL) {
			g_slist_foreach(gridch_items, list_object_destroy, NULL);
			g_slist_free(gridch_items);
			gridch_items = NULL;
			g_slist_free(gridch_items);
			gridch_items = NULL;
		}
	}
	if(gridprog_items != NULL) {
		g_slist_foreach(gridprog_items, list_object_destroy, NULL);
		g_slist_free(gridprog_items);
		gridprog_items = NULL;
		g_slist_free(gridprog_items);
		gridprog_items = NULL;
	}
	if(gridtime_items != NULL) {
		g_slist_foreach(gridtime_items, list_object_destroy, NULL);
		g_slist_free(gridtime_items);
		gridtime_items = NULL;
		g_slist_free(gridprog_items);
		gridtime_items = NULL;
	}
	if(gridnw_items != NULL) {
		g_slist_foreach(gridnw_items, list_object_destroy, NULL);
		g_slist_free(gridnw_items);
		gridnw_items = NULL;
		g_slist_free(gridnw_items);
		gridnw_items = NULL;
	}

	gnome_canvas_set_pixels_per_unit(canvas, 1.0);

	if(programs != NULL && update_channels) {
		prog = (struct GtvgProgram *) programs->data;
		strftime(stop_str, 80, "%R", &prog->stop_tm);
		strftime(start_str, 80, "%R", &prog->start_tm);
		//time interval ("20:00 - 21:30")
		g_snprintf(time_str, 200, _("%s\342\200\223%s"), start_str, stop_str);
		gstr = g_strdup_printf("%s\n%s", prog->title, time_str);
		item = gnome_canvas_item_new(gnome_canvas_root(canvas), gnome_canvas_text_get_type(), "x", 0.0, "y", 0.0, "text", gstr, "weight", PANGO_WEIGHT_BOLD, "anchor", GTK_ANCHOR_NW, NULL);
		gnome_canvas_item_get_bounds(item, &x1, &y1, &x2, &y2);
		if(y2 > channel_height - channel_margin * 2 - text_margin * 2)
			channel_height = y2 + channel_margin * 2 + text_margin * 2;
		g_free(gstr);
		gtk_object_destroy(GTK_OBJECT(item));
	}

	gnome_canvas_set_pixels_per_unit(time_canvas, 1.0);

	curtime = time(NULL);
	tmp_time = current_day;
	i = 1;
	x1 = progstart_x;
	while(i < 48) {
		x1 += 1800 / time_compression;
		tmp_time += 1800;
		localtime_r(&tmp_time, &tmptm);
		strftime(time_str, 200, "%R", &tmptm);
		item = gnome_canvas_item_new(gnome_canvas_root(time_canvas), gnome_canvas_text_get_type(), "x", x1, "y", top_text_margin, "text", time_str, "anchor", GTK_ANCHOR_NORTH, NULL);
		gridtime_items = g_slist_prepend(gridtime_items, item);
		i++;
	}
	gnome_canvas_item_get_bounds(item, &x1, &y1, &x2, &y2);
	time_height = y2;
	if(current_day == tomorrow_time - 86400) {
		x1 = progstart_x + (curtime - current_day) / time_compression;
		item = gnome_canvas_item_new(gnome_canvas_root(time_canvas), gnome_canvas_rect_get_type(), "x1", x1 - 1, "x2", x1 + 1, "y1", 0.0, "y2", time_height, "fill-color-gdk", &selected_bg_color, NULL);
		current_timemarker_item = item;
		gridtime_items = g_slist_prepend(gridtime_items, item);
		gnome_canvas_item_lower_to_bottom(item);
	}
	gnome_canvas_set_scroll_region(time_canvas, 0.0, 0.0, progstart_x + 86400 / time_compression, time_height);
	gtk_widget_set_usize(GTK_WIDGET(time_canvas), progstart_x + 86400 / time_compression, time_height);

	chindex_hash = g_hash_table_new(NULL, NULL);
	list = channels;
	i = 0;
	while(list != NULL) {
		ch = (struct GtvgChannel *) list->data;
		g_hash_table_insert(chindex_hash, ch, GINT_TO_POINTER(i));
		list = g_slist_next(list);
		i++;
	}

	i = 1;
	x1 = progstart_x;
	while(i < 48) {
		x1 += 1800 / time_compression;
		item = gnome_canvas_item_new(gnome_canvas_root(canvas), gnome_canvas_rect_get_type(), "x1", (i % 2 == 0) ? x1 : x1, "x2", (i % 2 == 0) ? x1 + 1 : x1 + 1, "y1", 0.0, "y2", progstart_y + g_slist_length(channels) * channel_height, "fill-color-gdk", &current_bg_color, NULL);
		gridprog_items = g_slist_prepend(gridprog_items, item);
		i++;
	}

	chcurrent_hash = g_hash_table_new(NULL, NULL);

	list = programs;
	list_begin = NULL;
	b2 = FALSE;
	while(list != NULL) {
		prog = (struct GtvgProgram *) list->data;
		if(prog->stop > current_day && prog->start < current_day + 86400) {
			blacklisted = g_slist_find_custom(blacklist, prog->title, gchar_compare_func) != NULL;
			if(list_begin == NULL)
				list_begin = list;
			i = GPOINTER_TO_INT(g_hash_table_lookup(chindex_hash, prog->channel));
			x1 = progstart_x + prog->start < current_day ? progstart_x : progstart_x + (prog->start - current_day) / time_compression;
			x2 = progstart_x + (prog->stop - current_day) / time_compression;
			width = x2 - x1;
			y1 = progstart_y + (i * channel_height) + channel_margin;
			y2 = progstart_y + ((i + 1) * channel_height) - channel_margin;
			height = y2 - y1;
			b = prog->start <= curtime && prog->stop > curtime;
			if(!b2 && (b || prog->start > curtime)) {
				if(g_hash_table_lookup(chcurrent_hash, prog->channel) == NULL) {
					current_gridprogs = g_slist_prepend(current_gridprogs, list);
					g_hash_table_insert(chcurrent_hash, prog->channel, list);
					if(g_hash_table_size(chcurrent_hash) == g_slist_length(channels)) {
						b2 = TRUE;
					}
				}
			}
			item = gnome_canvas_item_new(gnome_canvas_root(canvas), gnome_canvas_rect_get_type(), "x1", x1, "x2", x2, "y1", y1, "y2", y2, "fill-color-gdk", blacklisted ? NULL : (b ? &current_bg_color : (prog->favourites != NULL ? favBgColor(prog) : defBgColor(prog))), "outline-color-gdk", b ? &current_border_color : (prog->favourites != NULL ? &favourite_border_color : &default_border_color), "width-pixels", BORDER_WIDTH, NULL);
			gridprog_items = g_slist_prepend(gridprog_items, item);
			prog->canvas_rect = G_OBJECT(item);
			g_signal_connect(G_OBJECT(item), "event", G_CALLBACK(on_gridItem_event), prog);
		} else {
			prog->canvas_rect = NULL;
			prog->canvas_text = NULL;
		}
		list = g_slist_next(list);
	}

	if(current_day == tomorrow_time - 86400) {
		x1 = progstart_x + (curtime - current_day) / time_compression;
		scroll_x = progstart_x + (curtime - current_day - 1800) / time_compression;
		item = gnome_canvas_item_new(gnome_canvas_root(canvas), gnome_canvas_rect_get_type(), "x1", x1 - 1, "x2", x1 + 1, "y1", 0.0, "y2", progstart_y + g_slist_length(channels) * channel_height, "fill-color-gdk", &selected_bg_color, NULL);
		current_marker_item = item;
		gridprog_items = g_slist_prepend(gridprog_items, item);
	} else {
		scroll_x = 0.0;
	}

	list = list_begin;
	while(list != NULL) {
		prog = (struct GtvgProgram *) list->data;
		if(prog->stop > current_day && g_slist_find_custom(blacklist, prog->title, gchar_compare_func) == NULL) {
			if(prog->start >= current_day + 86400)
				break;
			strftime(stop_str, 80, "%R", &prog->stop_tm);
			strftime(start_str, 80, "%R", &prog->start_tm);
			//time interval ("20:00 - 21:30")
			g_snprintf(time_str, 200, _("%s\342\200\223%s"), start_str, stop_str);
			i = GPOINTER_TO_INT(g_hash_table_lookup(chindex_hash, prog->channel));
			b = prog->start <= curtime && prog->stop > curtime;
			x1 = progstart_x + prog->start < current_day ? progstart_x : progstart_x + (prog->start - current_day) / time_compression;
			if(b && x1 < scroll_x)
				x1 = scroll_x;
			x2 = progstart_x + (prog->stop - current_day) / time_compression;
			width = x2 - x1;
			y1 = progstart_y + (i * channel_height) + channel_margin;
			y2 = progstart_y + ((i + 1) * channel_height) - channel_margin;
			height = y2 - y1;
			if(prog->favourites != NULL) {
				gstr = g_markup_escape_text(prog->title, -1);
				gstr2 = g_strdup_printf("%s\n%s", gstr, time_str);
				g_free(gstr);
				list2 = prog->favourites;
				while(list2 != NULL) {
					struct GtvgFavourite *fav = (struct GtvgFavourite *) list2->data;

					if(fav->record > 0 || (recordings_enabled && fav->record < 0)) {
						gstr = g_strconcat(gstr2, " <span weight=\"bold\" foreground=\"red\">R</span>", NULL);
						break;
					}
					list2 = g_slist_next(list2);
				}
				if(list2 == NULL) {
					if(can_display_heart) {
						gstr = g_strconcat(gstr2, " <span weight=\"bold\" foreground=\"deep pink\">&#9829;</span>", NULL);
					} else {
						gstr = g_strconcat(gstr2, " <span weight=\"bold\" foreground=\"deep pink\">*</span>", NULL);
					}
				}
				g_free(gstr2);
				prog->canvas_favourite = TRUE;
			} else {
				gstr = g_strdup_printf("%s\n%s", prog->title, time_str);
				prog->canvas_favourite = FALSE;
			}
			item = gnome_canvas_item_new(gnome_canvas_root(canvas), gnome_canvas_text_get_type(), "x", x1 + text_margin, "y", y1 + text_margin, prog->favourites != NULL ? "markup" : "text", gstr, "fill-color-gdk", b ? &current_text_color : (prog->favourites != NULL ? favTextColor(prog) : defTextColor(prog)), "weight", prog->favourites != NULL ? PANGO_WEIGHT_BOLD : PANGO_WEIGHT_NORMAL, "anchor", GTK_ANCHOR_NW, "clip-width", width - (text_margin * 2), "clip-height", height - (text_margin * 2), "clip", TRUE, NULL);
			prog->canvas_text = G_OBJECT(item);
			gridprog_items = g_slist_prepend(gridprog_items, item);
			g_signal_connect(G_OBJECT(item), "event", G_CALLBACK(on_gridItem_event), prog);
			g_free(gstr);
		} else {
			prog->canvas_text = NULL;
		}
		list = g_slist_next(list);
	}
	if(current_day == tomorrow_time - 86400) {
		item = gnome_canvas_item_new(gnome_canvas_root(canvas), gnome_canvas_rect_get_type(), "x1", 0.0, "x2", progstart_x + (curtime - current_day) / time_compression, "y1", 0.0, "y2", progstart_y + g_slist_length(channels) * channel_height, "fill-color-gdk", &past_bg_color, "outline-color-gdk", &past_bg_color, NULL);
		past_backdrop_item = item;
		gridprog_items = g_slist_prepend(gridprog_items, item);
		gnome_canvas_item_lower_to_bottom(item);
		item = gnome_canvas_item_new(gnome_canvas_root(canvas), gnome_canvas_rect_get_type(), "x1", progstart_x + (curtime - current_day) / time_compression, "x2", progstart_x + 86400 / time_compression, "y1", 0.0, "y2", progstart_y + g_slist_length(channels) * channel_height, "fill-color-gdk", &future_bg_color, "outline-color-gdk", &future_bg_color, NULL);
		future_backdrop_item = item;
		gridprog_items = g_slist_prepend(gridprog_items, item);
		gnome_canvas_item_lower_to_bottom(item);
	} else {
		item = gnome_canvas_item_new(gnome_canvas_root(canvas), gnome_canvas_rect_get_type(), "x1", 0.0, "x2", progstart_x + 86400 / time_compression, "y1", 0.0, "y2", progstart_y + g_slist_length(channels) * channel_height, "fill-color-gdk", current_day >= tomorrow_time ? &future_bg_color : &past_bg_color, "outline-color-gdk", current_day >= tomorrow_time ? &future_bg_color : &past_bg_color, NULL);
		gridprog_items = g_slist_prepend(gridprog_items, item);
		gnome_canvas_item_lower_to_bottom(item);
	}
	gnome_canvas_set_scroll_region(canvas, 0.0, 0.0, progstart_x + 86400 / time_compression, progstart_y + g_slist_length(channels) * channel_height);
	gtk_widget_set_usize(GTK_WIDGET(canvas), progstart_x + 86400 / time_compression, progstart_y + g_slist_length(channels) * channel_height);
	g_free(stop_str);
	g_free(start_str);
	g_free(time_str);
	g_hash_table_destroy(chindex_hash);

	if(update_channels) {
		gnome_canvas_set_pixels_per_unit(ch_canvas, 1.0);
		list = channels;
		y1 = progstart_y;
		channel_width = 0.0;
		b = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(channelsList_store), &iter);
		while(b) {
			gtk_tree_model_get(GTK_TREE_MODEL(channelsList_store), &iter, CHANNELS_OBJECT_COLUMN, &ch, -1);
			if(ch->iconpath == NULL)
				icon = NULL;
			else
				icon = gdk_pixbuf_new_from_file_at_scale(ch->iconpath, -1, channel_height - channel_icon_y_margin * 2, TRUE, NULL);
			if(icon == NULL) {
				item = gnome_canvas_item_new(gnome_canvas_root(ch_canvas), gnome_canvas_text_get_type(), "x", channel_icon_x_margin, "y", y1 + channel_height / 2.0, "text", ch->name, "weight", PANGO_WEIGHT_BOLD, "anchor", GTK_ANCHOR_WEST, NULL);
				gnome_canvas_item_get_bounds(item, &x1, NULL, &x2, NULL);
				if(x2 - x1 > channel_width)
					channel_width = x2 - x1;
			} else {
				if(gdk_pixbuf_get_width(icon) > channel_width)
					channel_width = gdk_pixbuf_get_width(icon);
				item = gnome_canvas_item_new(gnome_canvas_root(ch_canvas), gnome_canvas_pixbuf_get_type(), "x", channel_icon_x_margin, "y", y1 + channel_icon_y_margin, "pixbuf", icon, NULL);
				g_object_unref(icon);
			}
			gridch_items = g_slist_prepend(gridch_items, item);
			y1 += channel_height;
			b = gtk_tree_model_iter_next(GTK_TREE_MODEL(channelsList_store), &iter);
		}
		list = gridch_items;
		while(list != NULL) {
			gnome_canvas_item_get_bounds(GNOME_CANVAS_ITEM(list->data), NULL, NULL, &x2, NULL);
			x2 -= channel_icon_x_margin;
			g_object_set(G_OBJECT(list->data), "x", (channel_width - x2) / 2.0 + channel_icon_x_margin, NULL);
			list = g_slist_next(list);
		}
		channel_width += channel_icon_x_margin * 2;
		gnome_canvas_set_scroll_region(ch_canvas, 0.0, 0.0, channel_width, progstart_y + g_slist_length(channels) * channel_height + 50.0);
		gtk_widget_set_usize(GTK_WIDGET(ch_canvas), channel_width, progstart_y + g_slist_length(channels) * channel_height + 50.0);
	}

	gnome_canvas_set_pixels_per_unit(nw_canvas, 1.0);

	gnome_canvas_set_scroll_region(nw_canvas, 0.0, 0.0, channel_width, time_height);
	gtk_widget_set_usize(GTK_WIDGET(nw_canvas), channel_width, time_height);

	if(scroll_x > 0.0) {
		while(gtk_events_pending())
			gtk_main_iteration();
	}
	grid_at_current = FALSE;
	gtk_adjustment_set_value(gtk_scrolled_window_get_hadjustment(GTK_SCROLLED_WINDOW(glade_xml_get_widget(gxml, "programCanvas_scrolled"))), scroll_x);
	if(scroll_x > 0.0)
		grid_at_current = TRUE;

	gtk_text_buffer_set_text(gtk_text_view_get_buffer(GTK_TEXT_VIEW(glade_xml_get_widget(gxml, "gridDescriptionView"))), "", -1);

	programSelected(selectedProgram());

	g_hash_table_destroy(chcurrent_hash);

}

void updateProgramGrid(gboolean update_channels)
{
	if(gtk_notebook_get_current_page(GTK_NOTEBOOK(glade_xml_get_widget(gxml, "viewPages"))) != 1) {
		pending_grid_updates = TRUE;
		pending_grid_update_channels = update_channels;
		return;
	}
	if(pending_grid_updates && pending_grid_update_channels)
		update_channels = TRUE;
	updateProgramGrid_sub(update_channels);
}

int loadXMLTVFile(const char *filename, gboolean init_run)
{

	xmlNodePtr cur, child, child2;
	xmlDocPtr doc;
	gchar *gstr, *gstr2, *tmpstr = NULL;
	gboolean download_icons = FALSE;
	gboolean has_gnomevfs = FALSE, has_wget = FALSE;
	GError *error = NULL;
	GSList *list, *list2, *prch_list = NULL, *prchannels = NULL;
	GHashTable *prch_hash, *category_hash;
	struct GtvgProgram *prog;
	struct GtvgChannel *ch;
	struct GtvgFavourite *fav;
	struct GtvgCategory *cat;
	GtkWidget *dialog;
	gboolean b, update_favs;
	time_t first_start, tmp_t;
	struct tm tmptp;
	long int gmtoff;

	loading_xmltv = TRUE;

	doc = xmlParseFile(filename);
	cur = xmlDocGetRootElement(doc);

	tmp_t = time(NULL);
	localtime_r(&tmp_t, &tmptp);

	if(cur == NULL) {
		xmlFreeDoc(doc);
		return 1;
	}
	while(cur != NULL) {
		if(xmlStrEqual(cur->name, (const xmlChar *) "tv")) {
			break;
		}
		cur = cur->next;
	}
	if(cur == NULL) {
		xmlFreeDoc(doc);
		return 1;
	}

	if(favourite_schedules != NULL) {
		g_slist_foreach(favourite_schedules, free_slist_favsched, NULL);
		g_slist_free(favourite_schedules);
		favourite_schedules = NULL;
	}

	if(record_schedules != NULL) {
		g_slist_foreach(record_schedules, free_slist_recsched, NULL);
		g_slist_free(record_schedules);
		record_schedules = NULL;
	}

	if(disabled_record_schedules != NULL) {
		g_slist_foreach(disabled_record_schedules, free_slist_recsched, NULL);
		g_slist_free(disabled_record_schedules);
		disabled_record_schedules = NULL;
	}

	if(notifying_favscheds != NULL) {
		g_slist_foreach(notifying_favscheds, free_slist_favsched, NULL);
		g_slist_free(notifying_favscheds);
		notifying_favscheds = NULL;
	}

	if(channels != NULL) {
		if(channels_moved)
			saveChannelConf();
		g_slist_foreach(channels, free_slist_channel, NULL);
		g_slist_free(channels);
		channels = NULL;
	}

	current_record_prog = NULL;

	if(programs != NULL) {
		g_slist_foreach(programs, free_slist_program, NULL);
		g_slist_free(programs);
		programs = NULL;
	}

	if(original_categories != NULL) {
		g_slist_foreach(original_categories, free_slist_gchar, NULL);
		g_slist_free(original_categories);
		original_categories = NULL;
	}

	if(!init_run) {
		saveCategories();
		if(categories != NULL) {
			g_slist_foreach(categories, free_list_category, NULL);
			g_slist_free(categories);
			categories = NULL;
		}
		loadCategories();
	}

	if(channel_hash != NULL) {
		g_hash_table_destroy(channel_hash);
	}

	first_day = 0;
	last_day = 0;

	channel_hash = g_hash_table_new_full(g_str_hash, g_str_equal, NULL, NULL);
	category_hash = g_hash_table_new_full(g_str_hash, g_str_equal, NULL, NULL);
	list = categories;
	while(list != NULL) {
		cat = (struct GtvgCategory *) list->data;
		list2 = cat->original_names;
		while(list2 != NULL) {
			g_hash_table_insert(category_hash, list2->data, cat);
			list2 = g_slist_next(list2);
		}
		list = g_slist_next(list);
	}
	prch_hash = g_hash_table_new_full(g_str_hash, g_str_equal, NULL, NULL);

	cur = cur->xmlChildrenNode;
	while(cur != NULL) {

		if(xmlStrEqual(cur->name, (const xmlChar *) "channel")) {

			ch = gtvg_channel_new();

			child = cur->xmlChildrenNode;
			ch->id = g_strdup((gchar *) xmlGetProp(cur, (xmlChar *) "id"));

			while(child != NULL) {
				if(xmlStrEqual(child->name, (const xmlChar *) "display-name")) {
					gstr2 = (gchar *) xmlNodeListGetString(doc, child->xmlChildrenNode, 1);
					if(ch->name == NULL || strlen(gstr2) > strlen(ch->name)) {
						ch->name = gstr2;
					}
				} else if(xmlStrEqual(child->name, (const xmlChar *) "icon")) {
					ch->iconurl = (gchar *) xmlGetProp(child, (xmlChar *) "src");
				}
				child = child->next;
			}
			if(ch->name == NULL) {
				ch->name = g_strdup(ch->id);
			} else {
				ch->name = g_strdup(ch->name);
			}
			if(ch->iconurl != NULL)
				ch->iconurl = g_strdup(ch->iconurl);

			g_hash_table_insert(channel_hash, ch->id, ch);
			channels = g_slist_prepend(channels, ch);

		} else if(xmlStrEqual(cur->name, (const xmlChar *) "programme")) {

			prog = gtvg_program_new();

			memset(&tmptp, '\0', sizeof(tmptp));

			strptime((const char *) xmlGetProp(cur, (xmlChar *) "start"), "%Y%m%d%H%M%S %z", &tmptp);

			gmtoff = tmptp.tm_gmtoff;
			prog->start = timegm(&tmptp);
			prog->start -= gmtoff - tmptp.tm_gmtoff;
			localtime_r(&prog->start, &prog->start_tm);

			tmpstr = (gchar *) xmlGetProp(cur, (xmlChar *) "stop");
			if(tmpstr != NULL && strlen(tmpstr) > 0) {
				memset(&tmptp, '\0', sizeof(tmptp));
				strptime((const char *) tmpstr, "%Y%m%d%H%M%S %z", &tmptp);
				gmtoff = tmptp.tm_gmtoff;
				prog->stop = timegm(&tmptp);
				prog->stop -= gmtoff - tmptp.tm_gmtoff;
				localtime_r(&prog->stop, &prog->stop_tm);
			}
			prog->chid = g_strdup((gchar *) xmlGetProp(cur, (xmlChar *) "channel"));

			tmpstr = (gchar *) xmlGetProp(cur, (xmlChar *) "showview");
			if(tmpstr != NULL)
				prog->showview = g_strdup(tmpstr);
			tmpstr = (gchar *) xmlGetProp(cur, (xmlChar *) "videoplus");
			if(tmpstr != NULL)
				prog->videoplus = g_strdup(tmpstr);

			child = cur->xmlChildrenNode;
			while(child != NULL) {
				if(prog->title == NULL && xmlStrEqual(child->name, (const xmlChar *) "title")) {
					prog->title = g_strdup((gchar *) xmlNodeListGetString(doc, child->xmlChildrenNode, 1));
				} else if(prog->subtitle == NULL && xmlStrEqual(child->name, (const xmlChar *) "sub-title")) {
					prog->subtitle = g_strdup((gchar *) xmlNodeListGetString(doc, child->xmlChildrenNode, 1));
				} else if(xmlStrEqual(child->name, (const xmlChar *) "desc")) {
					if(prog->description != NULL) {
						gstr2 = (gchar *) xmlNodeListGetString(doc, child->xmlChildrenNode, 1);
						if(strlen(gstr2) > strlen(prog->description)) {
							if(prog->short_description != NULL)
								g_free(prog->short_description);
							prog->short_description = prog->description;
							prog->description = g_strdup(gstr2);
						} else if(prog->short_description == NULL || strlen(gstr2) > strlen(prog->short_description)) {
							if(prog->short_description != NULL)
								g_free(prog->short_description);
							prog->short_description = g_strdup(gstr2);
						}
					} else {
						prog->description = g_strdup((gchar *) xmlNodeListGetString(doc, child->xmlChildrenNode, 1));
					}
				} else if(xmlStrEqual(child->name, (const xmlChar *) "category")) {
					gstr = (gchar *) xmlNodeListGetString(doc, child->xmlChildrenNode, 1);
					cat = g_hash_table_lookup(category_hash, gstr);
					if(cat == NULL) {
						cat = gtvg_category_new();
						cat->name = g_strdup(gstr);
						cat->original_names = g_slist_prepend(cat->original_names, g_strdup(gstr));
						categories = g_slist_prepend(categories, cat);
						original_categories = g_slist_prepend(original_categories, g_strdup(gstr));
						g_hash_table_insert(category_hash, (gchar *) cat->original_names->data, cat);
						prog->categories = g_slist_append(prog->categories, cat);
					} else {
						if(g_slist_find_custom(original_categories, gstr, gchar_compare_func) == NULL)
							original_categories = g_slist_prepend(original_categories, g_strdup(gstr));
						if(!g_slist_find(prog->categories, cat))
							prog->categories = g_slist_append(prog->categories, cat);
					}
					prog->original_categories = g_slist_prepend(prog->original_categories, g_strdup(gstr));
				} else if(prog->episode == NULL && xmlStrEqual(child->name, (const xmlChar *) "episode-num")) {
					if(xmlStrEqual(xmlGetProp(child, (xmlChar *) "system"), (const xmlChar *) "onscreen")) {
						prog->episode = g_strdup((gchar *) xmlNodeListGetString(doc, child->xmlChildrenNode, 1));
					}
				} else if(prog->date == NULL && xmlStrEqual(child->name, (const xmlChar *) "date")) {
					prog->date = g_strdup((gchar *) xmlNodeListGetString(doc, child->xmlChildrenNode, 1));
				} else if(xmlStrEqual(child->name, (const xmlChar *) "credits")) {
					child2 = child->xmlChildrenNode;
					while(child2 != NULL) {
						if(xmlStrEqual(child2->name, (const xmlChar *) "director")) {
							prog->directors = g_slist_prepend(prog->directors, g_strdup((gchar *) xmlNodeListGetString(doc, child2->xmlChildrenNode, 1)));
						} else if(xmlStrEqual(child2->name, (const xmlChar *) "actor")) {
							prog->actors = g_slist_prepend(prog->actors, g_strdup((gchar *) xmlNodeListGetString(doc, child2->xmlChildrenNode, 1)));
						} else if(xmlStrEqual(child2->name, (const xmlChar *) "writer")) {
							prog->writers = g_slist_prepend(prog->writers, g_strdup((gchar *) xmlNodeListGetString(doc, child2->xmlChildrenNode, 1)));
						} else if(xmlStrEqual(child2->name, (const xmlChar *) "adapter")) {
							prog->adapters = g_slist_prepend(prog->adapters, g_strdup((gchar *) xmlNodeListGetString(doc, child2->xmlChildrenNode, 1)));
						} else if(xmlStrEqual(child2->name, (const xmlChar *) "producer")) {
							prog->producers = g_slist_prepend(prog->producers, g_strdup((gchar *) xmlNodeListGetString(doc, child2->xmlChildrenNode, 1)));
						} else if(xmlStrEqual(child2->name, (const xmlChar *) "presenter")) {
							prog->presenters = g_slist_prepend(prog->presenters, g_strdup((gchar *) xmlNodeListGetString(doc, child2->xmlChildrenNode, 1)));
						} else if(xmlStrEqual(child2->name, (const xmlChar *) "commentator")) {
							prog->commentators = g_slist_prepend(prog->commentators, g_strdup((gchar *) xmlNodeListGetString(doc, child2->xmlChildrenNode, 1)));
						} else if(xmlStrEqual(child2->name, (const xmlChar *) "guest")) {
							prog->guests = g_slist_prepend(prog->guests, g_strdup((gchar *) xmlNodeListGetString(doc, child2->xmlChildrenNode, 1)));
						}
						child2 = child2->next;
					}
				} else if(prog->language == NULL && xmlStrEqual(child->name, (const xmlChar *) "language")) {
					prog->language = g_strdup((gchar *) xmlNodeListGetString(doc, child->xmlChildrenNode, 1));
				} else if(prog->original_language == NULL && xmlStrEqual(child->name, (const xmlChar *) "orig-language")) {
					prog->original_language = g_strdup((gchar *) xmlNodeListGetString(doc, child->xmlChildrenNode, 1));
				} else if(prog->length == NULL && xmlStrEqual(child->name, (const xmlChar *) "length")) {
					prog->length = g_strdup((gchar *) xmlNodeListGetString(doc, child->xmlChildrenNode, 1));
					prog->length_units = g_strdup((gchar *) xmlGetProp(child, (xmlChar *) "units"));
				} else if(prog->country == NULL && xmlStrEqual(child->name, (const xmlChar *) "country")) {
					prog->country = g_strdup((gchar *) xmlNodeListGetString(doc, child->xmlChildrenNode, 1));
				} else if(prog->star_rating == NULL && xmlStrEqual(child->name, (const xmlChar *) "star-rating")) {
					child2 = child->xmlChildrenNode;
					while(child2 != NULL) {
						if(xmlStrEqual(child2->name, (const xmlChar *) "value")) {
							prog->star_rating = g_strdup((gchar *) xmlNodeListGetString(doc, child2->xmlChildrenNode, 1));
						}
						child2 = child2->next;
					}
				} else if(prog->rating == NULL && xmlStrEqual(child->name, (const xmlChar *) "rating")) {
					child2 = child->xmlChildrenNode;
					while(child2 != NULL) {
						if(xmlStrEqual(child2->name, (const xmlChar *) "value")) {
							prog->rating = g_strdup((gchar *) xmlNodeListGetString(doc, child2->xmlChildrenNode, 1));
						}
						child2 = child2->next;
					}
				} else if(xmlStrEqual(child->name, (const xmlChar *) "video")) {
					child2 = child->xmlChildrenNode;
					while(child2 != NULL) {
						if(prog->aspect == NULL && xmlStrEqual(child2->name, (const xmlChar *) "aspect")) {
							prog->aspect = g_strdup((gchar *) xmlNodeListGetString(doc, child2->xmlChildrenNode, 1));
						} else if(prog->quality == NULL && xmlStrEqual(child2->name, (const xmlChar *) "quality")) {
							prog->quality = g_strdup((gchar *) xmlNodeListGetString(doc, child2->xmlChildrenNode, 1));
						} else if(prog->color == NULL && xmlStrEqual(child2->name, (const xmlChar *) "colour")) {
							prog->color = g_strdup((gchar *) xmlNodeListGetString(doc, child2->xmlChildrenNode, 1));
						}
						child2 = child2->next;
					}
				} else if(xmlStrEqual(child->name, (const xmlChar *) "audio")) {
					child2 = child->xmlChildrenNode;
					while(child2 != NULL) {
						if(prog->audio_present == NULL && xmlStrEqual(child2->name, (const xmlChar *) "present")) {
							prog->audio_present = g_strdup((gchar *) xmlNodeListGetString(doc, child2->xmlChildrenNode, 1));
						} else if(prog->audio_stereo == NULL && xmlStrEqual(child2->name, (const xmlChar *) "stereo")) {
							prog->audio_stereo = g_strdup((gchar *) xmlNodeListGetString(doc, child2->xmlChildrenNode, 1));
						}
						child2 = child2->next;
					}
				} else if(!prog->previously_shown && xmlStrEqual(child->name, (const xmlChar *) "previously-shown")) {
					prog->previously_shown = TRUE;
					prog->previous_start = g_strdup((gchar *) xmlGetProp(child, (xmlChar *) "start"));
					prog->previous_chid = (gchar *) xmlGetProp(child, (xmlChar *) "channel");
				} else if(xmlStrEqual(child->name, (const xmlChar *) "new")) {
					prog->new_program = TRUE;
				}
				child = child->next;
			}

			prch_list = (GSList *) g_hash_table_lookup(prch_hash, prog->chid);
			if(prch_list == NULL) {
				prchannels = g_slist_prepend(prchannels, prog->chid);
			}
			prch_list = g_slist_prepend(prch_list, prog);
			g_hash_table_replace(prch_hash, prog->chid, prch_list);

			programs = g_slist_prepend(programs, prog);

		}
		cur = cur->next;
	}

	list2 = prchannels;
	while(list2 != NULL) {
		gstr = (gchar *) list2->data;
		prch_list = (GSList *) g_hash_table_lookup(prch_hash, gstr);
		if(prch_list != NULL) {
			prch_list = g_slist_sort(prch_list, prch_compare_func);
			prog = (struct GtvgProgram *) prch_list->data;
			ch = (struct GtvgChannel *) g_hash_table_lookup(channel_hash, prog->chid);
			if(ch == NULL) {
				ch = gtvg_channel_new();
				ch->id = g_strdup(prog->chid);
				ch->name = g_strdup(prog->chid);
				g_hash_table_insert(channel_hash, ch->id, ch);
				channels = g_slist_prepend(channels, ch);
			}
			list = prch_list;
			while(list != NULL) {
				prog = (struct GtvgProgram *) list->data;
				prog->channel = ch;
				if(prog->previous_chid != NULL) {
					prog->previous_channel = (struct GtvgChannel *) g_hash_table_lookup(channel_hash, prog->previous_chid);
				}
				if(prog->title == NULL)
					prog->title = g_strdup(_("Untitled"));
				list = g_slist_next(list);
				if(prog->stop <= 0) {
					if(list != NULL) {
						prog->stop = ((struct GtvgProgram *) list->data)->start;
						prog->stop_tm = ((struct GtvgProgram *) list->data)->start_tm;
					} else {
						//no idea when the program stops, make it one hour
						prog->stop = prog->start + 3600;
						localtime_r(&prog->stop, &prog->stop_tm);
					}
				}
			}
			g_slist_free(prch_list);
		}
		list2 = g_slist_next(list2);
	}

	g_slist_free(prchannels);

	g_hash_table_destroy(category_hash);

	g_hash_table_destroy(prch_hash);

	loadChannelConf();

	list = channels;
	while(list != NULL) {
		ch = (struct GtvgChannel *) list->data;
		if(ch->custom_icon) {
			ch->icon = gdk_pixbuf_new_from_file_at_scale(ch->iconpath, -1, 22, TRUE, NULL);
		} else if(ch->iconurl != NULL) {
			gstr = g_path_get_basename(ch->iconurl);
			ch->iconpath = g_build_path(G_DIR_SEPARATOR_S, g_get_home_dir(), ".xmltv", "icons", gstr, NULL);
			g_free(gstr);
			ch->icon = gdk_pixbuf_new_from_file_at_scale(ch->iconpath, -1, 22, TRUE, NULL);
			if((!asked_if_download || download_icons) && ch->icon == NULL && !g_file_test(ch->iconpath, G_FILE_TEST_EXISTS)) {
				gstr = g_find_program_in_path("gnomevfs-copy");
				if(gstr) {
					g_free(gstr);
					has_gnomevfs = TRUE;
				} else {
					gstr = g_find_program_in_path("wget");
					if(gstr) {
						has_wget = TRUE;
						g_free(gstr);
					} else {
						asked_if_download = TRUE;
						download_icons = FALSE;
					}
				}
				if(!asked_if_download) {
					dialog = gtk_message_dialog_new(GTK_WINDOW(window), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, _("Do you want to download missing channel icons?\n\n(This question will never be asked again. If you later want to update the icons, please you use %s in the File menu.)"), _("Update Channel Icons"));
					if(gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_YES) {
						download_icons = TRUE;
						gstr = g_path_get_dirname(tmpstr);
						g_mkdir_with_parents(gstr, S_IRWXU);
						g_free(gstr);
					}
					gtk_widget_destroy(dialog);
					asked_if_download = TRUE;
					gconf_client_set_bool(client, "/apps/gtvg/has_asked_if_download_icons", TRUE, NULL);
				}
				if(download_icons) {
					if(has_gnomevfs) {
						gstr = g_strdup_printf("gnomevfs-copy %s %s", ch->iconurl, ch->iconpath);
						if(g_spawn_command_line_sync(gstr, NULL, NULL, NULL, &error)) {
							ch->icon = gdk_pixbuf_new_from_file_at_scale(ch->iconpath, -1, 22, TRUE, NULL);
						} else {
							g_printerr(_("Failed to download channel icon (using %s): %s"), gstr, error->message);
							g_error_free(error);
						}
						g_free(gstr);
					} else if(has_wget) {
						gstr = g_strdup_printf("wget --output-document=%s %s", ch->iconpath, ch->iconurl);
						if(g_spawn_command_line_sync(gstr, NULL, NULL, NULL, &error)) {
							ch->icon = gdk_pixbuf_new_from_file_at_scale(ch->iconpath, -1, 22, TRUE, NULL);
						} else {
							g_printerr(_("Failed to download channel icon (using %s): %s"), gstr, error->message);
							g_error_free(error);
						}
						g_free(gstr);
					}
				}
			}
		}
		list = g_slist_next(list);
	}

	channels = g_slist_sort(channels, channels_compare_func);
	programs = g_slist_sort(programs, programs_compare_func);
	categories = g_slist_sort(categories, categories_compare_func);
	original_categories = g_slist_sort(original_categories, gchar_compare_func);

	if(programs == NULL)
		first_start = 0;
	else
		first_start = ((struct GtvgProgram *) programs->data)->start;

	update_favs = FALSE;
	if(first_start > 0 && first_start <= time(NULL)) {
		list = favourites;
		while(list) {
			fav = (struct GtvgFavourite *) list->data;
			if(fav->time > 0 && fav->time < first_start) {
				gtvg_favourite_free(fav);
				favourites = g_slist_remove_link(favourites, list);
				list = favourites;
				update_favs = TRUE;
			} else {
				list = g_slist_next(list);
			}
		}
	}
	if(programs == NULL) {
		first_day = 0;
	} else {
		tmptp = ((struct GtvgProgram *) programs->data)->start_tm;
		tmptp.tm_sec = 0;
		b = (tmptp.tm_hour * 60 + tmptp.tm_min < day_starts_at);
		tmptp.tm_hour = day_starts_at / 60;
		tmptp.tm_min = day_starts_at % 60;
		first_day = mktime(&tmptp);
		if(b)
			first_day -= 86400;
		if(current_day < first_day) {
			current_day = tomorrow_time - 86400;
		}
	}
	if(first_day != 0) {
		tmptp = ((struct GtvgProgram *) g_slist_last(programs)->data)->stop_tm;
		tmptp.tm_sec = 0;
		b = (tmptp.tm_hour * 60 + tmptp.tm_min < day_starts_at);
		tmptp.tm_hour = day_starts_at / 60;
		tmptp.tm_min = day_starts_at % 60;
		last_day = mktime(&tmptp);
		if(b)
			last_day -= 86400;
	} else {
		last_day = 0;
	}

	updateDays();

	xmlFreeDoc(doc);

	updateReminders(NULL, NULL);
	updateChannelList();
	updateProgramList();
	updateProgramGrid(TRUE);
	updateCategoryList(NULL);

	if(update_favs)
		updateFavourites();

	status_list = programs;
	updateTooltip();

	loading_xmltv = FALSE;

	return 0;

}

void loadXMLTV(gboolean init_run)
{
	GConfValue *gvalue;
	struct stat buf;
	GtkWidget *dialog;

	gvalue = gconf_client_get(client, "/apps/gtvg/xmltv_file", NULL);
	if(gvalue == NULL) {
		dialog = gtk_message_dialog_new(GTK_WINDOW(window), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, _("No XMLTV file specified"));
		gtk_dialog_run(GTK_DIALOG(dialog));
		gtk_widget_destroy(dialog);
		return;
	}
	if(g_stat(gconf_value_get_string(gvalue), &buf) == 0) {
		xml_load_time = buf.st_mtime;
	}
	if(loadXMLTVFile(gconf_value_get_string(gvalue), init_run) != 0) {
		dialog = gtk_message_dialog_new(GTK_WINDOW(window), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, _("Failed to load XMLTV file: %s"), gconf_value_get_string(gvalue));
		gtk_dialog_run(GTK_DIALOG(dialog));
		gtk_widget_destroy(dialog);
	}
	gconf_value_free(gvalue);
}

/* bacon message callback */
static void on_bacon_message_received(const char *message, gpointer data)
{
	if(g_str_equal(message, "raise")) {
		gtk_window_present(GTK_WINDOW(window));
	} else {
		g_warning("Received unknown bacon command: >>>%s<<<", message);
	}
}

int main(int argc, char *argv[])
{

	GConfValue *gvalue;
	gboolean show_status_icon;
	const char *arg;
	int mainwindowState = MAINWINDOW_SHOWN;
	int i, result;
	time_t curtime;
	struct tm curtp, time_tm;
	gchar *gstr;
	gboolean b, file_updated = FALSE;
	PangoContext *context;
	PangoFont *font;
	PangoLanguage *language;
	PangoCoverage *coverage;
	PangoFontset *fontset;
	GError *error = NULL;

#ifdef USE_SM
	gchar *opt_session_arg = NULL;
#endif

	g_thread_init(NULL);

#ifdef ENABLE_NLS
	bindtextdomain(GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
	bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
	textdomain(GETTEXT_PACKAGE);
#endif

	notify_init("gtvg");

	g_set_prgname("gtvg");
	gtk_set_locale();
	gtk_init(&argc, &argv);

	bacon_connection = bacon_message_connection_new("gtvg");
	if(bacon_connection) {
		if(!bacon_message_connection_get_is_server(bacon_connection)) {
			g_warning(_("The TV Guide seems to be running already!"));
			bacon_message_connection_send(bacon_connection, "raise");
			bacon_message_connection_free(bacon_connection);
			gdk_notify_startup_complete();
			exit(0);
		} else {
			bacon_message_connection_set_callback(bacon_connection, on_bacon_message_received, NULL);
		}
	} else {
		g_warning("Cannot create IPC connection for the TV Guide!");
	}

	g_set_application_name(_("gTVG TV Guide"));
	gtk_window_set_default_icon_name("gtvg");

#ifdef HAVE_LIBGNOME
	gnome_sound_init("localhost");
#endif

	for(i = 1; i < argc; ++i) {
		arg = argv[i];
		if(!strcmp(arg, "--version") || !strcmp(arg, "-v")) {
			g_print("gTVG TV Guide %s\n", VERSION);
			return 0;
		} else if(!strcmp(arg, "--help") || !strcmp(arg, "-h")) {
			show_help();
			return 0;
		} else if(!strcmp(arg, "--iconify")) {
			mainwindowState = MAINWINDOW_ICONIFIED;
		} else if(!strncmp(arg, "--mainwindow-state=", 19)) {
			const gchar *param = arg + 19;

			if(g_str_equal(param, "iconified"))
				mainwindowState = MAINWINDOW_ICONIFIED;
			else if(g_str_equal(param, "hidden"))
				mainwindowState = MAINWINDOW_HIDDEN;
			else if(g_str_equal(param, "shown"))
				mainwindowState = MAINWINDOW_SHOWN;
			else
				fprintf(stderr, _("The --mainwindow-state argument must be given a parameter.\n"));
#ifdef USE_SM
		} else if(!strcmp(arg, "--session")) {
			i++;
			if(i < argc) {
				opt_session_arg = g_strdup(argv[i]);
			} else
				fprintf(stderr, _("The --session argument must be given a parameter.\n"));
#endif
		} else {
			fprintf(stderr, _("gTVG encountered an unknown argument: %s\n"), arg);
		}
	}

	gtk_icon_theme_append_search_path(gtk_icon_theme_get_default(), PACKAGE_DATA_DIR "/gtvg/icons");

	gxml = glade_xml_new(GLADE_FILE, NULL, NULL);
	glade_xml_signal_autoconnect(gxml);

	grabCommandCombo_store = NULL;

	client = gconf_client_get_default();
	gconf_client_add_dir(client, "/apps/gtvg", GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
	gconf_client_add_dir(client, "/desktop/gnome/interface", GCONF_CLIENT_PRELOAD_NONE, NULL);
	gconf_notify_id = gconf_client_notify_add(client, "/apps/gtvg", on_gconf_notify, NULL, NULL, NULL);

	create_window();

	context = gtk_widget_get_pango_context(window);
	language = pango_context_get_language(context);
	fontset = pango_context_load_fontset(context, gtk_widget_get_style(window)->font_desc, language);
	if(fontset != NULL) {
		font = pango_fontset_get_font(fontset, 0x2605);
		if(font != NULL) {
			coverage = pango_font_get_coverage(font, language);
			can_display_star = (pango_coverage_get(coverage, 0x2605) != PANGO_COVERAGE_NONE && pango_coverage_get(coverage, 0x2606) != PANGO_COVERAGE_NONE);
			g_object_unref(font);
			pango_coverage_unref(coverage);
		}
		font = pango_fontset_get_font(fontset, 0x2665);
		if(font != NULL) {
			coverage = pango_font_get_coverage(font, language);
			can_display_heart = (pango_coverage_get(coverage, 0x2665) != PANGO_COVERAGE_NONE);
			g_object_unref(font);
			pango_coverage_unref(coverage);
		}
	}
	g_object_unref(fontset);

	show_status_icon = gconf_client_get_bool(client, "/apps/gtvg/show_in_notification_area", NULL);

	if(mainwindowState == MAINWINDOW_ICONIFIED || (mainwindowState == MAINWINDOW_HIDDEN && !show_status_icon)) {
		gtk_window_iconify(GTK_WINDOW(window));
		gtk_widget_show(window);
	} else if(mainwindowState == MAINWINDOW_SHOWN) {
		gtk_widget_show(window);
	} else {
		gtk_widget_show(window);
		gtk_widget_hide(window);
	}

	gstr = gconf_client_get_string(client, "/apps/gtvg/day_starts_at", NULL);
	if(gstr != NULL) {
		if(strptime(gstr, "%H:%M", &time_tm) != NULL) {
			day_starts_at = time_tm.tm_min + time_tm.tm_hour * 60;
		}
		g_free(gstr);
	}

	gvalue = gconf_client_get(client, "/apps/gtvg/current_programs_in_tooltip", NULL);
	if(gvalue != NULL) {
		current_tooltip_items = gconf_value_get_int(gvalue);
		gconf_value_free(gvalue);
	}
	gvalue = gconf_client_get(client, "/apps/gtvg/upcoming_programs_in_tooltip", NULL);
	if(gvalue != NULL) {
		future_tooltip_items = gconf_value_get_int(gvalue);
		gconf_value_free(gvalue);
	}

	gvalue = gconf_client_get_without_default(client, "/apps/gtvg/xmltv_file", NULL);
	if(gvalue == NULL) {
		result = configure(TRUE);
		if(result == 0) {
			g_print("Initial configuration aborted. Exiting.");
			return 0;
		}
		file_updated = (result == 2);
	} else {
		gconf_value_free(gvalue);
		if(gconf_client_get_bool(client, "/apps/gtvg/update_on_startup", NULL)) {
			updateXMLTVFile(FALSE);
			file_updated = TRUE;
		}
	}

	loadFavourites();
	loadCategories();
	blacklist = gconf_client_get_list(client, "/apps/gtvg/blacklist", GCONF_VALUE_STRING, NULL);

	asked_if_download = gconf_client_get_bool(client, "/apps/gtvg/has_asked_if_download_icons", NULL);

	curtime = time(NULL);
	prevtime = curtime;
	localtime_r(&curtime, &curtp);
	curtp.tm_sec = 0;
	b = FALSE;
	if(curtp.tm_hour * 60 + curtp.tm_min < day_starts_at) {
		b = TRUE;
	}
	curtp.tm_hour = day_starts_at / 60;
	curtp.tm_min = day_starts_at % 60;
	current_day = mktime(&curtp);
	if(b)
		current_day -= 86400;
	tomorrow_time = current_day + 86400;

	status_icon = gtk_status_icon_new_from_icon_name("gtvg");
	gtk_status_icon_set_tooltip(status_icon, "gTVG TV Guide");
	gtk_status_icon_set_visible(status_icon, show_status_icon);

	reminders_enabled = gconf_client_get_bool(client, "/apps/gtvg/reminders_enabled", NULL);
	reminder_time = gconf_client_get_int(client, "/apps/gtvg/reminder_time", NULL);
	reminder_duration = gconf_client_get_int(client, "/apps/gtvg/reminder_duration", NULL);
	reminder_details = gconf_client_get_bool(client, "/apps/gtvg/show_reminder_details", NULL);
	notify_sound = gconf_client_get_bool(client, "/apps/gtvg/play_reminder_sound", NULL);
	notify_sound_regardless = gconf_client_get_bool(client, "/apps/gtvg/always_play_reminder_sound", NULL);
	notify_sound_file = gconf_client_get_string(client, "/apps/gtvg/reminder_sound_file", NULL);
	if(notify_sound_file != NULL && strlen(notify_sound_file) == 0) {
		g_free(notify_sound_file);
		notify_sound_file = NULL;
	}
	wakeup_enabled = gconf_client_get_bool(client, "/apps/gtvg/wakeup_enabled", NULL);
	recordings_enabled = gconf_client_get_bool(client, "/apps/gtvg/recordings_enabled", NULL);
	ask_record = gconf_client_get_bool(client, "/apps/gtvg/ask_if_record", NULL);
	start_recording_command = gconf_client_get_string(client, "/apps/gtvg/start_recording_command", NULL);
	stop_recording_command = gconf_client_get_string(client, "/apps/gtvg/stop_recording_command", NULL);
	start_margin = gconf_client_get_int(client, "/apps/gtvg/start_recording_margin", NULL);
	stop_margin = gconf_client_get_int(client, "/apps/gtvg/stop_recording_margin", NULL);

	loadXMLTV(TRUE);

	updateFavourites();
	updateBlacklist();

	g_signal_connect(G_OBJECT(status_icon), "activate", G_CALLBACK(on_status_icon_activated), NULL);
	g_signal_connect(G_OBJECT(status_icon), "popup-menu", G_CALLBACK(on_status_icon_popup_menu), NULL);

	while(gtk_events_pending())
		gtk_main_iteration();

#ifdef USE_SM
	session_init(BIN_DIR G_DIR_SEPARATOR_S "gtvg", opt_session_arg);
	session_set_cmd(NULL, mainwindowState);
#endif

	g_signal_connect(G_OBJECT(window), "window_state_event", G_CALLBACK(on_window_state_event), NULL);

	checkFavourites(NULL);

	g_timeout_add_full(G_PRIORITY_DEFAULT_IDLE, (guint) (60 - (time(NULL) % 60)) * 1000, checkProgramTimes, NULL, NULL);

	g_signal_connect(G_OBJECT(window), "show", G_CALLBACK(on_window_shown), NULL);

	gconf_client_notify_add(client, "/desktop/gnome/interface/toolbar_style", on_gconf_notify, NULL, NULL, NULL);

	connection = dbus_g_bus_get(DBUS_BUS_SESSION, &error);
	if(connection == NULL) {
		g_printerr(_("Failed to open connection to bus: %s\n"), error->message);
		g_error_free(error);
		error = NULL;
		can_suspend = FALSE;
		proxy = NULL;
	} else {
		proxy = dbus_g_proxy_new_for_name(connection, "org.freedesktop.PowerManagement", "/org/freedesktop/PowerManagement", "org.freedesktop.PowerManagement");
		if(!dbus_g_proxy_call(proxy, "CanSuspend", &error, G_TYPE_INVALID, G_TYPE_BOOLEAN, &can_suspend, G_TYPE_INVALID)) {
			g_error_free(error);
			error = NULL;
			g_object_unref(proxy);
			proxy = dbus_g_proxy_new_for_name(connection, "org.gnome.PowerManager", "/org/gnome/PowerManager", "org.gnome.PowerManager");
			if(!dbus_g_proxy_call(proxy, "AllowedSuspend", &error, G_TYPE_INVALID, G_TYPE_BOOLEAN, &can_suspend, G_TYPE_INVALID)) {
				g_printerr(_("Failed to check if can suspend: %s\n"), error->message);
				g_error_free(error);
				error = NULL;
				can_suspend = FALSE;
			}
		}
	}

	gtk_main();

	bacon_message_connection_free(bacon_connection);
	notify_uninit();

#ifdef HAVE_LIBGNOME
	gnome_sound_shutdown();
#endif

	return 0;
}

void on_quit()
{

	if(current_record_stop_time > 0) {
		stopRecording();
	}

	saveChannelConf();
	saveFavourites();
	saveCategories();
	save_position();

	gtk_widget_hide(window);

#ifdef USE_SM
	/* unplug */
	session_end();
#endif

	gtk_main_quit();

}
